package org.apache.commons.codec.net;

import org.apache.commons.codec.CharEncoding;
import org.apache.commons.codec.DecoderException;
import org.apache.commons.codec.EncoderException;
import org.junit.Test;

/** 
 * Quoted-printable codec test cases
 * 
 * @version $Id$
 */
public class BCodecTest {
    static final int[] SWISS_GERMAN_STUFF_UNICODE = new int[]{ 71 , 114 , 252 , 101 , 122 , 105 , 95 , 122 , 228 , 109 , 228 };

    static final int[] RUSSIAN_STUFF_UNICODE = new int[]{ 1042 , 1089 , 1077 , 1084 , 95 , 1087 , 1088 , 1080 , 1074 , 1077 , 1090 };

    private String constructString(final int[] unicodeChars) {
        final StringBuilder buffer = new StringBuilder();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),0,buffer);
        if (unicodeChars != null) {
            for (final int unicodeChar : unicodeChars) {
                buffer.append(((char)(unicodeChar)));
            }
        } 
        return buffer.toString();
    }

    @Test
    public void testUTF8RoundTrip() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUTF8RoundTrip");
            final String ru_msg = constructString(RUSSIAN_STUFF_UNICODE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),27,ru_msg);
            final String ch_msg = constructString(SWISS_GERMAN_STUFF_UNICODE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),28,ch_msg);
            final BCodec bcodec = new BCodec(CharEncoding.UTF_8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,bcodec);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),21,bcodec.encode(ru_msg));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),22,bcodec.encode(ch_msg));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),23,ru_msg);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),24,bcodec.decode(bcodec.encode(ru_msg)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,ch_msg);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),26,bcodec.decode(bcodec.encode(ch_msg)));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testBasicEncodeDecode() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBasicEncodeDecode");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),4,bcodec);
            final String plain = "Helo there";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),5,plain);
            final String encoded = bcodec.encode(plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),6,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),3,bcodec.decode(encoded));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testBasicEncodeDecode_literalMutation2() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBasicEncodeDecode_literalMutation2");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),4,bcodec);
            final String plain = "Hello theÔre";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),5,plain);
            final String encoded = bcodec.encode(plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),6,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),3,bcodec.decode(encoded));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testBasicEncodeDecode_literalMutation3() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBasicEncodeDecode_literalMutation3");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),4,bcodec);
            final String plain = "Hello thee";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),5,plain);
            final String encoded = bcodec.encode(plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),6,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),3,bcodec.decode(encoded));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEncodeObjects_add2() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects_add2");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "what not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeObjects() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "wha­ not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeObjects_literalMutation14() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects_literalMutation14");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "whatn not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeObjects_literalMutation15() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects_literalMutation15");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "wht not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeObjects_literalMutation17() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects_literalMutation17");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "what not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(4.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeObjects_literalMutation18() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects_literalMutation18");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "what not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(2.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeObjects_literalMutation19() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects_literalMutation19");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "what not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(1.5);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testEncodeObjects_literalMutation20() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEncodeObjects_literalMutation20");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,bcodec);
            final String plain = "what not";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,plain);
            final String encoded = ((String)(bcodec.encode(((Object)(plain)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,encoded);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,encoded);
            final Object result = bcodec.encode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,result);
            try {
                final Object dObj = new Double(6.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,dObj);
                bcodec.encode(dObj);
            } catch (final EncoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDecodeObjects_add1() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects_add1");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTF-8?B?d2hhdCBub3Q=?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeObjects_literalMutation10() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects_literalMutation10");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTF-8?B?d2hhdCBub3Q=?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(1.5);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeObjects_literalMutation11() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects_literalMutation11");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTF-8?B?d2hhdCBub3Q=?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(6.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeObjects() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTFÐ8?B?d2hhdCBub3Q=?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeObjects_literalMutation5() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects_literalMutation5");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTF-8?ÏB?d2hhdCBub3Q=?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeObjects_literalMutation6() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects_literalMutation6");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTF-8?B?d2hhdCBub3Q?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(3.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeObjects_literalMutation8() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects_literalMutation8");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTF-8?B?d2hhdCBub3Q=?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(4.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDecodeObjects_literalMutation9() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDecodeObjects_literalMutation9");
            final BCodec bcodec = new BCodec();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,bcodec);
            final String decoded = "=?UTF-8?B?d2hhdCBub3Q=?=";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,decoded);
            final String plain = ((String)(bcodec.decode(((Object)(decoded)))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,plain);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,plain);
            final Object result = bcodec.decode(((Object)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,result);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,result);
            try {
                final Object dObj = new Double(2.0);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,dObj);
                bcodec.decode(dObj);
            } catch (final DecoderException ee) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

