package org.apache.commons.collections4;

import java.util.Collection;
import org.apache.commons.collections4.map.Flat3Map;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

/** 
 * <code>MapPerformanceTest</code> is designed to perform basic Map performance tests.
 * 
 * @version $Id$
 */
public class MapPerformance {
    /** 
     * The total number of runs for each test
     */
private static final int RUNS = 20000000;

    /** 
     * Main method
     */
public static void main(final String[] args) {
        MapPerformance.testAll();
    }

    private static void testAll() {
        final Map<java.lang.String, java.lang.String> dummyMap = new DummyMap<java.lang.String, java.lang.String>();
        final Map<java.lang.String, java.lang.String> hashMap = new HashMap<java.lang.String, java.lang.String>();
        final Map<java.lang.String, java.lang.String> flatMap = new Flat3Map<java.lang.String, java.lang.String>(hashMap);
        System.out.println(flatMap);
        MapPerformance.test(dummyMap, "         Dummy ");
        MapPerformance.test(dummyMap, "         Dummy ");
        MapPerformance.test(dummyMap, "         Dummy ");
        MapPerformance.test(flatMap, "         Flat3 ");
        MapPerformance.test(hashMap, "       HashMap ");
        MapPerformance.test(flatMap, "         Flat3 ");
        MapPerformance.test(flatMap, "         Flat3 ");
        MapPerformance.test(flatMap, "         Flat3 ");
        MapPerformance.test(hashMap, "       HashMap ");
        MapPerformance.test(hashMap, "       HashMap ");
        MapPerformance.test(hashMap, "       HashMap ");
    }

    private static void test(final Map<java.lang.String, java.lang.String> map, final String name) {
        long start = 0;
        long end = 0;
        start = System.currentTimeMillis();
        for (int i = RUNS ; i > 0 ; i--) {
            map.put("Alpha", "A");
            map.put("Beta", "B");
            map.put("Beta", "C");
            map.put("Gamma", "D");
            map.put("Delta", "E");
            map.clear();
        }
        end = System.currentTimeMillis();
        System.out.println((name + (end - start)));
    }

    private static class DummyMap<K, V> implements Map<K, V> {
        public void clear() {
        }

        public boolean containsKey(final Object key) {
            return false;
        }

        public boolean containsValue(final Object value) {
            return false;
        }

        public Set<java.util.Map.Entry<K, V>> entrySet() {
            return null;
        }

        public V get(final Object key) {
            return null;
        }

        public boolean isEmpty() {
            return false;
        }

        public Set<K> keySet() {
            return null;
        }

        public V put(final K key, final V value) {
            return null;
        }

        public void putAll(final Map<? extends K, ? extends V> t) {
        }

        public V remove(final Object key) {
            return null;
        }

        public int size() {
            return 0;
        }

        public Collection<V> values() {
            return null;
        }
    }
}

