package org.apache.commons.collections4.map;

import org.apache.commons.collections4.iterators.AbstractOrderedMapIteratorTest;
import java.util.ArrayList;
import org.apache.commons.collections4.BulkTest;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.NoSuchElementException;
import org.apache.commons.collections4.comparators.NullComparator;
import org.apache.commons.collections4.OrderedMap;
import org.apache.commons.collections4.OrderedMapIterator;
import org.junit.Test;
import java.util.TreeMap;

/** 
 * Abstract test class for {@link org.apache.commons.collections4.OrderedMap} methods and contracts.
 * 
 * @version $Id$
 */
public abstract class AbstractOrderedMapTest<K, V> extends AbstractIterableMapTest<K, V> {
    /** 
     * JUnit constructor.
     * 
     * @param testName  the test name
     */
public AbstractOrderedMapTest(final String testName) {
        super(testName);
    }

    /** 
     * {@inheritDoc}
     */
@Override
    public abstract OrderedMap<K, V> makeObject();

    /** 
     * {@inheritDoc}
     */
@Override
    public OrderedMap<K, V> makeFullMap() {
        return ((OrderedMap<K, V>)(super.makeFullMap()));
    }

    /** 
     * OrderedMap uses TreeMap as its known comparison.
     * 
     * @return a map that is known to be valid
     */
@Override
    public Map<K, V> makeConfirmedMap() {
        return new TreeMap<K, V>(new NullComparator<K>());
    }

    /** 
     * The only confirmed collection we have that is ordered is the sorted one.
     * Thus, sort the keys.
     */
@Override
    @SuppressWarnings(value = "unchecked")
    public K[] getSampleKeys() {
        final List<K> list = new ArrayList<K>(java.util.Arrays.asList(super.getSampleKeys()));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,list);
        java.util.Collections.sort(list, new NullComparator<K>());
        return ((K[])(list.toArray()));
    }

    @Test(timeout = 1000)
    public void testFirstKey() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFirstKey");
            resetEmpty();
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,ordered);
            try {
                ordered.firstKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,ordered);
            final K confirmedFirst = confirmed.keySet().iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,ordered.firstKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFirstKey_add172() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFirstKey_add172");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,ordered);
            try {
                ordered.firstKey();
                ordered.firstKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,ordered);
            final K confirmedFirst = confirmed.keySet().iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,ordered.firstKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFirstKey_add173() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFirstKey_add173");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,ordered);
            try {
                ordered.firstKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,ordered);
            final K confirmedFirst = confirmed.keySet().iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,ordered.firstKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFirstKey_remove141() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFirstKey_remove141");
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,ordered);
            try {
                ordered.firstKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,ordered);
            final K confirmedFirst = confirmed.keySet().iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,ordered.firstKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFirstKey_remove142() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFirstKey_remove142");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,ordered);
            try {
                ordered.firstKey();
            } catch (final NoSuchElementException ex) {
            }
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,ordered);
            final K confirmedFirst = confirmed.keySet().iterator().next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,confirmedFirst);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,ordered.firstKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testLastKey() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastKey");
            resetEmpty();
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,ordered);
            try {
                ordered.lastKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,ordered);
            K confirmedLast = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,confirmedLast);
            for (final Iterator<K> it = confirmed.keySet().iterator() ; it.hasNext() ; ) {
                confirmedLast = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,confirmedLast);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,ordered.lastKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testLastKey_add175() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastKey_add175");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,ordered);
            try {
                ordered.lastKey();
                ordered.lastKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,ordered);
            K confirmedLast = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,confirmedLast);
            for (final Iterator<K> it = confirmed.keySet().iterator() ; it.hasNext() ; ) {
                confirmedLast = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,confirmedLast);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,ordered.lastKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testLastKey_add176() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastKey_add176");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,ordered);
            try {
                ordered.lastKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,ordered);
            K confirmedLast = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,confirmedLast);
            for (final Iterator<K> it = confirmed.keySet().iterator() ; it.hasNext() ; ) {
                confirmedLast = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,confirmedLast);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,ordered.lastKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testLastKey_remove143() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastKey_remove143");
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,ordered);
            try {
                ordered.lastKey();
            } catch (final NoSuchElementException ex) {
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,ordered);
            K confirmedLast = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,confirmedLast);
            for (final Iterator<K> it = confirmed.keySet().iterator() ; it.hasNext() ; ) {
                confirmedLast = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,confirmedLast);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,ordered.lastKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testLastKey_remove144() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLastKey_remove144");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,ordered);
            try {
                ordered.lastKey();
            } catch (final NoSuchElementException ex) {
            }
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,ordered);
            K confirmedLast = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,confirmedLast);
            for (final Iterator<K> it = confirmed.keySet().iterator() ; it.hasNext() ; ) {
                confirmedLast = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,confirmedLast);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,ordered.lastKey());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNextKey() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNextKey");
            resetEmpty();
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,ordered.nextKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,ordered.nextKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,ordered.nextKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,ordered);
            final Iterator<K> it = confirmed.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,ordered.nextKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,ordered.nextKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.nextKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,ordered.nextKey(null));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNextKey_add178() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNextKey_add178");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,ordered.nextKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,ordered.nextKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,ordered.nextKey(null));
            }
            resetFull();
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,ordered);
            final Iterator<K> it = confirmed.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,ordered.nextKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,ordered.nextKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.nextKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,ordered.nextKey(null));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNextKey_add179() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNextKey_add179");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,ordered.nextKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,ordered.nextKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,ordered.nextKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,ordered);
            final Iterator<K> it = confirmed.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,ordered.nextKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,ordered.nextKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.nextKey(null);
                    ordered.nextKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,ordered.nextKey(null));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNextKey_remove145() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNextKey_remove145");
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,ordered.nextKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,ordered.nextKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,ordered.nextKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,ordered);
            final Iterator<K> it = confirmed.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,ordered.nextKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,ordered.nextKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.nextKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,ordered.nextKey(null));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNextKey_remove146() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNextKey_remove146");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,ordered.nextKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,ordered.nextKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,ordered.nextKey(null));
            }
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,ordered);
            final Iterator<K> it = confirmed.keySet().iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,ordered.nextKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,ordered.nextKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.nextKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,ordered.nextKey(null));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPreviousKey() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPreviousKey");
            resetEmpty();
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,ordered.previousKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,ordered.previousKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,ordered.previousKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,ordered);
            final List<K> list = new ArrayList<K>(confirmed.keySet());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,list);
            java.util.Collections.reverse(list);
            final Iterator<K> it = list.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,ordered.previousKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,ordered.previousKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.previousKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                if (!(isAllowNullKey())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,ordered.previousKey(null));
                } 
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPreviousKey_add181() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPreviousKey_add181");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,ordered.previousKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,ordered.previousKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,ordered.previousKey(null));
            }
            resetFull();
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,ordered);
            final List<K> list = new ArrayList<K>(confirmed.keySet());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,list);
            java.util.Collections.reverse(list);
            final Iterator<K> it = list.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,ordered.previousKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,ordered.previousKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.previousKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                if (!(isAllowNullKey())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,ordered.previousKey(null));
                } 
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPreviousKey_add182() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPreviousKey_add182");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,ordered.previousKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,ordered.previousKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,ordered.previousKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,ordered);
            final List<K> list = new ArrayList<K>(confirmed.keySet());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,list);
            java.util.Collections.reverse(list);
            java.util.Collections.reverse(list);
            final Iterator<K> it = list.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,ordered.previousKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,ordered.previousKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.previousKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                if (!(isAllowNullKey())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,ordered.previousKey(null));
                } 
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPreviousKey_add183() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPreviousKey_add183");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,ordered.previousKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,ordered.previousKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,ordered.previousKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,ordered);
            final List<K> list = new ArrayList<K>(confirmed.keySet());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,list);
            java.util.Collections.reverse(list);
            final Iterator<K> it = list.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,ordered.previousKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,ordered.previousKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.previousKey(null);
                    ordered.previousKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                if (!(isAllowNullKey())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,ordered.previousKey(null));
                } 
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPreviousKey_remove147() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPreviousKey_remove147");
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,ordered.previousKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,ordered.previousKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,ordered.previousKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,ordered);
            final List<K> list = new ArrayList<K>(confirmed.keySet());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,list);
            java.util.Collections.reverse(list);
            final Iterator<K> it = list.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,ordered.previousKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,ordered.previousKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.previousKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                if (!(isAllowNullKey())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,ordered.previousKey(null));
                } 
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPreviousKey_remove148() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPreviousKey_remove148");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,ordered.previousKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,ordered.previousKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,ordered.previousKey(null));
            }
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,ordered);
            final List<K> list = new ArrayList<K>(confirmed.keySet());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,list);
            java.util.Collections.reverse(list);
            final Iterator<K> it = list.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,ordered.previousKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,ordered.previousKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.previousKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                if (!(isAllowNullKey())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,ordered.previousKey(null));
                } 
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPreviousKey_remove149() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPreviousKey_remove149");
            resetEmpty();
            OrderedMap<K, V> ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,ordered);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,ordered.previousKey(getOtherKeys()[0]));
            if (!(isAllowNullKey())) {
                try {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,ordered.previousKey(null));
                } catch (final NullPointerException ex) {
                }
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,ordered.previousKey(null));
            }
            resetFull();
            ordered = getMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,ordered);
            final List<K> list = new ArrayList<K>(confirmed.keySet());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,list);
            final Iterator<K> it = list.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,it);
            K confirmedLast = it.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,confirmedLast);
            while (it.hasNext()) {
                final K confirmedObject = it.next();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,confirmedObject);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,ordered.previousKey(confirmedLast));
                confirmedLast = confirmedObject;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,confirmedLast);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,ordered.previousKey(confirmedLast));
            if (!(isAllowNullKey())) {
                try {
                    ordered.previousKey(null);
                } catch (final NullPointerException ex) {
                }
            } else {
                if (!(isAllowNullKey())) {
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,ordered.previousKey(null));
                } 
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public BulkTest bulkTestOrderedMapIterator() {
        return new InnerTestOrderedMapIterator();
    }

    public class InnerTestOrderedMapIterator extends AbstractOrderedMapIteratorTest<K, V> {
        public InnerTestOrderedMapIterator() {
            super("InnerTestOrderedMapIterator");
        }

        @Override
        public boolean supportsRemove() {
            return org.apache.commons.collections4.map.AbstractOrderedMapTest.this.isRemoveSupported();
        }

        @Override
        public boolean isGetStructuralModify() {
            return org.apache.commons.collections4.map.AbstractOrderedMapTest.this.isGetStructuralModify();
        }

        @Override
        public boolean supportsSetValue() {
            return org.apache.commons.collections4.map.AbstractOrderedMapTest.this.isSetValueSupported();
        }

        @Override
        public OrderedMapIterator<K, V> makeEmptyIterator() {
            resetEmpty();
            return org.apache.commons.collections4.map.AbstractOrderedMapTest.this.getMap().mapIterator();
        }

        @Override
        public OrderedMapIterator<K, V> makeObject() {
            resetFull();
            return org.apache.commons.collections4.map.AbstractOrderedMapTest.this.getMap().mapIterator();
        }

        @Override
        public OrderedMap<K, V> getMap() {
            return org.apache.commons.collections4.map.AbstractOrderedMapTest.this.getMap();
        }

        @Override
        public Map<K, V> getConfirmedMap() {
            return org.apache.commons.collections4.map.AbstractOrderedMapTest.this.getConfirmed();
        }

        @Override
        public void verify() {
            super.verify();
            org.apache.commons.collections4.map.AbstractOrderedMapTest.this.verify();
        }
    }

    /** 
     * {@inheritDoc}
     */
@Override
    public OrderedMap<K, V> getMap() {
        return ((OrderedMap<K, V>)(super.getMap()));
    }
}

