package org.apache.commons.io;

import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import java.io.IOException;
import org.junit.Test;

/** 
 * This class ensure the correctness of {@link FileUtils#directoryContains(File,File)}.
 * 
 * @see FileUtils#directoryContains(File, File)
 * @since 2.2
 * @version $Id$
 */
public class FileUtilsDirectoryContainsTestCase extends FileBasedTestCase {
    private File directory1;

    private File directory2;

    private File directory3;

    private File file1;

    private File file1ByRelativeDirectory2;

    private File file2;

    private File file2ByRelativeDirectory1;

    private File file3;

    final File top = FileBasedTestCase.getTestDirectory();

    public FileUtilsDirectoryContainsTestCase(String name) {
        super(name);
    }

    @Override
    protected void setUp() throws Exception {
        top.mkdirs();
        directory1 = new File(top , "directory1");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),402,directory1);
        directory2 = new File(top , "directory2");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),403,directory2);
        directory3 = new File(directory2 , "directory3");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),404,directory3);
        directory1.mkdir();
        directory2.mkdir();
        directory3.mkdir();
        file1 = new File(directory1 , "file1");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),405,file1);
        file2 = new File(directory2 , "file2");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),406,file2);
        file3 = new File(top , "file3");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),407,file3);
        file1ByRelativeDirectory2 = new File(FileBasedTestCase.getTestDirectory() , "directory2/../directory1/file1");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),408,file1ByRelativeDirectory2);
        file2ByRelativeDirectory1 = new File(FileBasedTestCase.getTestDirectory() , "directory1/../directory2/file2");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),409,file2ByRelativeDirectory1);
        org.apache.commons.io.FileUtils.touch(file1);
        org.apache.commons.io.FileUtils.touch(file2);
        org.apache.commons.io.FileUtils.touch(file3);
    }

    @Override
    protected void tearDown() throws Exception {
        org.apache.commons.io.FileUtils.deleteDirectory(top);
    }

    @Test
    public void testCanonicalPath() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCanonicalPath");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),410,org.apache.commons.io.FileUtils.directoryContains(directory1, file1ByRelativeDirectory2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),411,org.apache.commons.io.FileUtils.directoryContains(directory2, file2ByRelativeDirectory1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),412,org.apache.commons.io.FileUtils.directoryContains(directory1, file2ByRelativeDirectory1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),413,org.apache.commons.io.FileUtils.directoryContains(directory2, file1ByRelativeDirectory2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDirectoryContainsDirectory() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDirectoryContainsDirectory");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),414,org.apache.commons.io.FileUtils.directoryContains(top, directory1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,org.apache.commons.io.FileUtils.directoryContains(top, directory2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),416,org.apache.commons.io.FileUtils.directoryContains(top, directory3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),417,org.apache.commons.io.FileUtils.directoryContains(directory2, directory3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDirectoryContainsFile() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDirectoryContainsFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),418,org.apache.commons.io.FileUtils.directoryContains(directory1, file1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),419,org.apache.commons.io.FileUtils.directoryContains(directory2, file2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDirectoryDoesNotContainFile() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDirectoryDoesNotContainFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),420,org.apache.commons.io.FileUtils.directoryContains(directory1, file2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),421,org.apache.commons.io.FileUtils.directoryContains(directory2, file1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),422,org.apache.commons.io.FileUtils.directoryContains(directory1, file3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,org.apache.commons.io.FileUtils.directoryContains(directory2, file3));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDirectoryDoesNotContainsDirectory() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDirectoryDoesNotContainsDirectory");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),424,org.apache.commons.io.FileUtils.directoryContains(directory1, top));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),425,org.apache.commons.io.FileUtils.directoryContains(directory2, top));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),426,org.apache.commons.io.FileUtils.directoryContains(directory3, top));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),427,org.apache.commons.io.FileUtils.directoryContains(directory3, directory2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDirectoryDoesNotExist() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDirectoryDoesNotExist");
            final File dir = new File("D¢ESNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,dir);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,dir.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,org.apache.commons.io.FileUtils.directoryContains(dir, file1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,("Expected " + (java.lang.IllegalArgumentException.class.getName())));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDirectoryDoesNotExist_literalMutation352() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDirectoryDoesNotExist_literalMutation352");
            final File dir = new File("DOESNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,dir);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,dir.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,org.apache.commons.io.FileUtils.directoryContains(dir, file1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,("Expected " + (java.lang.IllegalArgumentException.class.getName())));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testDirectoryDoesNotExist_literalMutation353() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDirectoryDoesNotExist_literalMutation353");
            final File dir = new File("DOESNOTEIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),431,dir);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,dir.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),429,org.apache.commons.io.FileUtils.directoryContains(dir, file1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),430,("Expected " + (java.lang.IllegalArgumentException.class.getName())));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testSameFile() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameFile");
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),440,org.apache.commons.io.FileUtils.directoryContains(file1, file1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),441,("Expected " + (java.lang.IllegalArgumentException.class.getName())));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testFileDoesNotExist() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileDoesNotExist");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,org.apache.commons.io.FileUtils.directoryContains(top, null));
            final File file = new File("DOESNOTEÌIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,org.apache.commons.io.FileUtils.directoryContains(top, file));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testFileDoesNotExist_literalMutation355() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileDoesNotExist_literalMutation355");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,org.apache.commons.io.FileUtils.directoryContains(top, null));
            final File file = new File("DÔOESNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,org.apache.commons.io.FileUtils.directoryContains(top, file));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testFileDoesNotExist_literalMutation356() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileDoesNotExist_literalMutation356");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),436,org.apache.commons.io.FileUtils.directoryContains(top, null));
            final File file = new File("DOESNOTEXST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),439,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),437,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),438,org.apache.commons.io.FileUtils.directoryContains(top, file));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test to demonstrate a file which does not exist returns false
     * @throws IOException
     */
@Test
    public void testFileDoesNotExistBug() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileDoesNotExistBug");
            final File file = new File(top , "D$ESNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,top.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,org.apache.commons.io.FileUtils.directoryContains(top, file));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test to demonstrate a file which does not exist returns false
     * @throws IOException
     */
@Test
    public void testFileDoesNotExistBug_literalMutation358() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileDoesNotExistBug_literalMutation358");
            final File file = new File(top , "DOEWSNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,top.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,org.apache.commons.io.FileUtils.directoryContains(top, file));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test to demonstrate a file which does not exist returns false
     * @throws IOException
     */
@Test
    public void testFileDoesNotExistBug_literalMutation359() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileDoesNotExistBug_literalMutation359");
            final File file = new File(top , "DOENOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),435,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),432,top.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),433,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),434,org.apache.commons.io.FileUtils.directoryContains(top, file));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testUnrealizedContainment() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUnrealizedContainment");
            final File dir = new File("DOESNOTEIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,dir);
            final File file = new File(dir , "DOESNOTEXIST2");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,dir.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,file.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,org.apache.commons.io.FileUtils.directoryContains(dir, file));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testUnrealizedContainment_literalMutation361() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUnrealizedContainment_literalMutation361");
            final File dir = new File("DOEëSNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,dir);
            final File file = new File(dir , "DOESNOTEXIST2");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,dir.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,file.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,org.apache.commons.io.FileUtils.directoryContains(dir, file));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testUnrealizedContainment_literalMutation362() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUnrealizedContainment_literalMutation362");
            final File dir = new File("DOESNOTEXST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,dir);
            final File file = new File(dir , "DOESNOTEXIST2");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,dir.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,file.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,org.apache.commons.io.FileUtils.directoryContains(dir, file));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testUnrealizedContainment_literalMutation363() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUnrealizedContainment_literalMutation363");
            final File dir = new File("DOESNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,dir);
            final File file = new File(dir , "DOESNOTEX¯ST2");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,dir.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,file.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,org.apache.commons.io.FileUtils.directoryContains(dir, file));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testUnrealizedContainment_literalMutation364() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUnrealizedContainment_literalMutation364");
            final File dir = new File("DOESNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,dir);
            final File file = new File(dir , "DOESNOVTEXIST2");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,dir.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,file.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,org.apache.commons.io.FileUtils.directoryContains(dir, file));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test
    public void testUnrealizedContainment_literalMutation365() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUnrealizedContainment_literalMutation365");
            final File dir = new File("DOESNOTEXIST");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,dir);
            final File file = new File(dir , "DESNOTEXIST2");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),446,file);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),442,dir.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),443,file.exists());
            try {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),444,org.apache.commons.io.FileUtils.directoryContains(dir, file));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

