package org.apache.commons.io;

import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import org.junit.Test;

/** 
 * This is used to test FileUtils for correctness.
 */
public class FileUtilsFileNewerTestCase extends FileBasedTestCase {
    private static final int FILE1_SIZE = 1;

    private static final int FILE2_SIZE = (1024 * 4) + 1;

    private File m_testFile1;

    private File m_testFile2;

    public FileUtilsFileNewerTestCase(String name) {
        super(name);
        m_testFile1 = new File(FileBasedTestCase.getTestDirectory() , "file1-test.txt");
        m_testFile2 = new File(FileBasedTestCase.getTestDirectory() , "file2-test.txt");
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        FileBasedTestCase.getTestDirectory().mkdirs();
        createFile(m_testFile1, FILE1_SIZE);
        createFile(m_testFile2, FILE2_SIZE);
    }

    /** 
     * @see junit.framework.TestCase#tearDown()
     */
@Override
    protected void tearDown() throws Exception {
        m_testFile1.delete();
        m_testFile2.delete();
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewer_add100() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_add100");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewer_add101() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_add101");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewer_add99() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_add99");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_tesFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation367() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation367");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation368() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation368");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("Te m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation369() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation369");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation370() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation370");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 1999;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation371() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation371");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 1000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation372() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation372");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 4000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation374() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation374");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier Äs not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation375() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation375");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation376() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation376");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second arlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation377() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation377");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), true);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation378() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation378");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("saØe time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation379() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation379");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same timõe is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation380() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation380");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("sam time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation381() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation381");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, true);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation382() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation382");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two seÐond later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation383() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation383");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second lËater is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewer_literalMutation384() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_literalMutation384");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("two second earlier is not newer", m_testFile1, (fileLastModified + TWO_SECOND), false);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two econd later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewer_remove59() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_remove59");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewer_remove60() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_remove60");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a "normal" file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewer_remove61() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewer_remove61");
            if (!(m_testFile1.exists())) {
                throw new IllegalStateException("The m_testFile1 should exist");
            } 
            long fileLastModified = m_testFile1.lastModified();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),460,fileLastModified);
            final long TWO_SECOND = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,TWO_SECOND);
            testIsFileNewer("same time is not newer", m_testFile1, fileLastModified, false);
            testIsFileNewer("two second later is newer", m_testFile1, (fileLastModified - TWO_SECOND), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewerImaginaryFile_add102() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_add102");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imagnaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation387() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation387");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaÉginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation388() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation388");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imainaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation389() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation389");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File ehists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation390() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation390");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation391() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation391");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary ile exists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation392() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation392");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file£can be newer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation393() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation393");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can be ne>wer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation394() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation394");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can benewer", imaginaryFile, m_testFile2.lastModified(), false);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
public void testIsFileNewerImaginaryFile_literalMutation395() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_literalMutation395");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
            testIsFileNewer("imaginary file can be newer", imaginaryFile, m_testFile2.lastModified(), true);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which a not existing file.
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
@Test(timeout = 1000)
    public void testIsFileNewerImaginaryFile_remove62() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerImaginaryFile_remove62");
            File imaginaryFile = new File(FileBasedTestCase.getTestDirectory() , "imaginaryFile");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),459,imaginaryFile);
            if (imaginaryFile.exists()) {
                throw new IllegalStateException("The imaginary File exists");
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, *)</code> methods which the specified conditions.
     * <p/>
     * Creates :
     * <ul>
     * <li>a <code>Date</code> which represents the time reference</li>
     * <li>a temporary file with the same last modification date than the time reference</li>
     * </ul>
     * Then compares (with the needed <code>isFileNewer</code> method) the last modification date of
     * the specified file with the specified time reference, the created <code>Date</code> and the temporary
     * file.
     * <br/>
     * The test is successfull if the three comparaisons return the specified wanted result.
     * 
     * @param description describes the tested situation
     * @param file the file of which the last modification date is compared
     * @param time the time reference measured in milliseconds since the epoch
     * 
     * @see FileUtils#isFileNewer(File, long)
     * @see FileUtils#isFileNewer(File, Date)
     * @see FileUtils#isFileNewer(File, File)
     */
protected void testIsFileNewer(String description, File file, long time, boolean wantedResult) {
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),447,(description + " - time"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),448,wantedResult);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),449,org.apache.commons.io.FileUtils.isFileNewer(file, time));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,(description + " - date"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),451,wantedResult);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),452,org.apache.commons.io.FileUtils.isFileNewer(file, new java.util.Date(time)));
        File temporaryFile = m_testFile2;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),458,temporaryFile);
        temporaryFile.setLastModified(time);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,time);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),454,temporaryFile.lastModified());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),455,(description + " - file"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),456,wantedResult);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),457,org.apache.commons.io.FileUtils.isFileNewer(file, temporaryFile));
    }

    /** 
     * Tests the <code>isFileNewer(File, long)</code> method without specifying a <code>File</code>.
     * <br/>
     * The test is successfull if the method throws an <code>IllegalArgumentException</code>.
     */
@Test(timeout = 1000)
    public void testIsFileNewerNoFile_add104() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerNoFile_add104");
            try {
                org.apache.commons.io.FileUtils.isFileNewer(null, 0);
                org.apache.commons.io.FileUtils.isFileNewer(null, 0);
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, long)</code> method without specifying a <code>File</code>.
     * <br/>
     * The test is successfull if the method throws an <code>IllegalArgumentException</code>.
     */
public void testIsFileNewerNoFile() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerNoFile");
            try {
                org.apache.commons.io.FileUtils.isFileNewer(null, 1);
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, long)</code> method without specifying a <code>File</code>.
     * <br/>
     * The test is successfull if the method throws an <code>IllegalArgumentException</code>.
     */
public void testIsFileNewerNoFile_literalMutation399() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerNoFile_literalMutation399");
            try {
                org.apache.commons.io.FileUtils.isFileNewer(null, -1);
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, long)</code> method without specifying a <code>File</code>.
     * <br/>
     * The test is successfull if the method throws an <code>IllegalArgumentException</code>.
     */
public void testIsFileNewerNoFile_literalMutation400() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerNoFile_literalMutation400");
            try {
                org.apache.commons.io.FileUtils.isFileNewer(null, 0);
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, Date)</code> method without specifying a <code>Date</code>.
     * <br/>
     * The test is successfull if the method throws an <code>IllegalArgumentException</code>.
     */
@Test(timeout = 1000)
    public void testIsFileNewerNoDate() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerNoDate");
            try {
                org.apache.commons.io.FileUtils.isFileNewer(m_testFile1, ((java.util.Date)(null)));
                org.apache.commons.io.FileUtils.isFileNewer(m_testFile1, ((java.util.Date)(null)));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests the <code>isFileNewer(File, File)</code> method without specifying a reference <code>File</code>.
     * <br/>
     * The test is successfull if the method throws an <code>IllegalArgumentException</code>.
     */
@Test(timeout = 1000)
    public void testIsFileNewerNoFileReference() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsFileNewerNoFileReference");
            try {
                org.apache.commons.io.FileUtils.isFileNewer(m_testFile1, ((File)(null)));
                org.apache.commons.io.FileUtils.isFileNewer(m_testFile1, ((File)(null)));
            } catch (IllegalArgumentException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

