package org.apache.commons.io.comparator;

import java.util.ArrayList;
import java.util.Comparator;
import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import java.util.List;
import org.junit.Test;

/** 
 * Base Test case for Comparator implementations.
 */
public abstract class ComparatorAbstractTestCase extends FileBasedTestCase {
    /** 
     * comparator instance
     */
protected AbstractFileComparator comparator;

    /** 
     * reverse comparator instance
     */
protected Comparator<java.io.File> reverse;

    /** 
     * File which compares equal to  "equalFile2"
     */
protected File equalFile1;

    /** 
     * File which compares equal to  "equalFile1"
     */
protected File equalFile2;

    /** 
     * File which is less than the "moreFile"
     */
protected File lessFile;

    /** 
     * File which is more than the "lessFile"
     */
protected File moreFile;

    /** 
     * Construct a new test case with the specified name
     * @param name Name of the test
     */
public ComparatorAbstractTestCase(String name) {
        super(name);
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        comparator = ((AbstractFileComparator)(DefaultFileComparator.DEFAULT_COMPARATOR));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,comparator);
        reverse = DefaultFileComparator.DEFAULT_REVERSE;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,reverse);
    }

    /** 
     * @see junit.framework.TestCase#tearDown()
     */
@Override
    protected void tearDown() throws Exception {
        comparator = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,comparator);
        reverse = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,reverse);
        equalFile1 = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,equalFile1);
        equalFile2 = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,equalFile2);
        lessFile = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,lessFile);
        moreFile = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),21,moreFile);
        org.apache.commons.io.FileUtils.deleteDirectory(FileBasedTestCase.getTestDirectory());
    }

    /** 
     * Test the comparator.
     */
public void testComparator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComparator");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),22,comparator.compare(equalFile1, equalFile2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),23,((comparator.compare(lessFile, moreFile)) < 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),24,((comparator.compare(moreFile, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator reversed.
     */
public void testReverseComparator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReverseComparator");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,reverse.compare(equalFile1, equalFile2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),26,((reverse.compare(moreFile, lessFile)) < 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),27,((reverse.compare(lessFile, moreFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test comparator array sort is null safe.
     */
public void testSortArrayNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArrayNull");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),28,comparator.sort(((java.io.File[])(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortArray_add16() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_add16");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray");
            File[] files = new File[4];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation81() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation81");
            File[] files = new File[2];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation82() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation82");
            File[] files = new File[1];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation83() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation83");
            File[] files = new File[6];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation85() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation85");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[1] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),39,files[1]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation86() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation86");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[-1] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),40,files[-1]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation87() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation87");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation89() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation89");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[2] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),41,files[2]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation90() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation90");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[0] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),42,files[0]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation91() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation91");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[0] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),42,files[0]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation93() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation93");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[1] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),43,files[1]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation94() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation94");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[4] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),44,files[4]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
public void testSortArray_literalMutation95() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_literalMutation95");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[3] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),45,files[3]);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortArray_remove16() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortArray_remove16");
            File[] files = new File[3];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,files);
            files[0] = equalFile1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,files[0]);
            files[1] = moreFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,files[1]);
            files[2] = lessFile;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,files[2]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,files[0]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),31,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),32,files[1]);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),33,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),34,files[2]);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(equalFile1);
            files.add(equalFile1);
            files.add(moreFile);
            files.add(lessFile);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList_add18() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList_add18");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(equalFile1);
            files.add(moreFile);
            files.add(moreFile);
            files.add(lessFile);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList_add19() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList_add19");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(equalFile1);
            files.add(moreFile);
            files.add(lessFile);
            files.add(lessFile);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList_add20() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList_add20");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(equalFile1);
            files.add(moreFile);
            files.add(lessFile);
            comparator.sort(files);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList_remove17() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList_remove17");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(moreFile);
            files.add(lessFile);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList_remove18() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList_remove18");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(moreFile);
            files.add(lessFile);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList_remove19() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList_remove19");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(moreFile);
            files.add(lessFile);
            comparator.sort(files);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test the comparator array sort.
     */
@Test(timeout = 1000)
    public void testSortList_remove20() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortList_remove20");
            List<java.io.File> files = new ArrayList<java.io.File>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),53,files);
            files.add(equalFile1);
            files.add(moreFile);
            files.add(lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,lessFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),48,files.get(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),49,equalFile1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),50,files.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),51,moreFile);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),52,files.get(2));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test comparator list sort is null safe.
     */
public void testSortListNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSortListNull");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),46,comparator.sort(((java.util.List<java.io.File>)(null))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test comparator toString.
     */
public void testToString() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testToString");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),54,comparator.toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),55,reverse.toString().startsWith("ReverseComparator["));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

