package org.apache.commons.io.comparator;

import java.util.ArrayList;
import java.util.Comparator;
import java.io.File;
import java.util.List;
import org.junit.Test;

/** 
 * Test case for {@link CompositeFileComparator}.
 */
public class CompositeFileComparatorTest extends ComparatorAbstractTestCase {
    /** 
     * Construct a new test case with the specified name.
     * 
     * @param name Name of the test
     */
public CompositeFileComparatorTest(String name) {
        super(name);
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        super.setUp();
        comparator = new CompositeFileComparator(SizeFileComparator.SIZE_COMPARATOR , ExtensionFileComparator.EXTENSION_COMPARATOR);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),56,comparator);
        reverse = new ReverseComparator(comparator);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),57,reverse);
        File dir = org.apache.commons.io.testtools.FileBasedTestCase.getTestDirectory();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),62,dir);
        lessFile = new File(dir , "xyz.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),58,lessFile);
        equalFile1 = new File(dir , "foo.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),59,equalFile1);
        equalFile2 = new File(dir , "bar.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),60,equalFile2);
        moreFile = new File(dir , "foo.xyz");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),61,moreFile);
        createFile(lessFile, 32);
        createFile(equalFile1, 48);
        createFile(equalFile2, 48);
        createFile(moreFile, 48);
    }

    /** 
     * Test Constructor with null Iterable
     */
@Test(timeout = 1000)
    public void testConstructorIterable() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructorIterable");
            List<java.util.Comparator<java.io.File>> list = new ArrayList<java.util.Comparator<java.io.File>>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),74,list);
            list.add(SizeFileComparator.SIZE_COMPARATOR);
            list.add(SizeFileComparator.SIZE_COMPARATOR);
            list.add(ExtensionFileComparator.EXTENSION_COMPARATOR);
            Comparator<java.io.File> c = new CompositeFileComparator(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),75,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),71,c.compare(equalFile1, equalFile2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),72,((c.compare(lessFile, moreFile)) < 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),73,((c.compare(moreFile, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test Constructor with null Iterable
     */
@Test(timeout = 1000)
    public void testConstructorIterable_add22() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructorIterable_add22");
            List<java.util.Comparator<java.io.File>> list = new ArrayList<java.util.Comparator<java.io.File>>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),74,list);
            list.add(SizeFileComparator.SIZE_COMPARATOR);
            list.add(ExtensionFileComparator.EXTENSION_COMPARATOR);
            list.add(ExtensionFileComparator.EXTENSION_COMPARATOR);
            Comparator<java.io.File> c = new CompositeFileComparator(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),75,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),71,c.compare(equalFile1, equalFile2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),72,((c.compare(lessFile, moreFile)) < 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),73,((c.compare(moreFile, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test Constructor with null Iterable
     */
@Test(timeout = 1000)
    public void testConstructorIterable_remove21() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructorIterable_remove21");
            List<java.util.Comparator<java.io.File>> list = new ArrayList<java.util.Comparator<java.io.File>>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),74,list);
            list.add(ExtensionFileComparator.EXTENSION_COMPARATOR);
            Comparator<java.io.File> c = new CompositeFileComparator(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),75,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),71,c.compare(equalFile1, equalFile2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),72,((c.compare(lessFile, moreFile)) < 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),73,((c.compare(moreFile, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test Constructor with null Iterable
     */
@Test(timeout = 1000)
    public void testConstructorIterable_remove22() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructorIterable_remove22");
            List<java.util.Comparator<java.io.File>> list = new ArrayList<java.util.Comparator<java.io.File>>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),74,list);
            list.add(ExtensionFileComparator.EXTENSION_COMPARATOR);
            Comparator<java.io.File> c = new CompositeFileComparator(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),75,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),71,c.compare(equalFile1, equalFile2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),72,((c.compare(lessFile, moreFile)) < 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),73,((c.compare(moreFile, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test Constructor with null Iterable
     */
public void testConstructorIterableNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructorIterableNull");
            Comparator<java.io.File> c = new CompositeFileComparator(((Iterable<java.util.Comparator<java.io.File>>)(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),70,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),67,c.compare(lessFile, moreFile));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),68,c.compare(moreFile, lessFile));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),69,c.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test Constructor with null array
     */
public void testConstructorArrayNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructorArrayNull");
            Comparator<java.io.File> c = new CompositeFileComparator(((Comparator<java.io.File>[])(null)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),66,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),63,c.compare(lessFile, moreFile));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),64,c.compare(moreFile, lessFile));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),65,c.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

