package org.apache.commons.io.comparator;

import java.util.Comparator;
import java.io.File;

/** 
 * Test case for {@link NameFileComparator}.
 */
public class NameFileComparatorTest extends ComparatorAbstractTestCase {
    /** 
     * Construct a new test case with the specified name.
     * 
     * @param name Name of the test
     */
public NameFileComparatorTest(String name) {
        super(name);
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        super.setUp();
        comparator = ((AbstractFileComparator)(NameFileComparator.NAME_INSENSITIVE_COMPARATOR));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,comparator);
        reverse = NameFileComparator.NAME_REVERSE;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,reverse);
        equalFile1 = new File("a/foo.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,equalFile1);
        equalFile2 = new File("b/foo.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,equalFile2);
        lessFile = new File("c/ABC.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,lessFile);
        moreFile = new File("d/XYZ.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,moreFile);
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity");
            File file3 = new File("a/FOO.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new NameFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = NameFileComparator.NAME_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation103() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation103");
            File file3 = new File("aFOO.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new NameFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = NameFileComparator.NAME_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation104() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation104");
            File file3 = new File("a/FOMO.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new NameFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = NameFileComparator.NAME_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation105() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation105");
            File file3 = new File("a/FO.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new NameFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = NameFileComparator.NAME_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

