package org.apache.commons.io.comparator;

import java.util.Comparator;
import java.io.File;

/** 
 * Test case for {@link PathFileComparator}.
 */
public class PathFileComparatorTest extends ComparatorAbstractTestCase {
    /** 
     * Construct a new test case with the specified name.
     * 
     * @param name Name of the test
     */
public PathFileComparatorTest(String name) {
        super(name);
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        super.setUp();
        comparator = ((AbstractFileComparator)(PathFileComparator.PATH_COMPARATOR));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),87,comparator);
        reverse = PathFileComparator.PATH_REVERSE;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),88,reverse);
        equalFile1 = new File("foo/file.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),82,equalFile1);
        equalFile2 = new File("foo/file.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),83,equalFile2);
        lessFile = new File("abc/file.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),84,lessFile);
        moreFile = new File("xyz/file.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),85,moreFile);
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity");
            File file3 = new File("FOO/file.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new PathFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = PathFileComparator.PATH_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation107() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation107");
            File file3 = new File("FOO/fiae.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new PathFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = PathFileComparator.PATH_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation108() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation108");
            File file3 = new File("FOO/filÄe.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new PathFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = PathFileComparator.PATH_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test case sensitivity
     */
public void testCaseSensitivity_literalMutation109() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCaseSensitivity_literalMutation109");
            File file3 = new File("FOO/fil.txt");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),96,file3);
            Comparator<java.io.File> sensitive = new PathFileComparator(null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),97,sensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),89,((sensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),90,((sensitive.compare(equalFile1, file3)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),91,((sensitive.compare(equalFile1, lessFile)) > 0));
            Comparator<java.io.File> insensitive = PathFileComparator.PATH_INSENSITIVE_COMPARATOR;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),98,insensitive);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),92,((insensitive.compare(equalFile1, equalFile2)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),93,((insensitive.compare(equalFile1, file3)) == 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),94,((insensitive.compare(equalFile1, lessFile)) > 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),95,((insensitive.compare(file3, lessFile)) > 0));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

