package org.apache.commons.io.output;

import junit.framework.AssertionFailedError;
import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import java.io.FileOutputStream;
import java.io.FileWriter;
import java.io.IOException;
import java.io.OutputStreamWriter;
import org.junit.Test;
import java.io.Writer;

/** 
 * Tests that the encoding is actually set and used.
 * 
 * @version $Id$
 */
public class FileWriterWithEncodingTest extends FileBasedTestCase {
    private String defaultEncoding;

    private File file1;

    private File file2;

    private String textContent;

    public FileWriterWithEncodingTest(String name) {
        super(name);
    }

    @Override
    public void setUp() {
        File encodingFinder = new File(FileBasedTestCase.getTestDirectory() , "finder.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,encodingFinder);
        OutputStreamWriter out = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),125,out);
        try {
            out = new OutputStreamWriter(new FileOutputStream(encodingFinder));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),118,out);
            defaultEncoding = out.getEncoding();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),119,defaultEncoding);
        } catch (IOException ex) {
            throw new RuntimeException(ex.getMessage());
        } finally {
            org.apache.commons.io.IOUtils.closeQuietly(out);
        }
        file1 = new File(FileBasedTestCase.getTestDirectory() , "testfile1.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),120,file1);
        file2 = new File(FileBasedTestCase.getTestDirectory() , "testfile2.txt");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),121,file2);
        char[] arr = new char[1024];
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),126,arr);
        for (int i = 0 ; i < (arr.length) ; i++) {
            arr[i] = ((char)(i));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),122,arr[i]);
        }
        textContent = new String(arr);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),123,textContent);
    }

    @Override
    public void tearDown() throws Exception {
        org.apache.commons.io.FileUtils.deleteDirectory(FileBasedTestCase.getTestDirectory());
        defaultEncoding = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),127,defaultEncoding);
        textContent = null;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),128,textContent);
    }

    @Test(timeout = 1000)
    public void testSameEncoding() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameEncoding");
            FileWriter fw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,fw1);
            FileWriterWithEncoding fw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,fw2);
            try {
                fw1 = new FileWriter(file1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,fw1);
                fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,fw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,file2.exists());
                fw1.write(textContent);
                fw1.write(textContent);
                fw2.write(textContent);
                fw1.flush();
                fw2.flush();
                checkFile(file1, file2);
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,file1.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,file2.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSameEncoding_add42() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameEncoding_add42");
            FileWriter fw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,fw1);
            FileWriterWithEncoding fw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,fw2);
            try {
                fw1 = new FileWriter(file1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,fw1);
                fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,fw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,file2.exists());
                fw1.write(textContent);
                fw2.write(textContent);
                fw2.write(textContent);
                fw1.flush();
                fw2.flush();
                checkFile(file1, file2);
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,file1.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,file2.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSameEncoding_add43() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameEncoding_add43");
            FileWriter fw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,fw1);
            FileWriterWithEncoding fw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,fw2);
            try {
                fw1 = new FileWriter(file1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,fw1);
                fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,fw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,file2.exists());
                fw1.write(textContent);
                fw2.write(textContent);
                fw1.flush();
                fw1.flush();
                fw2.flush();
                checkFile(file1, file2);
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,file1.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,file2.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSameEncoding_add44() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameEncoding_add44");
            FileWriter fw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,fw1);
            FileWriterWithEncoding fw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,fw2);
            try {
                fw1 = new FileWriter(file1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,fw1);
                fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,fw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,file2.exists());
                fw1.write(textContent);
                fw2.write(textContent);
                fw1.flush();
                fw2.flush();
                fw2.flush();
                checkFile(file1, file2);
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,file1.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,file2.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSameEncoding_add45() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameEncoding_add45");
            FileWriter fw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,fw1);
            FileWriterWithEncoding fw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,fw2);
            try {
                fw1 = new FileWriter(file1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,fw1);
                fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,fw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,file2.exists());
                fw1.write(textContent);
                fw2.write(textContent);
                fw1.flush();
                fw2.flush();
                checkFile(file1, file2);
                checkFile(file1, file2);
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,file1.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,file2.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSameEncoding_add46() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameEncoding_add46");
            FileWriter fw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,fw1);
            FileWriterWithEncoding fw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,fw2);
            try {
                fw1 = new FileWriter(file1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,fw1);
                fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,fw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,file2.exists());
                fw1.write(textContent);
                fw2.write(textContent);
                fw1.flush();
                fw2.flush();
                checkFile(file1, file2);
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,file1.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,file2.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSameEncoding_add47() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSameEncoding_add47");
            FileWriter fw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),167,fw1);
            FileWriterWithEncoding fw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),168,fw2);
            try {
                fw1 = new FileWriter(file1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),165,fw1);
                fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),166,fw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),161,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,file2.exists());
                fw1.write(textContent);
                fw2.write(textContent);
                fw1.flush();
                fw2.flush();
                checkFile(file1, file2);
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(fw1);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
                org.apache.commons.io.IOUtils.closeQuietly(fw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),163,file1.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),164,file2.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add27() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add27");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add28() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add28");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add29() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add29");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add30() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add30");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add31() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add31");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add32() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add32");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add33() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add33");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add34() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add34");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add35() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add35");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add36() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add36");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add37() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add37");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add38() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add38");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add39() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add39");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDifferentEncoding_add40() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_add40");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentEncoding() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding");
            if (java.nio.charset.Charset.isSupported("UÑF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentEncoding_literalMutation121() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_literalMutation121");
            if (java.nio.charset.Charset.isSupported("UTðF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentEncoding_literalMutation122() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_literalMutation122");
            if (java.nio.charset.Charset.isSupported("UF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentEncoding_literalMutation125() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_literalMutation125");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTFD16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentEncoding_literalMutation126() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_literalMutation126");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-o16LE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDifferentEncoding_literalMutation127() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDifferentEncoding_literalMutation127");
            if (java.nio.charset.Charset.isSupported("UTF-16BE")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),157,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),158,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),153,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),154,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),146,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),147,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),148,file2.exists());
            } 
            if (java.nio.charset.Charset.isSupported("UTF-16E")) {
                FileWriter fw1 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),159,fw1);
                FileWriterWithEncoding fw2 = null;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),160,fw2);
                try {
                    fw1 = new FileWriter(file1);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),155,fw1);
                    fw2 = new FileWriterWithEncoding(file2 , defaultEncoding);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),156,fw2);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),149,file1.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),150,file2.exists());
                    fw1.write(textContent);
                    fw2.write(textContent);
                    fw1.flush();
                    fw2.flush();
                    try {
                        checkFile(file1, file2);
                    } catch (AssertionFailedError ex) {
                    }
                } finally {
                    org.apache.commons.io.IOUtils.closeQuietly(fw1);
                    org.apache.commons.io.IOUtils.closeQuietly(fw2);
                }
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),151,file1.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),152,file2.exists());
            } 
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_File_encoding_badEncoding_add24() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding_add24");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,writer);
            try {
                writer = new FileWriterWithEncoding(file1 , "BAD-ENCODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,writer);
            } catch (IOException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,file1.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,file1.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_encoding_badEncoding() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,writer);
            try {
                writer = new FileWriterWithEncoding(file1 , "BAì-ENCODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,writer);
            } catch (IOException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,file1.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,file1.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_encoding_badEncoding_literalMutation114() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding_literalMutation114");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,writer);
            try {
                writer = new FileWriterWithEncoding(file1 , "BAD-\rENCODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,writer);
            } catch (IOException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,file1.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,file1.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_encoding_badEncoding_literalMutation115() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding_literalMutation115");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),136,writer);
            try {
                writer = new FileWriterWithEncoding(file1 , "BD-ENCODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),135,writer);
            } catch (IOException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),133,file1.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),134,file1.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_File_directory() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_directory");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,writer);
            try {
                writer = new FileWriterWithEncoding(FileBasedTestCase.getTestDirectory() , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),131,writer);
            } catch (IOException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),129,file1.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),130,file1.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_File_nullFile() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_nullFile");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),140,writer);
            try {
                writer = new FileWriterWithEncoding(((File)(null)) , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),139,writer);
            } catch (NullPointerException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),137,file1.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),138,file1.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_fileName_nullFile() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_fileName_nullFile");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),144,writer);
            try {
                writer = new FileWriterWithEncoding(((String)(null)) , defaultEncoding);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),143,writer);
            } catch (NullPointerException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),141,file1.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),142,file1.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

