package org.apache.commons.io.output;

import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import java.io.IOException;
import org.junit.Test;
import java.nio.charset.UnsupportedCharsetException;
import java.io.Writer;

/** 
 * Tests that files really lock, although no writing is done as
 * the locking is tested only on construction.
 * 
 * @version $Id$
 */
public class LockableFileWriterTest extends FileBasedTestCase {
    private File file;

    private File lockDir;

    private File lockFile;

    private File altLockDir;

    private File altLockFile;

    public LockableFileWriterTest(String name) {
        super(name);
    }

    @Override
    public void setUp() {
        file = new File(FileBasedTestCase.getTestDirectory() , "testlockfile");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),169,file);
        lockDir = new File(java.lang.System.getProperty("java.io.tmpdir"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),170,lockDir);
        lockFile = new File(lockDir , ((file.getName()) + ".lck"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),171,lockFile);
        altLockDir = FileBasedTestCase.getTestDirectory();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),172,altLockDir);
        altLockFile = new File(altLockDir , ((file.getName()) + ".lck"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),173,altLockFile);
    }

    @Override
    public void tearDown() {
        file.delete();
        lockFile.delete();
        altLockFile.delete();
    }

    @Test(timeout = 1000)
    public void testFileLocked() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileLocked");
            LockableFileWriter lfw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,lfw1);
            LockableFileWriter lfw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,lfw2);
            LockableFileWriter lfw3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,lfw3);
            try {
                lfw1 = new LockableFileWriter(file);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,lfw1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,lockFile.exists());
                try {
                    lfw2 = new LockableFileWriter(file);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,lfw2);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,lockFile.exists());
                }
                try {
                    lfw3 = new LockableFileWriter(file);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,lfw3);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,lockFile.exists());
                }
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
                org.apache.commons.io.IOUtils.closeQuietly(lfw3);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFileLocked_add55() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileLocked_add55");
            LockableFileWriter lfw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,lfw1);
            LockableFileWriter lfw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,lfw2);
            LockableFileWriter lfw3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,lfw3);
            try {
                lfw1 = new LockableFileWriter(file);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,lfw1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,lockFile.exists());
                try {
                    lfw2 = new LockableFileWriter(file);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,lfw2);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,lockFile.exists());
                }
                try {
                    lfw3 = new LockableFileWriter(file);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,lfw3);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,lockFile.exists());
                }
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
                org.apache.commons.io.IOUtils.closeQuietly(lfw3);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFileLocked_add56() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileLocked_add56");
            LockableFileWriter lfw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),223,lfw1);
            LockableFileWriter lfw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),224,lfw2);
            LockableFileWriter lfw3 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),225,lfw3);
            try {
                lfw1 = new LockableFileWriter(file);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),220,lfw1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),210,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),211,lockFile.exists());
                try {
                    lfw2 = new LockableFileWriter(file);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,lfw2);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),226,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),212,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),213,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),214,lockFile.exists());
                }
                try {
                    lfw3 = new LockableFileWriter(file);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),222,lfw3);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),227,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),215,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),216,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),217,lockFile.exists());
                }
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
                org.apache.commons.io.IOUtils.closeQuietly(lfw3);
                org.apache.commons.io.IOUtils.closeQuietly(lfw3);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),218,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),219,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAlternateLockDir() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAlternateLockDir");
            LockableFileWriter lfw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,lfw1);
            LockableFileWriter lfw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,lfw2);
            try {
                lfw1 = new LockableFileWriter(file , true , altLockDir.getAbsolutePath());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,lfw1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),175,altLockFile.exists());
                try {
                    lfw2 = new LockableFileWriter(file , true , altLockDir.getAbsolutePath());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,lfw2);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),176,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),177,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,altLockFile.exists());
                }
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,altLockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAlternateLockDir_add49() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAlternateLockDir_add49");
            LockableFileWriter lfw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),183,lfw1);
            LockableFileWriter lfw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,lfw2);
            try {
                lfw1 = new LockableFileWriter(file , true , altLockDir.getAbsolutePath());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,lfw1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),174,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),175,altLockFile.exists());
                try {
                    lfw2 = new LockableFileWriter(file , true , altLockDir.getAbsolutePath());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),182,lfw2);
                } catch (IOException ioe) {
                    String msg = ioe.getMessage();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),185,msg);
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),176,msg.startsWith("Can\'t write file, lock "));
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),177,file.exists());
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,altLockFile.exists());
                }
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),179,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),180,altLockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFileNotLocked() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileNotLocked");
            LockableFileWriter lfw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),238,lfw1);
            try {
                lfw1 = new LockableFileWriter(file);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),236,lfw1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,lockFile.exists());
            LockableFileWriter lfw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),239,lfw2);
            try {
                lfw2 = new LockableFileWriter(file);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),237,lfw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),235,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testFileNotLocked_add58() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testFileNotLocked_add58");
            LockableFileWriter lfw1 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),238,lfw1);
            try {
                lfw1 = new LockableFileWriter(file);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),236,lfw1);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),228,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),229,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw1);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),230,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),231,lockFile.exists());
            LockableFileWriter lfw2 = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),239,lfw2);
            try {
                lfw2 = new LockableFileWriter(file);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),237,lfw2);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),233,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
                org.apache.commons.io.IOUtils.closeQuietly(lfw2);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),235,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_encoding_badEncoding() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,writer);
            try {
                writer = new LockableFileWriter(file , "BAD-ENCODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,writer);
            } catch (UnsupportedCharsetException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_File_encoding_badEncoding_add51() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding_add51");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,writer);
            try {
                writer = new LockableFileWriter(file , "BAD-ENCODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,writer);
            } catch (UnsupportedCharsetException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_encoding_badEncoding_literalMutation138() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding_literalMutation138");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,writer);
            try {
                writer = new LockableFileWriter(file , "BAD-ENCDE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,writer);
            } catch (UnsupportedCharsetException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_encoding_badEncoding_literalMutation139() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding_literalMutation139");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,writer);
            try {
                writer = new LockableFileWriter(file , "BAD-E0NCODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,writer);
            } catch (UnsupportedCharsetException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_encoding_badEncoding_literalMutation140() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_encoding_badEncoding_literalMutation140");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),197,writer);
            try {
                writer = new LockableFileWriter(file , "BAD-ECODE");
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),196,writer);
            } catch (UnsupportedCharsetException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),192,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),194,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),195,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_directory() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_directory");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,writer);
            try {
                writer = new LockableFileWriter(FileBasedTestCase.getTestDirectory());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,writer);
            } catch (IOException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_File_directory_add50() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_directory_add50");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),191,writer);
            try {
                writer = new LockableFileWriter(FileBasedTestCase.getTestDirectory());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),190,writer);
            } catch (IOException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),186,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),187,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),188,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),189,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_File_nullFile() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_nullFile");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,writer);
            try {
                writer = new LockableFileWriter(((File)(null)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,writer);
            } catch (NullPointerException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_File_nullFile_add52() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_File_nullFile_add52");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),203,writer);
            try {
                writer = new LockableFileWriter(((File)(null)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),202,writer);
            } catch (NullPointerException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),198,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),199,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),201,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConstructor_fileName_nullFile() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_fileName_nullFile");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),209,writer);
            try {
                writer = new LockableFileWriter(((String)(null)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),208,writer);
            } catch (NullPointerException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),206,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),207,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testConstructor_fileName_nullFile_add53() throws IOException {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConstructor_fileName_nullFile_add53");
            Writer writer = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),209,writer);
            try {
                writer = new LockableFileWriter(((String)(null)));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),208,writer);
            } catch (NullPointerException ex) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),204,file.exists());
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),205,lockFile.exists());
            } finally {
                org.apache.commons.io.IOUtils.closeQuietly(writer);
                org.apache.commons.io.IOUtils.closeQuietly(writer);
            }
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),206,file.exists());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),207,lockFile.exists());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

