package com.google.gson;

import java.util.HashMap;
import java.util.Map;
import org.junit.Test;
import junit.framework.TestCase;
import java.lang.reflect.Type;
import com.google.gson.reflect.TypeToken;

/** 
 * Unit test for the default JSON map serialization object located in the
 * {@link DefaultTypeAdapters} class.
 * 
 * @author Joel Leitch
 */
public class DefaultMapJsonSerializerTest extends TestCase {
    private Gson gson = new Gson();

    public void testEmptyMapNoTypeSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapNoTypeSerialization");
            Map<java.lang.String, java.lang.String> emptyMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2643,emptyMap);
            JsonElement element = gson.toJsonTree(emptyMap, emptyMap.getClass());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2644,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2641,(element instanceof com.google.gson.JsonObject));
            JsonObject emptyMapJsonObject = ((JsonObject)(element));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2645,emptyMapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2642,emptyMapJsonObject.entrySet().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEmptyMapSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapSerialization");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2648,mapType);
            Map<java.lang.String, java.lang.String> emptyMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2649,emptyMap);
            JsonElement element = gson.toJsonTree(emptyMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2650,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2646,(element instanceof com.google.gson.JsonObject));
            JsonObject emptyMapJsonObject = ((JsonObject)(element));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2651,emptyMapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2647,emptyMapJsonObject.entrySet().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testEmptyMapSerialization_remove469() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMapSerialization_remove469");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2648,mapType);
            Map<java.lang.String, java.lang.String> emptyMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2649,emptyMap);
            JsonElement element = gson.toJsonTree(emptyMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2650,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2646,(element instanceof com.google.gson.JsonObject));
            JsonObject emptyMapJsonObject = ((JsonObject)(element));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2651,emptyMapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2647,emptyMapJsonObject.entrySet().isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNonEmptyMapSerialization_add576() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_add576");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "key1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "value1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNonEmptyMapSerialization_add577() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_add577");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "key1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "value1");
            myMap.put(key, "value1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonEmptyMapSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "ky1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "value1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonEmptyMapSerialization_literalMutation4006() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_literalMutation4006");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "ke0y1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "value1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonEmptyMapSerialization_literalMutation4007() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_literalMutation4007");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "ke1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "value1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonEmptyMapSerialization_literalMutation4008() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_literalMutation4008");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "key1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "v\"lue1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonEmptyMapSerialization_literalMutation4009() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_literalMutation4009");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "key1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "value1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNonEmptyMapSerialization_literalMutation4010() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_literalMutation4010");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "key1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "valu1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNonEmptyMapSerialization_remove470() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_remove470");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "key1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            myMap.put(key, "value1");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNonEmptyMapSerialization_remove471() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNonEmptyMapSerialization_remove471");
            Type mapType = new TypeToken<java.util.Map<java.lang.String, java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2654,mapType);
            Map<java.lang.String, java.lang.String> myMap = new HashMap<java.lang.String, java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2655,myMap);
            String key = "key1";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2656,key);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            JsonElement element = gson.toJsonTree(myMap, mapType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2657,element);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2652,element.isJsonObject());
            JsonObject mapJsonObject = element.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2658,mapJsonObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2653,mapJsonObject.has(key));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

