package com.google.gson;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.util.List;
import java.util.Map;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import org.junit.Test;
import junit.framework.TestCase;
import java.lang.reflect.Type;
import com.google.gson.reflect.TypeToken;

/** 
 * Check that Gson doesn't return non-serializable data types.
 * 
 * @author Jesse Wilson
 */
public final class JavaSerializationTest extends TestCase {
    private final Gson gson = new Gson();

    @Test(timeout = 1000)
    public void testMapIsSerializable_add594() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIsSerializable_add594");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.Integer>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2735,type);
            Map<java.lang.String, java.lang.Integer> map = gson.fromJson("{\"b\":1,\"c\":2,\"a\":3}", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2736,map);
            Map<java.lang.String, java.lang.Integer> serialized = serializedCopy(map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2737,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2731,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2732,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2733,java.util.Arrays.asList("b", "c", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2734,new java.util.ArrayList<java.lang.String>(serialized.keySet()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIsSerializable() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIsSerializable");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.Integer>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2735,type);
            Map<java.lang.String, java.lang.Integer> map = gson.fromJson("{\"b\":1,\".\":2,\"a\":3}", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2736,map);
            Map<java.lang.String, java.lang.Integer> serialized = serializedCopy(map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2737,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2731,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2732,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2733,java.util.Arrays.asList("b", "c", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2734,new java.util.ArrayList<java.lang.String>(serialized.keySet()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIsSerializable_literalMutation4094() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIsSerializable_literalMutation4094");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.Integer>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2735,type);
            Map<java.lang.String, java.lang.Integer> map = gson.fromJson("{\"b\":1,\"c\":2,\"a\":3}", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2736,map);
            Map<java.lang.String, java.lang.Integer> serialized = serializedCopy(map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2737,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2731,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2732,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2733,java.util.Arrays.asList("b", "c", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2734,new java.util.ArrayList<java.lang.String>(serialized.keySet()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testMapIsSerializable_literalMutation4095() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIsSerializable_literalMutation4095");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.Integer>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2735,type);
            Map<java.lang.String, java.lang.Integer> map = gson.fromJson("{\"b\":1\"c\":2,\"a\":3}", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2736,map);
            Map<java.lang.String, java.lang.Integer> serialized = serializedCopy(map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2737,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2731,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2732,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2733,java.util.Arrays.asList("b", "c", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2734,new java.util.ArrayList<java.lang.String>(serialized.keySet()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testMapIsSerializable_remove485() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapIsSerializable_remove485");
            Type type = new TypeToken<java.util.Map<java.lang.String, java.lang.Integer>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2735,type);
            Map<java.lang.String, java.lang.Integer> map = gson.fromJson("{\"b\":1,\"c\":2,\"a\":3}", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2736,map);
            Map<java.lang.String, java.lang.Integer> serialized = serializedCopy(map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2737,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2731,map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2732,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2733,java.util.Arrays.asList("b", "c", "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2734,new java.util.ArrayList<java.lang.String>(serialized.keySet()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testListIsSerializable_add593() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListIsSerializable_add593");
            Type type = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2728,type);
            List<java.lang.String> list = gson.fromJson("[\"a\",\"b\",\"c\"]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2729,list);
            List<java.lang.String> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2730,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2726,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2727,serialized);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListIsSerializable() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListIsSerializable");
            Type type = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2728,type);
            List<java.lang.String> list = gson.fromJson("a\"a\",\"b\",\"c\"]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2729,list);
            List<java.lang.String> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2730,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2726,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2727,serialized);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListIsSerializable_literalMutation4091() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListIsSerializable_literalMutation4091");
            Type type = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2728,type);
            List<java.lang.String> list = gson.fromJson("[\"a\",\"b\",¢\"c\"]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2729,list);
            List<java.lang.String> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2730,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2726,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2727,serialized);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testListIsSerializable_literalMutation4092() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListIsSerializable_literalMutation4092");
            Type type = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2728,type);
            List<java.lang.String> list = gson.fromJson("[\"a\",\"b\",\"c]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2729,list);
            List<java.lang.String> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2730,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2726,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2727,serialized);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testListIsSerializable_remove484() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testListIsSerializable_remove484");
            Type type = new TypeToken<java.util.List<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2728,type);
            List<java.lang.String> list = gson.fromJson("[\"a\",\"b\",\"c\"]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2729,list);
            List<java.lang.String> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2730,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2726,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2727,serialized);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNumberIsSerializable_add595() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNumberIsSerializable_add595");
            Type type = new TypeToken<java.util.List<java.lang.Number>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2458,type);
            List<java.lang.Number> list = gson.fromJson("[1,3.14,6.673e-11]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2741,list);
            List<java.lang.Number> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2742,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2738,serialized.get(0).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2739,serialized.get(1).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2740,serialized.get(2).doubleValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNumberIsSerializable() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNumberIsSerializable");
            Type type = new TypeToken<java.util.List<java.lang.Number>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2458,type);
            List<java.lang.Number> list = gson.fromJson("[1,3å14,6.673e-11]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2741,list);
            List<java.lang.Number> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2742,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2738,serialized.get(0).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2739,serialized.get(1).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2740,serialized.get(2).doubleValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNumberIsSerializable_literalMutation4097() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNumberIsSerializable_literalMutation4097");
            Type type = new TypeToken<java.util.List<java.lang.Number>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2458,type);
            List<java.lang.Number> list = gson.fromJson("[E1,3.14,6.673e-11]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2741,list);
            List<java.lang.Number> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2742,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2738,serialized.get(0).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2739,serialized.get(1).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2740,serialized.get(2).doubleValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNumberIsSerializable_literalMutation4098() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNumberIsSerializable_literalMutation4098");
            Type type = new TypeToken<java.util.List<java.lang.Number>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2458,type);
            List<java.lang.Number> list = gson.fromJson("[1,.14,6.673e-11]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2741,list);
            List<java.lang.Number> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2742,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2738,serialized.get(0).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2739,serialized.get(1).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2740,serialized.get(2).doubleValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNumberIsSerializable_remove486() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNumberIsSerializable_remove486");
            Type type = new TypeToken<java.util.List<java.lang.Number>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2458,type);
            List<java.lang.Number> list = gson.fromJson("[1,3.14,6.673e-11]", type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2741,list);
            List<java.lang.Number> serialized = serializedCopy(list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2742,serialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2738,serialized.get(0).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2739,serialized.get(1).doubleValue());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2740,serialized.get(2).doubleValue());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unchecked")
    private <T>T serializedCopy(T object) throws IOException, ClassNotFoundException {
        ByteArrayOutputStream bytesOut = new ByteArrayOutputStream();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2722,bytesOut);
        ObjectOutputStream out = new ObjectOutputStream(bytesOut);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2723,out);
        out.writeObject(object);
        out.close();
        ByteArrayInputStream bytesIn = new ByteArrayInputStream(bytesOut.toByteArray());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2724,bytesIn);
        ObjectInputStream in = new ObjectInputStream(bytesIn);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2725,in);
        return ((T)(in.readObject()));
    }
}

