package com.google.gson;

import java.io.IOException;
import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import junit.framework.TestCase;

/** 
 * @author Jesse Wilson
 */
public class OverrideCoreTypeAdaptersTest extends TestCase {
    private static final TypeAdapter<java.lang.Boolean> booleanAsIntAdapter = new TypeAdapter<java.lang.Boolean>() {
        @Override
        public void write(JsonWriter out, Boolean value) throws IOException {
            out.value((value ? 1 : 0));
        }

        @Override
        public Boolean read(JsonReader in) throws IOException {
            int value = in.nextInt();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2916,value);
            return value != 0;
        }
    };

    private static final TypeAdapter<java.lang.String> swapCaseStringAdapter = new TypeAdapter<java.lang.String>() {
        @Override
        public void write(JsonWriter out, String value) throws IOException {
            out.value(value.toUpperCase(java.util.Locale.US));
        }

        @Override
        public String read(JsonReader in) throws IOException {
            return in.nextString().toLowerCase(java.util.Locale.US);
        }
    };

    public void testOverrideWrapperBooleanAdapter() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testOverrideWrapperBooleanAdapter");
            Gson gson = new GsonBuilder().registerTypeAdapter(Boolean.class, booleanAsIntAdapter).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2695,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2927,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2928,gson.toJson(true, java.lang.Boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2929,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2930,gson.fromJson("true", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2931,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2932,gson.fromJson("1", java.lang.Boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2933,java.lang.Boolean.FALSE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2934,gson.fromJson("0", java.lang.Boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testOverridePrimitiveBooleanAdapter() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testOverridePrimitiveBooleanAdapter");
            Gson gson = new GsonBuilder().registerTypeAdapter(boolean.class, booleanAsIntAdapter).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1458,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2917,gson.toJson(true, boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2918,gson.toJson(true, java.lang.Boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2919,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2920,gson.fromJson("1", boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2921,java.lang.Boolean.TRUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2922,gson.fromJson("true", java.lang.Boolean.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2923,gson.toJson(false, boolean.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testOverrideStringAdapter() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testOverrideStringAdapter");
            Gson gson = new GsonBuilder().registerTypeAdapter(String.class, swapCaseStringAdapter).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2926,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2924,gson.toJson("Hello", java.lang.String.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2925,gson.fromJson("\"Hello\"", java.lang.String.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

