package com.google.gson;

import com.google.gson.internal.Excluder;
import com.google.gson.annotations.Since;
import junit.framework.TestCase;

/** 
 * Unit tests for the {@link Excluder} class.
 * 
 * @author Joel Leitch
 */
public class VersionExclusionStrategyTest extends TestCase {
    private static final double VERSION = 5.0;

    public void testClassAndFieldAreAtSameVersion() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassAndFieldAreAtSameVersion");
            Excluder excluder = Excluder.DEFAULT.withVersion(VERSION);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2960,excluder);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2958,excluder.excludeClass(com.google.gson.VersionExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2959,excluder.excludeField(com.google.gson.VersionExclusionStrategyTest.MockObject.class.getField("someField"), true));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassAndFieldAreBehindInVersion() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassAndFieldAreBehindInVersion");
            Excluder excluder = Excluder.DEFAULT.withVersion(((VERSION) + 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2963,excluder);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2961,excluder.excludeClass(com.google.gson.VersionExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2962,excluder.excludeField(com.google.gson.VersionExclusionStrategyTest.MockObject.class.getField("someField"), true));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassAndFieldAreBehindInVersion_literalMutation4244() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassAndFieldAreBehindInVersion_literalMutation4244");
            Excluder excluder = Excluder.DEFAULT.withVersion(((VERSION) + 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2963,excluder);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2961,excluder.excludeClass(com.google.gson.VersionExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2962,excluder.excludeField(com.google.gson.VersionExclusionStrategyTest.MockObject.class.getField("someField"), true));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassAndFieldAreBehindInVersion_literalMutation4245() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassAndFieldAreBehindInVersion_literalMutation4245");
            Excluder excluder = Excluder.DEFAULT.withVersion(((VERSION) + 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2963,excluder);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2961,excluder.excludeClass(com.google.gson.VersionExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2962,excluder.excludeField(com.google.gson.VersionExclusionStrategyTest.MockObject.class.getField("someField"), true));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassAndFieldAreAheadInVersion() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassAndFieldAreAheadInVersion");
            Excluder excluder = Excluder.DEFAULT.withVersion(((VERSION) - 2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2957,excluder);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2955,excluder.excludeClass(com.google.gson.VersionExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2956,excluder.excludeField(com.google.gson.VersionExclusionStrategyTest.MockObject.class.getField("someField"), true));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassAndFieldAreAheadInVersion_literalMutation4240() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassAndFieldAreAheadInVersion_literalMutation4240");
            Excluder excluder = Excluder.DEFAULT.withVersion(((VERSION) - 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2957,excluder);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2955,excluder.excludeClass(com.google.gson.VersionExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2956,excluder.excludeField(com.google.gson.VersionExclusionStrategyTest.MockObject.class.getField("someField"), true));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassAndFieldAreAheadInVersion_literalMutation4241() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassAndFieldAreAheadInVersion_literalMutation4241");
            Excluder excluder = Excluder.DEFAULT.withVersion(((VERSION) - 0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2957,excluder);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2955,excluder.excludeClass(com.google.gson.VersionExclusionStrategyTest.MockObject.class, true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2956,excluder.excludeField(com.google.gson.VersionExclusionStrategyTest.MockObject.class.getField("someField"), true));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Since(value = VersionExclusionStrategyTest.VERSION)
    private static class MockObject {
        @Since(value = VersionExclusionStrategyTest.VERSION)
        public final int someField = 0;
    }
}

