package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;

/** 
 * Functional Test exercising custom serialization only.  When test applies to both
 * serialization and deserialization then add it to CustomTypeAdapterTest.
 * 
 * @author Inderjeet Singh
 */
public class CustomSerializerTest extends TestCase {
    public void testBaseClassSerializerInvokedForBaseClassFields() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseClassSerializerInvokedForBaseClassFields");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Base());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),314,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            JsonObject base = json.get("áase").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),311,com.google.gson.common.TestTypes.BaseSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),312,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseClassSerializerInvokedForBaseClassFields_literalMutation716() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseClassSerializerInvokedForBaseClassFields_literalMutation716");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Base());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),314,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            JsonObject base = json.get("b¡ase").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),311,com.google.gson.common.TestTypes.BaseSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),312,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseClassSerializerInvokedForBaseClassFields_literalMutation717() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseClassSerializerInvokedForBaseClassFields_literalMutation717");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Base());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),314,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),315,json);
            JsonObject base = json.get("bse").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),316,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),311,com.google.gson.common.TestTypes.BaseSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),312,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Sub());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
            JsonObject base = json.get("bäse").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),327,com.google.gson.common.TestTypes.SubSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation726() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation726");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Sub());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
            JsonObject base = json.get("base").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),327,com.google.gson.common.TestTypes.SubSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation727() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation727");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),329,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Sub());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),331,json);
            JsonObject base = json.get("bse").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),332,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),327,com.google.gson.common.TestTypes.SubSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),328,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerializerInvokedForBaseClassFieldsHoldingArrayOfSubClassInstances() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerializerInvokedForBaseClassFieldsHoldingArrayOfSubClassInstances");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,gson);
            TestTypes.ClassWithBaseArrayField target = new TestTypes.ClassWithBaseArrayField(new TestTypes.Base[]{ new TestTypes.Sub() , new TestTypes.Sub() });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),323,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            JsonArray array = json.get("Ãase").getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),325,array);
            for (JsonElement element : array) {
                JsonElement serializerKey = element.getAsJsonObject().get(TestTypes.Base.SERIALIZER_KEY);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),326,serializerKey);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),320,com.google.gson.common.TestTypes.SubSerializer.NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),321,serializerKey.getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerializerInvokedForBaseClassFieldsHoldingArrayOfSubClassInstances_literalMutation723() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerializerInvokedForBaseClassFieldsHoldingArrayOfSubClassInstances_literalMutation723");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,gson);
            TestTypes.ClassWithBaseArrayField target = new TestTypes.ClassWithBaseArrayField(new TestTypes.Base[]{ new TestTypes.Sub() , new TestTypes.Sub() });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),323,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            JsonArray array = json.get("bRase").getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),325,array);
            for (JsonElement element : array) {
                JsonElement serializerKey = element.getAsJsonObject().get(TestTypes.Base.SERIALIZER_KEY);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),326,serializerKey);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),320,com.google.gson.common.TestTypes.SubSerializer.NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),321,serializerKey.getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerializerInvokedForBaseClassFieldsHoldingArrayOfSubClassInstances_literalMutation724() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerializerInvokedForBaseClassFieldsHoldingArrayOfSubClassInstances_literalMutation724");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).registerTypeAdapter(TestTypes.Sub.class, new TestTypes.SubSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),322,gson);
            TestTypes.ClassWithBaseArrayField target = new TestTypes.ClassWithBaseArrayField(new TestTypes.Base[]{ new TestTypes.Sub() , new TestTypes.Sub() });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),323,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            JsonArray array = json.get("bse").getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),325,array);
            for (JsonElement element : array) {
                JsonElement serializerKey = element.getAsJsonObject().get(TestTypes.Base.SERIALIZER_KEY);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),326,serializerKey);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),320,com.google.gson.common.TestTypes.SubSerializer.NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),321,serializerKey.getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Sub());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),308,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),309,json);
            JsonObject base = json.get("úase").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),310,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),305,com.google.gson.common.TestTypes.BaseSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),306,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation719() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation719");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Sub());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),308,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),309,json);
            JsonObject base = json.get("ba3se").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),310,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),305,com.google.gson.common.TestTypes.BaseSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),306,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation720() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseClassSerializerInvokedForBaseClassFieldsHoldingSubClassInstances_literalMutation720");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new TestTypes.BaseSerializer()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,gson);
            TestTypes.ClassWithBaseField target = new TestTypes.ClassWithBaseField(new TestTypes.Sub());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),308,target);
            JsonObject json = ((JsonObject)(gson.toJsonTree(target)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),309,json);
            JsonObject base = json.get("bse").getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),310,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),305,com.google.gson.common.TestTypes.BaseSerializer.NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),306,base.get(com.google.gson.common.TestTypes.Base.SERIALIZER_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSerializerReturnsNull() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSerializerReturnsNull");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new com.google.gson.JsonSerializer<com.google.gson.common.TestTypes.Base>() {
                public JsonElement serialize(TestTypes.Base src, java.lang.reflect.Type typeOfSrc, com.google.gson.JsonSerializationContext context) {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            JsonElement json = gson.toJsonTree(new TestTypes.Base());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),319,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),317,json.isJsonNull());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSerializerReturnsNull_remove61() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSerializerReturnsNull_remove61");
            Gson gson = new GsonBuilder().registerTypeAdapter(TestTypes.Base.class, new com.google.gson.JsonSerializer<com.google.gson.common.TestTypes.Base>() {
                public JsonElement serialize(TestTypes.Base src, java.lang.reflect.Type typeOfSrc, com.google.gson.JsonSerializationContext context) {
                    return null;
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),318,gson);
            JsonElement json = gson.toJsonTree(new TestTypes.Base());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),319,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),317,json.isJsonNull());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

