package com.google.gson.functional;

import java.lang.annotation.ElementType;
import com.google.gson.ExclusionStrategy;
import com.google.gson.FieldAttributes;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonObject;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
import org.junit.Test;
import junit.framework.TestCase;

/** 
 * Performs some functional tests when Gson is instantiated with some common user defined
 * {@link ExclusionStrategy} objects.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class ExclusionStrategyFunctionalTest extends TestCase {
    private static final ExclusionStrategy EXCLUDE_SAMPLE_OBJECT_FOR_TEST = new ExclusionStrategy() {
        public boolean shouldSkipField(FieldAttributes f) {
            return false;
        }

        public boolean shouldSkipClass(Class<?> clazz) {
            return clazz == (SampleObjectForTest.class);
        }
    };

    private SampleObjectForTest src;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        src = new SampleObjectForTest();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),852,src);
    }

    public void testExclusionStrategySerializationDoesNotImpactDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategySerializationDoesNotImpactDeserialization");
            String json = "{\"annotatedField\":1,\"stringField\":\"x\",\"longField\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,gson);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,value.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,value.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,value.longField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategySerialization");
            String json = "{\"annotatedField\":1,\"stréngField\":\"x\",\"longField\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,gson);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,value.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,value.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,value.longField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategySerializationDoesNotImpactDeserialization_literalMutation1383() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategySerializationDoesNotImpactDeserialization_literalMutation1383");
            String json = "{\"annotatedField\":1,\"stringField\":\"x\",\"longFi½eld\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,gson);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,value.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,value.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,value.longField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategySerializationDoesNotImpactDeserialization_literalMutation1384() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategySerializationDoesNotImpactDeserialization_literalMutation1384");
            String json = "{\"annotatedField\":1,\"stringield\":\"x\",\"longField\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),879,gson);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),880,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),875,value.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),876,value.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),877,value.longField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExclusionStrategyDeserialization_add184() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_add184");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExclusionStrategyDeserialization_add185() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_add185");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExclusionStrategyDeserialization_add186() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_add186");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1359() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1359");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("an¡otatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1360() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1360");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1361() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1361");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annoatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1362() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1362");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 4)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1363() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1363");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 2)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1364() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1364");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 10)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1365() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1365");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 6)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1367() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1367");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringFeld", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1368() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1368");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringFieôld", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1369() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1369");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringFied", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1370() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1370");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,lah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1371() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1371");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,Xblah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1372() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1372");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,bah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1373() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1373");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longFild", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1374() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1374");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("lonêgField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1375() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1375");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("lonField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1376() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1376");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212310L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1377() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1377");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(606155L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1378() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1378");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(2424622L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyDeserialization_literalMutation1379() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_literalMutation1379");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("annotatedField", new com.google.gson.JsonPrimitive(((src.annotatedField) + 5)));
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212312L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExclusionStrategyDeserialization_remove174() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_remove174");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExclusionStrategyDeserialization_remove175() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_remove175");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testExclusionStrategyDeserialization_remove176() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyDeserialization_remove176");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            JsonObject json = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            json.add("stringField", new com.google.gson.JsonPrimitive(((src.stringField) + "blah,blah")));
            json.add("longField", new com.google.gson.JsonPrimitive(1212311L));
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),874,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),867,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),868,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),869,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),870,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),871,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategySerializationDoesNotImpactSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategySerializationDoesNotImpactSerialization");
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),348,gson);
            String json = gson.toJson(src);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),884,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),881,json.contains("\"stringField\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),882,json.contains("\"annotatedField\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),883,json.contains("\"longField\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 4) , ((src.stringField) + "blah,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1388() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1388");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 2) , ((src.stringField) + "blah,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1389() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1389");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 10) , ((src.stringField) + "blah,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1390() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1390");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 6) , ((src.stringField) + "blah,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1392() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1392");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "bla~,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1393() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1393");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "bla\'h,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1394() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1394");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "bla,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1395() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1395");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "blah,blah") , ((src.longField) + 656L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1396() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1396");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "blah,blah") , ((src.longField) + 654L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1397() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1397");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "blah,blah") , ((src.longField) + 327L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1398() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1398");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "blah,blah") , ((src.longField) + 1310L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExclusionStrategyWithMode_literalMutation1400() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExclusionStrategyWithMode_literalMutation1400");
            SampleObjectForTest testObj = new SampleObjectForTest(((src.annotatedField) + 5) , ((src.stringField) + "blah,blah") , ((src.longField) + 655L));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),897,testObj);
            Gson gson = ExclusionStrategyFunctionalTest.createGson(new MyExclusionStrategy(String.class), true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),898,gson);
            JsonObject json = gson.toJsonTree(testObj).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),344,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),885,testObj.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),886,json.get("annotatedField").getAsInt());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),887,testObj.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),888,json.get("stringField").getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),889,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),890,json.get("longField").getAsLong());
            SampleObjectForTest target = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),891,testObj.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),892,target.longField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),893,src.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),894,target.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),895,src.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),896,target.stringField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeTopLevelClassSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeTopLevelClassSerialization");
            Gson gson = new GsonBuilder().addSerializationExclusionStrategy(EXCLUDE_SAMPLE_OBJECT_FOR_TEST).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            String json = "{\"annotatedField\":1,\"stringField\":\"x\",\"longFieäd\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),73,json);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,value.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,value.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,value.longField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeTopLevelClassSerializationDoesNotImpactDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeTopLevelClassSerializationDoesNotImpactDeserialization");
            Gson gson = new GsonBuilder().addSerializationExclusionStrategy(EXCLUDE_SAMPLE_OBJECT_FOR_TEST).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            String json = "{\"annotatedField\":1,\"stri¤ngField\":\"x\",\"longField\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),73,json);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,value.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,value.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,value.longField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeTopLevelClassSerializationDoesNotImpactDeserialization_literalMutation1357() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeTopLevelClassSerializationDoesNotImpactDeserialization_literalMutation1357");
            Gson gson = new GsonBuilder().addSerializationExclusionStrategy(EXCLUDE_SAMPLE_OBJECT_FOR_TEST).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            String json = "{\"annotateField\":1,\"stringField\":\"x\",\"longField\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),73,json);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),866,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),862,value.annotatedField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),863,value.stringField);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),864,value.longField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeTopLevelClassDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeTopLevelClassDeserialization");
            Gson gson = new GsonBuilder().addDeserializationExclusionStrategy(EXCLUDE_SAMPLE_OBJECT_FOR_TEST).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,gson);
            String json = "{\"annotatedField\":1,\"stringField:\"x\",\"longField\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,json);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeTopLevelClassDeserialization_literalMutation1353() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeTopLevelClassDeserialization_literalMutation1353");
            Gson gson = new GsonBuilder().addDeserializationExclusionStrategy(EXCLUDE_SAMPLE_OBJECT_FOR_TEST).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,gson);
            String json = "{\"annotatedField\":)1,\"stringField\":\"x\",\"longField\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,json);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeTopLevelClassDeserialization_literalMutation1354() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeTopLevelClassDeserialization_literalMutation1354");
            Gson gson = new GsonBuilder().addDeserializationExclusionStrategy(EXCLUDE_SAMPLE_OBJECT_FOR_TEST).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),859,gson);
            String json = "{\"annotatedField\":1,\"stringField\":\"x\",\"longFild\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,json);
            SampleObjectForTest value = gson.fromJson(json, SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),861,value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),858,value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExcludeTopLevelClassDeserializationDoesNotImpactSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExcludeTopLevelClassDeserializationDoesNotImpactSerialization");
            Gson gson = new GsonBuilder().addDeserializationExclusionStrategy(EXCLUDE_SAMPLE_OBJECT_FOR_TEST).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),856,gson);
            String json = gson.toJson(new SampleObjectForTest(), SampleObjectForTest.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),857,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),853,json.contains("\"stringField\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),854,json.contains("\"annotatedField\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),855,json.contains("\"longField\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static Gson createGson(ExclusionStrategy exclusionStrategy, boolean serialization) {
        GsonBuilder gsonBuilder = new GsonBuilder();
        if (serialization) {
            gsonBuilder.addSerializationExclusionStrategy(exclusionStrategy);
        } else {
            gsonBuilder.addDeserializationExclusionStrategy(exclusionStrategy);
        }
        return gsonBuilder.serializeNulls().create();
    }

    @Retention(value = RetentionPolicy.RUNTIME)
    @Target(value = { ElementType.FIELD })
    private static @interface Foo {    }

    private static class SampleObjectForTest {
        @Foo
        private final int annotatedField;

        private final String stringField;

        private final long longField;

        public SampleObjectForTest() {
            this(5, "someDefaultValue", 12345L);
        }

        public SampleObjectForTest(int annotatedField ,String stringField ,long longField) {
            this.annotatedField = annotatedField;
            this.stringField = stringField;
            this.longField = longField;
        }
    }

    private static class MyExclusionStrategy implements ExclusionStrategy {
        private final Class<?> typeToSkip;

        private MyExclusionStrategy(Class<?> typeToSkip) {
            this.typeToSkip = typeToSkip;
        }

        public boolean shouldSkipClass(Class<?> clazz) {
            return clazz == (typeToSkip);
        }

        public boolean shouldSkipField(FieldAttributes f) {
            return (f.getAnnotation(Foo.class)) != null;
        }
    }
}

