package com.google.gson.functional;

import com.google.gson.annotations.Expose;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.InstanceCreator;
import junit.framework.TestCase;
import java.lang.reflect.Type;

/** 
 * Unit tests for the regarding functional "@Expose" type tests.
 * 
 * @author Joel Leitch
 */
public class ExposeFieldsTest extends TestCase {
    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new GsonBuilder().excludeFieldsWithoutExposeAnnotation().registerTypeAdapter(SomeInterface.class, new SomeInterfaceInstanceCreator()).create();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),901,gson);
    }

    public void testNullExposeFieldSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullExposeFieldSerialization");
            ClassWithExposedFields object = new ClassWithExposedFields(null , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),933,object);
            String json = gson.toJson(object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),934,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),931,object.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),932,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullExposeFieldSerialization_literalMutation1448() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullExposeFieldSerialization_literalMutation1448");
            ClassWithExposedFields object = new ClassWithExposedFields(null , 0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),933,object);
            String json = gson.toJson(object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),934,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),931,object.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),932,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullExposeFieldSerialization_literalMutation1449() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullExposeFieldSerialization_literalMutation1449");
            ClassWithExposedFields object = new ClassWithExposedFields(null , 0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),933,object);
            String json = gson.toJson(object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),934,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),931,object.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),932,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization");
            ClassWithExposedFields object1 = new ClassWithExposedFields(2 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1402() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1402");
            ClassWithExposedFields object1 = new ClassWithExposedFields(0 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1403() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1403");
            ClassWithExposedFields object1 = new ClassWithExposedFields(0 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1405() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1405");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1406() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1406");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1407() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1407");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1410() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1410");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1411() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1411");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1412() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1412");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 0);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1414() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1414");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(1 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1415() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1415");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(4 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1416() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1416");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(3 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1418() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1418");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1419() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1419");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1420() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayWithOneNullExposeFieldObjectSerialization_literalMutation1420");
            ClassWithExposedFields object1 = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),904,object1);
            ClassWithExposedFields object2 = new ClassWithExposedFields(null , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),905,object2);
            ClassWithExposedFields object3 = new ClassWithExposedFields(2 , 3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),906,object3);
            ClassWithExposedFields[] objects = new ClassWithExposedFields[]{ object1 , object2 , object3 };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),907,objects);
            String json = gson.toJson(objects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),908,json);
            String expected = new StringBuilder().append('[').append(object1.getExpectedJson()).append(',').append(object2.getExpectedJson()).append(',').append(object3.getExpectedJson()).append(']').toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),909,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),902,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),903,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationSerialization");
            ClassWithExposedFields target = new ClassWithExposedFields(2 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),913,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),914,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationSerialization_literalMutation1430() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationSerialization_literalMutation1430");
            ClassWithExposedFields target = new ClassWithExposedFields(0 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),913,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),914,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationSerialization_literalMutation1431() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationSerialization_literalMutation1431");
            ClassWithExposedFields target = new ClassWithExposedFields(0 , 2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),913,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),914,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationSerialization_literalMutation1433() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationSerialization_literalMutation1433");
            ClassWithExposedFields target = new ClassWithExposedFields(1 , 1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),913,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),914,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationSerialization_literalMutation1434() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationSerialization_literalMutation1434");
            ClassWithExposedFields target = new ClassWithExposedFields(1 , 4);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),913,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),914,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationSerialization_literalMutation1435() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationSerialization_literalMutation1435");
            ClassWithExposedFields target = new ClassWithExposedFields(1 , 3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),915,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),913,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),914,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationDeserialization");
            String json = "{a:3,b:4,do20.0}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            ClassWithExposedFields target = gson.fromJson(json, ClassWithExposedFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),910,((int)(target.a)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),911,target.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),912,((target.d) == 20));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationDeserialization_literalMutation1427() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationDeserialization_literalMutation1427");
            String json = "{a:3,b:4,d:20j.0}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            ClassWithExposedFields target = gson.fromJson(json, ClassWithExposedFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),910,((int)(target.a)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),911,target.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),912,((target.d) == 20));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposeAnnotationDeserialization_literalMutation1428() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposeAnnotationDeserialization_literalMutation1428");
            String json = "{a:3,b:4,d:0.0}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),873,json);
            ClassWithExposedFields target = gson.fromJson(json, ClassWithExposedFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),910,((int)(target.a)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),911,target.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),912,((target.d) == 20));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNoExposedFieldSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNoExposedFieldSerialization");
            ClassWithNoExposedFields obj = new ClassWithNoExposedFields();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),929,obj);
            String json = gson.toJson(obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),930,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),928,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNoExposedFieldDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNoExposedFieldDeserialization");
            String json = "{a:W,b:5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),926,json);
            ClassWithNoExposedFields obj = gson.fromJson(json, ClassWithNoExposedFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),927,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),924,obj.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),925,obj.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNoExposedFieldDeserialization_literalMutation1444() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNoExposedFieldDeserialization_literalMutation1444");
            String json = "{a:4,b:5}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),926,json);
            ClassWithNoExposedFields obj = gson.fromJson(json, ClassWithNoExposedFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),927,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),924,obj.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),925,obj.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNoExposedFieldDeserialization_literalMutation1445() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNoExposedFieldDeserialization_literalMutation1445");
            String json = "{a:4,b:}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),926,json);
            ClassWithNoExposedFields obj = gson.fromJson(json, ClassWithNoExposedFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),927,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),924,obj.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),925,obj.b);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposedInterfaceFieldSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposedInterfaceFieldSerialization");
            String expected = "{\"interfaeField\":{}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),921,expected);
            ClassWithInterfaceField target = new ClassWithInterfaceField(new SomeObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),922,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),923,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),919,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),920,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposedInterfaceFieldSerialization_literalMutation1441() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposedInterfaceFieldSerialization_literalMutation1441");
            String expected = "{\"interface÷Field\":{}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),921,expected);
            ClassWithInterfaceField target = new ClassWithInterfaceField(new SomeObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),922,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),923,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),919,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),920,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposedInterfaceFieldSerialization_literalMutation1442() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposedInterfaceFieldSerialization_literalMutation1442");
            String expected = "{\"interfaceField\":{}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),921,expected);
            ClassWithInterfaceField target = new ClassWithInterfaceField(new SomeObject());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),922,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),923,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),919,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),920,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposedInterfaceFieldDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposedInterfaceFieldDeserialization");
            String json = "{\"£nterfaceField\":{}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),917,json);
            ClassWithInterfaceField obj = gson.fromJson(json, ClassWithInterfaceField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),918,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),916,obj.interfaceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposedInterfaceFieldDeserialization_literalMutation1438() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposedInterfaceFieldDeserialization_literalMutation1438");
            String json = "{\"interfaceF#ield\":{}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),917,json);
            ClassWithInterfaceField obj = gson.fromJson(json, ClassWithInterfaceField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),918,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),916,obj.interfaceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testExposedInterfaceFieldDeserialization_literalMutation1439() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testExposedInterfaceFieldDeserialization_literalMutation1439");
            String json = "{\"interfaceField\":{}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),917,json);
            ClassWithInterfaceField obj = gson.fromJson(json, ClassWithInterfaceField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),918,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),916,obj.interfaceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithExposedFields {
        @Expose
        private final Integer a;

        private final Integer b;

        @Expose(serialize = false)
        final long c;

        @Expose(deserialize = false)
        final double d;

        @Expose(deserialize = false, serialize = false)
        final char e;

        public ClassWithExposedFields(Integer a ,Integer b) {
            this(a, b, 1L, 2.0, 'a');
        }

        public ClassWithExposedFields(Integer a ,Integer b ,long c ,double d ,char e) {
            this.a = a;
            this.b = b;
            this.c = c;
            this.d = d;
            this.e = e;
        }

        public String getExpectedJson() {
            StringBuilder sb = new StringBuilder("{");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),900,sb);
            if ((a) != null) {
                sb.append("\"a\":").append(a).append(",");
            } 
            sb.append("\"d\":").append(d);
            sb.append("}");
            return sb.toString();
        }
    }

    private static class ClassWithNoExposedFields {
        private final int a = 0;

        private final int b = 1;
    }

    private static interface SomeInterface {    }

    private static class SomeObject implements SomeInterface {    }

    private static class SomeInterfaceInstanceCreator implements InstanceCreator<SomeInterface> {
        public SomeInterface createInstance(Type type) {
            return new SomeObject();
        }
    }

    private static class ClassWithInterfaceField {
        @Expose
        private final SomeInterface interfaceField;

        public ClassWithInterfaceField(SomeInterface interfaceField) {
            this.interfaceField = interfaceField;
        }
    }
}

