package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.annotations.SerializedName;
import junit.framework.TestCase;

public final class FieldNamingTest extends TestCase {
    public void testIdentity() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIdentity");
            Gson gson = new GsonBuilder().setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.IDENTITY).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),958,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),956,("{\'lowerCamel\':1,\'UpperCamel\':2,\'_lowerCamelLeadingUnderscore\':3," + ("\'_UpperCamelLeadingUnderscore\':4,\'lower_words\':5,\'UPPER_WORDS\':6," + "\'annotatedName\':7}")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),957,gson.toJson(new com.google.gson.functional.FieldNamingTest.TestNames()).replace('\"', '\''));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUpperCamelCase() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUpperCamelCase");
            Gson gson = new GsonBuilder().setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),966,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),964,("{\'LowerCamel\':1,\'UpperCamel\':2,\'_LowerCamelLeadingUnderscore\':3," + ("\'_UpperCamelLeadingUnderscore\':4,\'Lower_words\':5,\'UPPER_WORDS\':6," + "\'annotatedName\':7}")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),965,gson.toJson(new com.google.gson.functional.FieldNamingTest.TestNames()).replace('\"', '\''));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUpperCamelCaseWithSpaces() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUpperCamelCaseWithSpaces");
            Gson gson = new GsonBuilder().setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE_WITH_SPACES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),969,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),967,("{\'Lower Camel\':1,\'Upper Camel\':2,\'_Lower Camel Leading Underscore\':3," + ("\'_ Upper Camel Leading Underscore\':4,\'Lower_words\':5,\'U P P E R_ W O R D S\':6," + "\'annotatedName\':7}")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),968,gson.toJson(new com.google.gson.functional.FieldNamingTest.TestNames()).replace('\"', '\''));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLowerCaseWithUnderscores() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLowerCaseWithUnderscores");
            Gson gson = new GsonBuilder().setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_UNDERSCORES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),954,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),962,("{\'lower_camel\':1,\'upper_camel\':2,\'_lower_camel_leading_underscore\':3," + ("\'__upper_camel_leading_underscore\':4,\'lower_words\':5,\'u_p_p_e_r__w_o_r_d_s\':6," + "\'annotatedName\':7}")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),963,gson.toJson(new com.google.gson.functional.FieldNamingTest.TestNames()).replace('\"', '\''));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLowerCaseWithDashes() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLowerCaseWithDashes");
            Gson gson = new GsonBuilder().setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_DASHES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),961,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),959,("{\'lower-camel\':1,\'upper-camel\':2,\'_lower-camel-leading-underscore\':3," + ("\'_-upper-camel-leading-underscore\':4,\'lower_words\':5,\'u-p-p-e-r_-w-o-r-d-s\':6," + "\'annotatedName\':7}")));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),960,gson.toJson(new com.google.gson.functional.FieldNamingTest.TestNames()).replace('\"', '\''));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "unused")
    private static class TestNames {
        int lowerCamel = 1;

        int UpperCamel = 2;

        int _lowerCamelLeadingUnderscore = 3;

        int _UpperCamelLeadingUnderscore = 4;

        int lower_words = 5;

        int UPPER_WORDS = 6;

        @SerializedName(value = "annotatedName")
        int annotated = 7;
    }
}

