package com.google.gson.functional;

import java.lang.reflect.Field;
import com.google.gson.FieldNamingStrategy;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.annotations.SerializedName;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;

/** 
 * Functional tests for naming policies.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class NamingPolicyTest extends TestCase {
    private GsonBuilder builder;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        builder = new GsonBuilder();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1440,builder);
    }

    public void testGsonWithNonDefaultFieldNamingPolicySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithNonDefaultFieldNamingPolicySerialization");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("b3ah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1466,(("{\"SomeConstantStringInstanceField\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1467,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithNonDefaultFieldNamingPolicySerialization_literalMutation2268() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithNonDefaultFieldNamingPolicySerialization_literalMutation2268");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("blµah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1466,(("{\"SomeConstantStringInstanceField\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1467,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithNonDefaultFieldNamingPolicySerialization_literalMutation2269() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithNonDefaultFieldNamingPolicySerialization_literalMutation2269");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),313,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("bah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1466,(("{\"SomeConstantStringInstanceField\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1467,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithNonDefaultFieldNamingPolicyDeserialiation() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithNonDefaultFieldNamingPolicyDeserialiation");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1464,gson);
            String target = "{\"SomeConstantStringInstaceField\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1465,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1463,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithNonDefaultFieldNamingPolicyDeserialiation_literalMutation2265() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithNonDefaultFieldNamingPolicyDeserialiation_literalMutation2265");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1464,gson);
            String target = "{\"SomeConstantStringInstanceField\":\"someValueÏ\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1465,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1463,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithNonDefaultFieldNamingPolicyDeserialiation_literalMutation2266() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithNonDefaultFieldNamingPolicyDeserialiation_literalMutation2266");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1464,gson);
            String target = "{\"SomeConstantStringInstaceField\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1075,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1465,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1463,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseDashPolicySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseDashPolicySerialization");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_DASHES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1458,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("b¦ah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1456,(("{\"some-constant-string-instance-field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1457,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseDashPolicySerialization_literalMutation2256() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseDashPolicySerialization_literalMutation2256");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_DASHES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1458,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("blah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1456,(("{\"some-constant-string-instance-field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1457,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseDashPolicySerialization_literalMutation2257() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseDashPolicySerialization_literalMutation2257");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_DASHES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1458,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("blh");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),330,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1456,(("{\"some-constant-string-instance-field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1457,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseDashPolicyDeserialiation() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseDashPolicyDeserialiation");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_DASHES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1454,gson);
            String target = "{\"some-constant-string-instance-field\":\"someVaue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1455,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1453,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseDashPolicyDeserialiation_literalMutation2253() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseDashPolicyDeserialiation_literalMutation2253");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_DASHES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1454,gson);
            String target = "{ \"some-constant-string-instance-field\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1455,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1453,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseDashPolicyDeserialiation_literalMutation2254() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseDashPolicyDeserialiation_literalMutation2254");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_DASHES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1454,gson);
            String target = "{\"some-constant-string-instance-field\"\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1455,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1453,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseUnderscorePolicySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseUnderscorePolicySerialization");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_UNDERSCORES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("bÊah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1461,(("{\"some_constant_string_instance_field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1462,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseUnderscorePolicySerialization_literalMutation2262() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseUnderscorePolicySerialization_literalMutation2262");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_UNDERSCORES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("bÛlah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1461,(("{\"some_constant_string_instance_field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1462,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseUnderscorePolicySerialization_literalMutation2263() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseUnderscorePolicySerialization_literalMutation2263");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_UNDERSCORES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),872,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("bah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),243,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1461,(("{\"some_constant_string_instance_field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1462,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseUnderscorePolicyDeserialiation() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseUnderscorePolicyDeserialiation");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_UNDERSCORES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,gson);
            String target = "{\"some_constant_string_instance_field\":\"some$alue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1460,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1459,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseUnderscorePolicyDeserialiation_literalMutation2259() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseUnderscorePolicyDeserialiation_literalMutation2259");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_UNDERSCORES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,gson);
            String target = "{\"some_constant_ástring_instance_field\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1460,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1459,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithLowerCaseUnderscorePolicyDeserialiation_literalMutation2260() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithLowerCaseUnderscorePolicyDeserialiation_literalMutation2260");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.LOWER_CASE_WITH_UNDERSCORES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),307,gson);
            String target = "{\"some_constant_stringinstance_field\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),415,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1460,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1459,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(4 , 6);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2281() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2281");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(2 , 6);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2282() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2282");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(10 , 6);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2283() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2283");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(6 , 6);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2285() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2285");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 5);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2286() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2286");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2287() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2287");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 12);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2288() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicySerialization_literalMutation2288");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 7);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,expected);
            String actual = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,expected.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(4 , 7);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2271() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2271");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(2 , 7);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2272() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2272");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(10 , 7);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2273() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2273");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(6 , 7);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2275() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2275");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 8);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2276() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2276");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 6);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2277() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2277");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2278() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithSerializedNameFieldNamingPolicyDeserialization_literalMutation2278");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,gson);
            TestTypes.ClassWithSerializedNameFields expected = new TestTypes.ClassWithSerializedNameFields(5 , 14);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,expected);
            TestTypes.ClassWithSerializedNameFields actual = gson.fromJson(expected.getExpectedJson(), TestTypes.ClassWithSerializedNameFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,expected.f);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,actual.f);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_add356() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_add356");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            try {
                ClassWithDuplicateFields target = new ClassWithDuplicateFields(10);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
                gson.toJson(target);
                gson.toJson(target);
            } catch (IllegalArgumentException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            try {
                ClassWithDuplicateFields target = new ClassWithDuplicateFields(9);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
                gson.toJson(target);
            } catch (IllegalArgumentException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_literalMutation2248() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_literalMutation2248");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            try {
                ClassWithDuplicateFields target = new ClassWithDuplicateFields(5);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
                gson.toJson(target);
            } catch (IllegalArgumentException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_literalMutation2249() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_literalMutation2249");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            try {
                ClassWithDuplicateFields target = new ClassWithDuplicateFields(20);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
                gson.toJson(target);
            } catch (IllegalArgumentException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_literalMutation2250() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonDuplicateNameUsingSerializedNameFieldNamingPolicySerialization_literalMutation2250");
            Gson gson = builder.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,gson);
            try {
                ClassWithDuplicateFields target = new ClassWithDuplicateFields(11);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),899,target);
                gson.toJson(target);
            } catch (IllegalArgumentException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithUpperCamelCaseSpacesPolicySerialiation() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithUpperCamelCaseSpacesPolicySerialiation");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE_WITH_SPACES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1100,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("b\rah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1482,(("{\"Some Constant String Instance Field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1483,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithUpperCamelCaseSpacesPolicySerialiation_literalMutation2294() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithUpperCamelCaseSpacesPolicySerialiation_literalMutation2294");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE_WITH_SPACES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1100,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("blIah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1482,(("{\"Some Constant String Instance Field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1483,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithUpperCamelCaseSpacesPolicySerialiation_literalMutation2295() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithUpperCamelCaseSpacesPolicySerialiation_literalMutation2295");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE_WITH_SPACES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1100,gson);
            TestTypes.StringWrapper target = new TestTypes.StringWrapper("bah");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),423,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1482,(("{\"Some Constant String Instance Field\":\"" + (target.someConstantStringInstanceField)) + "\"}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1483,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithUpperCamelCaseSpacesPolicyDeserialiation() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithUpperCamelCaseSpacesPolicyDeserialiation");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE_WITH_SPACES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            String target = "{\"Some Eonstant String Instance Field\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1480,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1481,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1479,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithUpperCamelCaseSpacesPolicyDeserialiation_literalMutation2291() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithUpperCamelCaseSpacesPolicyDeserialiation_literalMutation2291");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE_WITH_SPACES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            String target = "{\"Some Constant String Instance Field\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1480,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1481,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1479,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonWithUpperCamelCaseSpacesPolicyDeserialiation_literalMutation2292() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonWithUpperCamelCaseSpacesPolicyDeserialiation_literalMutation2292");
            Gson gson = builder.setFieldNamingPolicy(com.google.gson.FieldNamingPolicy.UPPER_CAMEL_CASE_WITH_SPACES).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),865,gson);
            String target = "{\"Some Constant String Insance Field\":\"someValue\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1480,target);
            TestTypes.StringWrapper deserializedObject = gson.fromJson(target, TestTypes.StringWrapper.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1481,deserializedObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1479,deserializedObject.someConstantStringInstanceField);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeprecatedNamingStrategy() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeprecatedNamingStrategy");
            Gson gson = builder.setFieldNamingStrategy(new UpperCaseNamingStrategy()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1449,gson);
            ClassWithDuplicateFields target = new ClassWithDuplicateFields(9);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1450,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1451,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1448,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeprecatedNamingStrategy_literalMutation2243() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeprecatedNamingStrategy_literalMutation2243");
            Gson gson = builder.setFieldNamingStrategy(new UpperCaseNamingStrategy()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1449,gson);
            ClassWithDuplicateFields target = new ClassWithDuplicateFields(5);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1450,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1451,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1448,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeprecatedNamingStrategy_literalMutation2244() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeprecatedNamingStrategy_literalMutation2244");
            Gson gson = builder.setFieldNamingStrategy(new UpperCaseNamingStrategy()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1449,gson);
            ClassWithDuplicateFields target = new ClassWithDuplicateFields(20);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1450,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1451,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1448,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDeprecatedNamingStrategy_literalMutation2245() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDeprecatedNamingStrategy_literalMutation2245");
            Gson gson = builder.setFieldNamingStrategy(new UpperCaseNamingStrategy()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1449,gson);
            ClassWithDuplicateFields target = new ClassWithDuplicateFields(11);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1450,target);
            String actual = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1451,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1448,actual);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testComplexFieldNameStrategy() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComplexFieldNameStrategy");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,gson);
            String json = gson.toJson(new ClassWithComplexFieldName(9));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,json);
            String escapedFieldName = "@value\\\"_s$\\\\";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,escapedFieldName);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,(("{\"" + escapedFieldName) + "\":10}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,json);
            ClassWithComplexFieldName obj = gson.fromJson(json, ClassWithComplexFieldName.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testComplexFieldNameStrategy_literalMutation2235() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComplexFieldNameStrategy_literalMutation2235");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,gson);
            String json = gson.toJson(new ClassWithComplexFieldName(5));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,json);
            String escapedFieldName = "@value\\\"_s$\\\\";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,escapedFieldName);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,(("{\"" + escapedFieldName) + "\":10}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,json);
            ClassWithComplexFieldName obj = gson.fromJson(json, ClassWithComplexFieldName.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testComplexFieldNameStrategy_literalMutation2236() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComplexFieldNameStrategy_literalMutation2236");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,gson);
            String json = gson.toJson(new ClassWithComplexFieldName(20));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,json);
            String escapedFieldName = "@value\\\"_s$\\\\";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,escapedFieldName);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,(("{\"" + escapedFieldName) + "\":10}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,json);
            ClassWithComplexFieldName obj = gson.fromJson(json, ClassWithComplexFieldName.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testComplexFieldNameStrategy_literalMutation2237() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComplexFieldNameStrategy_literalMutation2237");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,gson);
            String json = gson.toJson(new ClassWithComplexFieldName(11));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,json);
            String escapedFieldName = "@value\\\"_s$\\\\";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,escapedFieldName);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,(("{\"" + escapedFieldName) + "\":10}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,json);
            ClassWithComplexFieldName obj = gson.fromJson(json, ClassWithComplexFieldName.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testComplexFieldNameStrategy_literalMutation2239() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComplexFieldNameStrategy_literalMutation2239");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,gson);
            String json = gson.toJson(new ClassWithComplexFieldName(10));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,json);
            String escapedFieldName = "@va=ue\\\"_s$\\\\";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,escapedFieldName);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,(("{\"" + escapedFieldName) + "\":10}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,json);
            ClassWithComplexFieldName obj = gson.fromJson(json, ClassWithComplexFieldName.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testComplexFieldNameStrategy_literalMutation2240() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComplexFieldNameStrategy_literalMutation2240");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,gson);
            String json = gson.toJson(new ClassWithComplexFieldName(10));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,json);
            String escapedFieldName = "@value\\c\"_s$\\\\";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,escapedFieldName);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,(("{\"" + escapedFieldName) + "\":10}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,json);
            ClassWithComplexFieldName obj = gson.fromJson(json, ClassWithComplexFieldName.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testComplexFieldNameStrategy_literalMutation2241() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testComplexFieldNameStrategy_literalMutation2241");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,gson);
            String json = gson.toJson(new ClassWithComplexFieldName(10));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),132,json);
            String escapedFieldName = "@valu\\\"_s$\\\\";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,escapedFieldName);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,(("{\"" + escapedFieldName) + "\":10}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,json);
            ClassWithComplexFieldName obj = gson.fromJson(json, ClassWithComplexFieldName.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,obj.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * http://code.google.com/p/google-gson/issues/detail?id=349
     */
public void testAtSignInSerializedName() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAtSignInSerializedName");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1441,new com.google.gson.Gson().toJson(new com.google.gson.functional.NamingPolicyTest.AtName()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    static class AtName {
        @SerializedName(value = "@foo")
        String f = "bar";
    }

    private static class UpperCaseNamingStrategy implements FieldNamingStrategy {
        public String translateName(Field f) {
            return f.getName().toUpperCase();
        }
    }

    @SuppressWarnings(value = "unused")
    private static class ClassWithDuplicateFields {
        public Integer a;

        @SerializedName(value = "a")
        public Double b;

        public ClassWithDuplicateFields(Integer a) {
            this(a, null);
        }

        public ClassWithDuplicateFields(Double b) {
            this(null, b);
        }

        public ClassWithDuplicateFields(Integer a ,Double b) {
            this.a = a;
            this.b = b;
        }
    }

    private static class ClassWithComplexFieldName {
        @SerializedName(value = "@value\"_s$\\")
        public final long value;

        ClassWithComplexFieldName(long value) {
            this.value = value;
        }
    }
}

