package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonParseException;
import java.util.List;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.lang.reflect.Type;

/** 
 * Functional tests that do not fall neatly into any of the existing classification.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class UncategorizedTest extends TestCase {
    private Gson gson = null;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2461,gson);
    }

    @Test(timeout = 1000)
    public void testInvalidJsonDeserializationFails_add505() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails_add505");
            try {
                gson.fromJson("adfasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
                gson.fromJson("adfasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasdf1112,,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInvalidJsonDeserializationFails_add506() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails_add506");
            try {
                gson.fromJson("adfasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasdf1112,,,\":}", TestTypes.BagOfPrimitives.class);
                gson.fromJson("{adfasdf1112,,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInvalidJsonDeserializationFails() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails");
            try {
                gson.fromJson("a5fasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasdf1112,,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInvalidJsonDeserializationFails_literalMutation3647() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails_literalMutation3647");
            try {
                gson.fromJson("adfaasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasdf1112,,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInvalidJsonDeserializationFails_literalMutation3648() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails_literalMutation3648");
            try {
                gson.fromJson("adfasdf1112,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasdf1112,,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInvalidJsonDeserializationFails_literalMutation3649() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails_literalMutation3649");
            try {
                gson.fromJson("adfasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasd1112,,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInvalidJsonDeserializationFails_literalMutation3650() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails_literalMutation3650");
            try {
                gson.fromJson("adfasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasdfà1112,,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInvalidJsonDeserializationFails_literalMutation3651() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInvalidJsonDeserializationFails_literalMutation3651");
            try {
                gson.fromJson("adfasdf1112,,,\":", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
            try {
                gson.fromJson("{adfasdf1112,,\":}", TestTypes.BagOfPrimitives.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testObjectEqualButNotSameSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectEqualButNotSameSerialization");
            TestTypes.ClassOverridingEquals objA = new TestTypes.ClassOverridingEquals();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2469,objA);
            TestTypes.ClassOverridingEquals objB = new TestTypes.ClassOverridingEquals();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2470,objB);
            objB.ref = objA;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2468,objB.ref);
            String json = gson.toJson(objB);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2466,objB.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2467,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStaticFieldsAreNotSerialized() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStaticFieldsAreNotSerialized");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2483,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2482,gson.toJson(target).contains("DEFAULT_VALUE"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGsonInstanceReusableForSerializationAndDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGsonInstanceReusableForSerializationAndDeserialization");
            TestTypes.BagOfPrimitives bag = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2464,bag);
            String json = gson.toJson(bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1848,json);
            TestTypes.BagOfPrimitives deserialized = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2465,deserialized);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2462,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2463,deserialized);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This test ensures that a custom deserializer is able to return a derived class instance for a
     * base class object. For a motivation for this test, see Issue 37 and
     * http://groups.google.com/group/google-gson/browse_thread/thread/677d56e9976d7761
     */
public void testReturningDerivedClassesDuringDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReturningDerivedClassesDuringDeserialization");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new BaseTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2479,gson);
            String json = "{\"opType\":;OP1\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2480,json);
            Base base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2481,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2471,(base instanceof com.google.gson.functional.UncategorizedTest.Derived1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2472,com.google.gson.functional.UncategorizedTest.OperationType.OP1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2473,base.opType);
            json = "{\"opType\":\"OP2\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2477,json);
            base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2478,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2474,(base instanceof com.google.gson.functional.UncategorizedTest.Derived2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2475,com.google.gson.functional.UncategorizedTest.OperationType.OP2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2476,base.opType);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This test ensures that a custom deserializer is able to return a derived class instance for a
     * base class object. For a motivation for this test, see Issue 37 and
     * http://groups.google.com/group/google-gson/browse_thread/thread/677d56e9976d7761
     */
public void testReturningDerivedClassesDuringDeserialization_literalMutation3653() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReturningDerivedClassesDuringDeserialization_literalMutation3653");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new BaseTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2479,gson);
            String json = "{\"opType\":\"WOP1\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2480,json);
            Base base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2481,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2471,(base instanceof com.google.gson.functional.UncategorizedTest.Derived1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2472,com.google.gson.functional.UncategorizedTest.OperationType.OP1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2473,base.opType);
            json = "{\"opType\":\"OP2\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2477,json);
            base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2478,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2474,(base instanceof com.google.gson.functional.UncategorizedTest.Derived2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2475,com.google.gson.functional.UncategorizedTest.OperationType.OP2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2476,base.opType);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This test ensures that a custom deserializer is able to return a derived class instance for a
     * base class object. For a motivation for this test, see Issue 37 and
     * http://groups.google.com/group/google-gson/browse_thread/thread/677d56e9976d7761
     */
public void testReturningDerivedClassesDuringDeserialization_literalMutation3654() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReturningDerivedClassesDuringDeserialization_literalMutation3654");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new BaseTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2479,gson);
            String json = "{\"opype\":\"OP1\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2480,json);
            Base base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2481,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2471,(base instanceof com.google.gson.functional.UncategorizedTest.Derived1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2472,com.google.gson.functional.UncategorizedTest.OperationType.OP1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2473,base.opType);
            json = "{\"opType\":\"OP2\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2477,json);
            base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2478,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2474,(base instanceof com.google.gson.functional.UncategorizedTest.Derived2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2475,com.google.gson.functional.UncategorizedTest.OperationType.OP2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2476,base.opType);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This test ensures that a custom deserializer is able to return a derived class instance for a
     * base class object. For a motivation for this test, see Issue 37 and
     * http://groups.google.com/group/google-gson/browse_thread/thread/677d56e9976d7761
     */
public void testReturningDerivedClassesDuringDeserialization_literalMutation3655() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReturningDerivedClassesDuringDeserialization_literalMutation3655");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new BaseTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2479,gson);
            String json = "{\"opType\":\"OP1\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2480,json);
            Base base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2481,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2471,(base instanceof com.google.gson.functional.UncategorizedTest.Derived1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2472,com.google.gson.functional.UncategorizedTest.OperationType.OP1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2473,base.opType);
            json = "{\"opTypeK:\"OP2\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2477,json);
            base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2478,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2474,(base instanceof com.google.gson.functional.UncategorizedTest.Derived2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2475,com.google.gson.functional.UncategorizedTest.OperationType.OP2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2476,base.opType);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This test ensures that a custom deserializer is able to return a derived class instance for a
     * base class object. For a motivation for this test, see Issue 37 and
     * http://groups.google.com/group/google-gson/browse_thread/thread/677d56e9976d7761
     */
public void testReturningDerivedClassesDuringDeserialization_literalMutation3656() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReturningDerivedClassesDuringDeserialization_literalMutation3656");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new BaseTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2479,gson);
            String json = "{\"opType\":\"OP1\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2480,json);
            Base base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2481,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2471,(base instanceof com.google.gson.functional.UncategorizedTest.Derived1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2472,com.google.gson.functional.UncategorizedTest.OperationType.OP1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2473,base.opType);
            json = "{\"opType\":\"OºP2\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2477,json);
            base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2478,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2474,(base instanceof com.google.gson.functional.UncategorizedTest.Derived2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2475,com.google.gson.functional.UncategorizedTest.OperationType.OP2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2476,base.opType);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This test ensures that a custom deserializer is able to return a derived class instance for a
     * base class object. For a motivation for this test, see Issue 37 and
     * http://groups.google.com/group/google-gson/browse_thread/thread/677d56e9976d7761
     */
public void testReturningDerivedClassesDuringDeserialization_literalMutation3657() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testReturningDerivedClassesDuringDeserialization_literalMutation3657");
            Gson gson = new GsonBuilder().registerTypeAdapter(Base.class, new BaseTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2479,gson);
            String json = "{\"opType\":\"OP1\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2480,json);
            Base base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2481,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2471,(base instanceof com.google.gson.functional.UncategorizedTest.Derived1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2472,com.google.gson.functional.UncategorizedTest.OperationType.OP1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2473,base.opType);
            json = "{\"opType\":OP2\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2477,json);
            base = gson.fromJson(json, Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2478,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2474,(base instanceof com.google.gson.functional.UncategorizedTest.Derived2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2475,com.google.gson.functional.UncategorizedTest.OperationType.OP2);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2476,base.opType);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that trailing whitespace is ignored.
     * http://code.google.com/p/google-gson/issues/detail?id=302
     */
@Test(timeout = 1000)
    public void testTrailingWhitespace_add507() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTrailingWhitespace_add507");
            List<java.lang.Integer> integers = gson.fromJson("[1,2,3]  \n\n  ", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.Integer>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2486,integers);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2484,java.util.Arrays.asList(1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2485,integers);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that trailing whitespace is ignored.
     * http://code.google.com/p/google-gson/issues/detail?id=302
     */
public void testTrailingWhitespace() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTrailingWhitespace");
            List<java.lang.Integer> integers = gson.fromJson("[1,&,3]  \n\n  ", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.Integer>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2486,integers);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2484,java.util.Arrays.asList(1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2485,integers);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that trailing whitespace is ignored.
     * http://code.google.com/p/google-gson/issues/detail?id=302
     */
public void testTrailingWhitespace_literalMutation3659() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTrailingWhitespace_literalMutation3659");
            List<java.lang.Integer> integers = gson.fromJson("[1,2,3]  \n\n  ", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.Integer>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2486,integers);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2484,java.util.Arrays.asList(1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2485,integers);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that trailing whitespace is ignored.
     * http://code.google.com/p/google-gson/issues/detail?id=302
     */
public void testTrailingWhitespace_literalMutation3660() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTrailingWhitespace_literalMutation3660");
            List<java.lang.Integer> integers = gson.fromJson("[1,2,3]  \n\n ", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.Integer>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2486,integers);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2484,java.util.Arrays.asList(1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2485,integers);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test that trailing whitespace is ignored.
     * http://code.google.com/p/google-gson/issues/detail?id=302
     */
@Test(timeout = 1000)
    public void testTrailingWhitespace_remove428() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTrailingWhitespace_remove428");
            List<java.lang.Integer> integers = gson.fromJson("[1,2,3]  \n\n  ", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.Integer>>() {            }.getType());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2486,integers);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2484,java.util.Arrays.asList(1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2485,integers);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private enum OperationType {
OP1, OP2;    }

    private static class Base {
        OperationType opType;
    }

    private static class Derived1 extends Base {
        Derived1() {
            opType = OperationType.OP1;
        }
    }

    private static class Derived2 extends Base {
        Derived2() {
            opType = OperationType.OP2;
        }
    }

    private static class BaseTypeAdapter implements JsonDeserializer<Base> {
        public Base deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
            String opTypeStr = json.getAsJsonObject().get("opType").getAsString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2459,opTypeStr);
            OperationType opType = OperationType.valueOf(opTypeStr);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2460,opType);
            switch (opType) {
                case OP1 :
                    return new Derived1();
                case OP2 :
                    return new Derived2();
            }
            throw new JsonParseException(("unknown type: " + json));
        }
    }
}

