package com.google.common.collect;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/** 
 * Unit tests for {@link HashMultimap}.
 * 
 * @author Jared Levy
 */
public class Test_32_HashMultimapTest extends TestCase {
    public static Test suite() {
        TestSuite suite = new TestSuite();
        suite.addTest(com.google.common.collect.testing.google.SetMultimapTestSuiteBuilder.using(new com.google.common.collect.testing.google.TestStringSetMultimapGenerator() {
            @java.lang.Override
            protected com.google.common.collect.SetMultimap<java.lang.String, java.lang.String> create(java.util.Map.Entry<java.lang.String, java.lang.String>[] entries) {
                com.google.common.collect.SetMultimap<java.lang.String, java.lang.String> multimap = HashMultimap.create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),30,multimap);
                for (java.util.Map.Entry<java.lang.String, java.lang.String> entry : entries) {
                    multimap.put(entry.getKey(), entry.getValue());
                }
                return multimap;
            }
        }).named("HashMultimap").withFeatures(com.google.common.collect.testing.features.MapFeature.ALLOWS_NULL_KEYS, com.google.common.collect.testing.features.MapFeature.ALLOWS_NULL_VALUES, com.google.common.collect.testing.features.MapFeature.ALLOWS_ANY_NULL_QUERIES, com.google.common.collect.testing.features.MapFeature.GENERAL_PURPOSE, com.google.common.collect.testing.features.MapFeature.FAILS_FAST_ON_CONCURRENT_MODIFICATION, com.google.common.collect.testing.features.CollectionFeature.SUPPORTS_ITERATOR_REMOVE, com.google.common.collect.testing.features.CollectionFeature.SERIALIZABLE, com.google.common.collect.testing.features.CollectionSize.ANY).createTestSuite());
        suite.addTestSuite(com.google.common.collect.Test_32_HashMultimapTest.class);
        return suite;
    }

    public void testCreateFromMultimap() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreateFromMultimap");
            HashMultimap<java.lang.String, java.lang.Integer> multimap = HashMultimap.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),38,multimap);
            multimap.put("foo", 1);
            multimap.put("bar", 2);
            multimap.put("foo", 3);
            HashMultimap<java.lang.String, java.lang.Integer> copy = HashMultimap.create(multimap);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),39,copy);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),35,multimap);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),36,copy);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),37,copy.expectedValuesPerKey);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @org.junit.Test(timeout = 1000)
    public void testCreateFromSizes() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreateFromSizes_remove13");
            HashMultimap<java.lang.String, java.lang.Integer> multimap = HashMultimap.create(20, 15);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),43,multimap);
            multimap.put("bar", 2);
            multimap.put("foo", 3);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),40,com.google.common.collect.ImmutableSet.of(1, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),41,multimap.get("foo"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),42,multimap.expectedValuesPerKey);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCreate() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreateFromIllegalSizes_literalMutation103");
            try {
                HashMultimap.create(19, 15);
            } catch (IllegalArgumentException expected) {
            }
            try {
                HashMultimap.create(20, 14);
            } catch (IllegalArgumentException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testCreateFromIllegalSizes() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testCreateFromIllegalSizes");
            try {
                HashMultimap.create(19, 15);
            } catch (IllegalArgumentException expected) {
            }
            try {
                HashMultimap.create(20, 16);
            } catch (IllegalArgumentException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEmptyMultimapsEqual() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyMultimapsEqual");
            Multimap<java.lang.String, java.lang.Integer> setMultimap = HashMultimap.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),46,setMultimap);
            Multimap<java.lang.String, java.lang.Integer> listMultimap = com.google.common.collect.ArrayListMultimap.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),47,listMultimap);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),44,setMultimap.equals(listMultimap));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),45,listMultimap.equals(setMultimap));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

