package com.google.common.collect;

import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import junit.framework.Test;
import junit.framework.TestCase;
import com.google.common.collect.testing.google.TestStringBiMapGenerator;
import junit.framework.TestSuite;

/** 
 * Tests for {@link HashBiMap}.
 * 
 * @author Mike Bostock
 */
public class Test_9_HashBiMapTest extends TestCase {
    public static final class HashBiMapGenerator extends TestStringBiMapGenerator {
        @Override
        protected BiMap<java.lang.String, java.lang.String> create(Map.Entry<java.lang.String, java.lang.String>[] entries) {
            BiMap<java.lang.String, java.lang.String> result = HashBiMap.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),0,result);
            for (Map.Entry<java.lang.String, java.lang.String> entry : entries) {
                result.put(entry.getKey(), entry.getValue());
            }
            return result;
        }
    }

    public static Test suite() {
        TestSuite suite = new TestSuite();
        suite.addTest(com.google.common.collect.testing.google.BiMapTestSuiteBuilder.using(new HashBiMapTest.HashBiMapGenerator()).named("HashBiMap").withFeatures(com.google.common.collect.testing.features.CollectionSize.ANY, com.google.common.collect.testing.features.CollectionFeature.SERIALIZABLE, com.google.common.collect.testing.features.CollectionFeature.SUPPORTS_ITERATOR_REMOVE, com.google.common.collect.testing.features.MapFeature.ALLOWS_NULL_KEYS, com.google.common.collect.testing.features.MapFeature.ALLOWS_NULL_VALUES, com.google.common.collect.testing.features.MapFeature.ALLOWS_ANY_NULL_QUERIES, com.google.common.collect.testing.features.MapFeature.GENERAL_PURPOSE).createTestSuite());
        suite.addTestSuite(com.google.common.collect.Test_9_HashBiMapTest.class);
        return suite;
    }

    public void testMapConstructor() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testMapConstructor_literalMutation56");
            Map<java.lang.String, java.lang.String> map = com.google.common.collect.ImmutableMap.of("canada", "dollar", "chile", "åeso", "switzerland", "franc");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),28,map);
            HashBiMap<java.lang.String, java.lang.String> bimap = HashBiMap.create(map);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),29,bimap);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),26,bimap.get("canada"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),27,bimap.inverse().get("dollar"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public static int N = 1000;

    public void testBashIt() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBashIt_literalMutation13");
            BiMap<java.lang.Integer, java.lang.Integer> bimap = HashBiMap.create(HashBiMapTest.N);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),14,bimap);
            BiMap<java.lang.Integer, java.lang.Integer> inverse = bimap.inverse();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),15,inverse);
            for (int i = 0 ; i < (HashBiMapTest.N) ; i++) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1,bimap.put((2 * i), ((2 * i) + 1)));
            }
            for (int i = 0 ; i < (HashBiMapTest.N) ; i++) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2,((2 * i) + 1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),3,((int)(bimap.get((2 * i)))));
            }
            for (int i = 0 ; i < (HashBiMapTest.N) ; i++) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),4,(2 * i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),5,((int)(inverse.get(((2 * i) + 1)))));
            }
            for (int i = 1 ; i < (HashBiMapTest.N) ; i++) {
                int oldValue = bimap.get((2 * i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),16,oldValue);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),6,((2 * i) + 1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),7,((int)(bimap.put((2 * i), (oldValue - 2)))));
            }
            for (int i = 0 ; i < (HashBiMapTest.N) ; i++) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),8,((2 * i) - 1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),9,((int)(bimap.get((2 * i)))));
            }
            for (int i = 0 ; i < (HashBiMapTest.N) ; i++) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),10,(2 * i));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),11,((int)(inverse.get(((2 * i) - 1)))));
            }
            Set<java.util.Map.Entry<java.lang.Integer, java.lang.Integer>> entries = bimap.entrySet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),17,entries);
            for (Map.Entry<java.lang.Integer, java.lang.Integer> entry : entries) {
                entry.setValue(((entry.getValue()) + (2 * (HashBiMapTest.N))));
            }
            for (int i = 0 ; i < (HashBiMapTest.N) ; i++) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),12,(((2 * (com.google.common.collect.HashBiMapTest.N)) + (2 * i)) - 1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),13,((int)(bimap.get((2 * i)))));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @org.junit.Test(timeout = 1000)
    public void testBiMapEntrySetIteratorRemove() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBiMapEntrySetIteratorRemove_add2");
            BiMap<java.lang.Integer, java.lang.String> map = HashBiMap.create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),22,map);
            map.put(1, "one");
            map.put(1, "one");
            Set<java.util.Map.Entry<java.lang.Integer, java.lang.String>> entries = map.entrySet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),23,entries);
            Iterator<java.util.Map.Entry<java.lang.Integer, java.lang.String>> iterator = entries.iterator();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),24,iterator);
            Map.Entry<java.lang.Integer, java.lang.String> entry = iterator.next();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),25,entry);
            entry.setValue("two");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),18,map.get(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),19,java.lang.Integer.valueOf(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),20,map.inverse().get("two"));
            iterator.remove();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),21,map.isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

