package org.apache.commons.io;

import java.io.File;
import org.apache.commons.io.testtools.FileBasedTestCase;
import org.junit.Test;

/** 
 * This is used to test FilenameUtils for correctness.
 * 
 * @version $Id$
 * @see FilenameUtils
 */
public class FilenameUtilsTestCase extends FileBasedTestCase {
    private static final String SEP = "" + (File.separatorChar);

    private static final boolean WINDOWS = (File.separatorChar) == '\\';

    private File testFile1;

    private File testFile2;

    private int testFile1Size;

    private int testFile2Size;

    public FilenameUtilsTestCase(String name) {
        super(name);
        testFile1 = new File(FileBasedTestCase.getTestDirectory() , "file1-test.txt");
        testFile2 = new File(FileBasedTestCase.getTestDirectory() , "file1a-test.txt");
        testFile1Size = ((int)(testFile1.length()));
        testFile2Size = ((int)(testFile2.length()));
    }

    /** 
     * @see junit.framework.TestCase#setUp()
     */
@Override
    protected void setUp() throws Exception {
        FileBasedTestCase.getTestDirectory().mkdirs();
        createFile(testFile1, testFile1Size);
        createFile(testFile2, testFile2Size);
        org.apache.commons.io.FileUtils.deleteDirectory(FileBasedTestCase.getTestDirectory());
        FileBasedTestCase.getTestDirectory().mkdirs();
        createFile(testFile1, testFile1Size);
        createFile(testFile2, testFile2Size);
    }

    /** 
     * @see junit.framework.TestCase#tearDown()
     */
@Override
    protected void tearDown() throws Exception {
        org.apache.commons.io.FileUtils.deleteDirectory(FileBasedTestCase.getTestDirectory());
    }

    public void testNormalize() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNormalize");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,org.apache.commons.io.FilenameUtils.normalize(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,org.apache.commons.io.FilenameUtils.normalize(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,org.apache.commons.io.FilenameUtils.normalize("1:\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,org.apache.commons.io.FilenameUtils.normalize("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,org.apache.commons.io.FilenameUtils.normalize("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,org.apache.commons.io.FilenameUtils.normalize("\\\\\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,org.apache.commons.io.FilenameUtils.normalize("\\\\a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1705,(((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1706,org.apache.commons.io.FilenameUtils.normalize("a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1707,(((((("" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1708,org.apache.commons.io.FilenameUtils.normalize("\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1709,(((((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1710,org.apache.commons.io.FilenameUtils.normalize("C:\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1711,(((((((((("" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1712,org.apache.commons.io.FilenameUtils.normalize("\\\\server\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1713,(((((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1714,org.apache.commons.io.FilenameUtils.normalize("~\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1715,(((((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1716,org.apache.commons.io.FilenameUtils.normalize("~user\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1717,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1718,org.apache.commons.io.FilenameUtils.normalize("a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1719,org.apache.commons.io.FilenameUtils.normalize("a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1720,("c" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1721,org.apache.commons.io.FilenameUtils.normalize("a/b/../../c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1722,org.apache.commons.io.FilenameUtils.normalize("a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1723,("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1724,org.apache.commons.io.FilenameUtils.normalize("a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1725,("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1726,org.apache.commons.io.FilenameUtils.normalize("a/b/../"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1727,org.apache.commons.io.FilenameUtils.normalize("a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1728,org.apache.commons.io.FilenameUtils.normalize("a/b/../../"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1729,org.apache.commons.io.FilenameUtils.normalize("a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1730,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1731,org.apache.commons.io.FilenameUtils.normalize("a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1732,((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1733,org.apache.commons.io.FilenameUtils.normalize("a/b/../c/../d/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1734,(((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1735,org.apache.commons.io.FilenameUtils.normalize("a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1736,((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1737,org.apache.commons.io.FilenameUtils.normalize("a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1738,((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1739,org.apache.commons.io.FilenameUtils.normalize("a/b/./././"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1740,("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1741,org.apache.commons.io.FilenameUtils.normalize("./a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1742,org.apache.commons.io.FilenameUtils.normalize("./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1743,org.apache.commons.io.FilenameUtils.normalize("./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1744,org.apache.commons.io.FilenameUtils.normalize("."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1745,org.apache.commons.io.FilenameUtils.normalize("../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1746,org.apache.commons.io.FilenameUtils.normalize(".."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1747,org.apache.commons.io.FilenameUtils.normalize(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1748,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1749,org.apache.commons.io.FilenameUtils.normalize("/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1750,(((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1751,org.apache.commons.io.FilenameUtils.normalize("/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1752,((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1753,org.apache.commons.io.FilenameUtils.normalize("/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1754,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1755,org.apache.commons.io.FilenameUtils.normalize("/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1756,org.apache.commons.io.FilenameUtils.normalize("/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1757,(((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1758,org.apache.commons.io.FilenameUtils.normalize("/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1759,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1760,org.apache.commons.io.FilenameUtils.normalize("/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1761,org.apache.commons.io.FilenameUtils.normalize("/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1762,((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1763,org.apache.commons.io.FilenameUtils.normalize("/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1764,((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1765,org.apache.commons.io.FilenameUtils.normalize("/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1766,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1767,org.apache.commons.io.FilenameUtils.normalize("/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1768,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1769,org.apache.commons.io.FilenameUtils.normalize("/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1770,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1771,org.apache.commons.io.FilenameUtils.normalize("/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1772,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1773,org.apache.commons.io.FilenameUtils.normalize("/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1774,org.apache.commons.io.FilenameUtils.normalize("/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1775,org.apache.commons.io.FilenameUtils.normalize("/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1776,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1777,org.apache.commons.io.FilenameUtils.normalize("/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1778,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1779,org.apache.commons.io.FilenameUtils.normalize("~/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1780,((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1781,org.apache.commons.io.FilenameUtils.normalize("~/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1782,(((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1783,org.apache.commons.io.FilenameUtils.normalize("~/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1784,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1785,org.apache.commons.io.FilenameUtils.normalize("~/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1786,org.apache.commons.io.FilenameUtils.normalize("~/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1787,((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1788,org.apache.commons.io.FilenameUtils.normalize("~/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1789,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1790,org.apache.commons.io.FilenameUtils.normalize("~/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1791,org.apache.commons.io.FilenameUtils.normalize("~/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1792,(((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1793,org.apache.commons.io.FilenameUtils.normalize("~/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1794,(((((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1795,org.apache.commons.io.FilenameUtils.normalize("~/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1796,((((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1797,org.apache.commons.io.FilenameUtils.normalize("~/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1798,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1799,org.apache.commons.io.FilenameUtils.normalize("~/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1800,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1801,org.apache.commons.io.FilenameUtils.normalize("~/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1802,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1803,org.apache.commons.io.FilenameUtils.normalize("~/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1804,org.apache.commons.io.FilenameUtils.normalize("~/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1805,org.apache.commons.io.FilenameUtils.normalize("~/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1806,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1807,org.apache.commons.io.FilenameUtils.normalize("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1808,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1809,org.apache.commons.io.FilenameUtils.normalize("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1810,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1811,org.apache.commons.io.FilenameUtils.normalize("~user/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1812,((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1813,org.apache.commons.io.FilenameUtils.normalize("~user/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1814,(((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1815,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1816,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1817,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1818,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1819,((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1820,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1821,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1822,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1823,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1824,(((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1825,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1826,(((((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1827,org.apache.commons.io.FilenameUtils.normalize("~user/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1828,((((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1829,org.apache.commons.io.FilenameUtils.normalize("~user/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1830,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1831,org.apache.commons.io.FilenameUtils.normalize("~user/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1832,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1833,org.apache.commons.io.FilenameUtils.normalize("~user/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1834,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1835,org.apache.commons.io.FilenameUtils.normalize("~user/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1836,org.apache.commons.io.FilenameUtils.normalize("~user/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1837,org.apache.commons.io.FilenameUtils.normalize("~user/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1838,("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1839,org.apache.commons.io.FilenameUtils.normalize("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1840,("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1841,org.apache.commons.io.FilenameUtils.normalize("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1842,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1843,org.apache.commons.io.FilenameUtils.normalize("C:/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1844,((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1845,org.apache.commons.io.FilenameUtils.normalize("C:/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1846,(((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1847,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1848,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1849,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1850,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1851,((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1852,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1853,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1854,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1855,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1856,(((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1857,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1858,(((((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1859,org.apache.commons.io.FilenameUtils.normalize("C:/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1860,((((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1861,org.apache.commons.io.FilenameUtils.normalize("C:/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1862,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1863,org.apache.commons.io.FilenameUtils.normalize("C:/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1864,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1865,org.apache.commons.io.FilenameUtils.normalize("C:/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1866,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1867,org.apache.commons.io.FilenameUtils.normalize("C:/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1868,org.apache.commons.io.FilenameUtils.normalize("C:/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1869,org.apache.commons.io.FilenameUtils.normalize("C:/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1870,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1871,org.apache.commons.io.FilenameUtils.normalize("C:/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1872,("C:" + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1873,org.apache.commons.io.FilenameUtils.normalize("C:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1874,(("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1875,org.apache.commons.io.FilenameUtils.normalize("C:a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1876,((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1877,org.apache.commons.io.FilenameUtils.normalize("C:a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1878,("C:" + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1879,org.apache.commons.io.FilenameUtils.normalize("C:a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1880,org.apache.commons.io.FilenameUtils.normalize("C:a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1881,(("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1882,org.apache.commons.io.FilenameUtils.normalize("C:a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1883,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1884,org.apache.commons.io.FilenameUtils.normalize("C:a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1885,org.apache.commons.io.FilenameUtils.normalize("C:a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1886,((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1887,org.apache.commons.io.FilenameUtils.normalize("C:a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1888,((((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1889,org.apache.commons.io.FilenameUtils.normalize("C:a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1890,(((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1891,org.apache.commons.io.FilenameUtils.normalize("C:a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1892,("C:" + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1893,org.apache.commons.io.FilenameUtils.normalize("C:./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1894,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1895,org.apache.commons.io.FilenameUtils.normalize("C:./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1896,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1897,org.apache.commons.io.FilenameUtils.normalize("C:."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1898,org.apache.commons.io.FilenameUtils.normalize("C:../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1899,org.apache.commons.io.FilenameUtils.normalize("C:.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1900,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1901,org.apache.commons.io.FilenameUtils.normalize("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1902,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1903,org.apache.commons.io.FilenameUtils.normalize("//server/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1904,((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1905,org.apache.commons.io.FilenameUtils.normalize("//server/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1906,(((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1907,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1908,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1909,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1910,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1911,((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1912,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1913,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1914,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1915,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1916,(((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1917,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1918,(((((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1919,org.apache.commons.io.FilenameUtils.normalize("//server/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1920,((((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1921,org.apache.commons.io.FilenameUtils.normalize("//server/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1922,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1923,org.apache.commons.io.FilenameUtils.normalize("//server/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1924,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1925,org.apache.commons.io.FilenameUtils.normalize("//server/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1926,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1927,org.apache.commons.io.FilenameUtils.normalize("//server/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1928,org.apache.commons.io.FilenameUtils.normalize("//server/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1929,org.apache.commons.io.FilenameUtils.normalize("//server/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1930,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1931,org.apache.commons.io.FilenameUtils.normalize("//server/"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNormalizeUnixWin() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNormalizeUnixWin");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2166,org.apache.commons.io.FilenameUtils.normalize("/a/b/../c/", true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2167,org.apache.commons.io.FilenameUtils.normalize("\\a\\b\\..\\c\\", true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2168,org.apache.commons.io.FilenameUtils.normalize("/a/b/../c/", false));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2169,org.apache.commons.io.FilenameUtils.normalize("\\a\\b\\..\\c\\", false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNormalizeNoEndSeparator() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNormalizeNoEndSeparator");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1932,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1933,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1934,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("1:\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1935,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1936,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1937,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("\\\\\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1938,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("\\\\a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1939,(((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1940,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1941,(((((("" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1942,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1943,(((((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1944,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1945,(((((((((("" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1946,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("\\\\server\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1947,(((((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1948,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1949,(((((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1950,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user\\a\\b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1951,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1952,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1953,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1954,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../../c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1955,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1956,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1957,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1958,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1959,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../../"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1960,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1961,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1962,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1963,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1964,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/../c/../d/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1965,(((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1966,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1967,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1968,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1969,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1970,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("a/b/./././"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1971,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("./a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1972,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1973,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1974,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1975,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1976,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator(".."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1977,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1978,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1979,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1980,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1981,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1982,((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1983,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1984,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1985,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1986,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1987,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1988,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1989,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1990,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1991,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1992,((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1993,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1994,((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1995,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1996,((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1997,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1998,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1999,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2000,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2001,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2002,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2003,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2004,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2005,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2006,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2007,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2008,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2009,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2010,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2011,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2012,(((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2013,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2014,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2015,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2016,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2017,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2018,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2019,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2020,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2021,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2022,(((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2023,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2024,(((((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2025,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2026,(((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2027,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2028,(("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2029,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2030,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2031,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2032,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2033,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2034,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2035,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2036,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2037,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2038,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2039,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2040,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2041,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2042,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2043,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2044,(((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2045,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2046,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2047,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2048,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2049,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2050,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2051,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2052,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2053,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2054,(((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2055,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2056,(((((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2057,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2058,(((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2059,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2060,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2061,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2062,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2063,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2064,(("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2065,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2066,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2067,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2068,("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2069,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2070,("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2071,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2072,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2073,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2074,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2075,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2076,(((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2077,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2078,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2079,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2080,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2081,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2082,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2083,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2084,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2085,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2086,(((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2087,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2088,(((((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2089,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2090,(((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2091,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2092,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2093,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2094,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2095,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2096,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2097,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2098,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2099,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2100,(("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2101,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2102,("C:" + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2103,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2104,("C:" + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2105,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2106,((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2107,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2108,("C:" + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2109,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2110,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2111,("C:" + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2112,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2113,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2114,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2115,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2116,((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2117,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2118,((((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2119,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2120,((("C:" + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2121,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2122,("C:" + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2123,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2124,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2125,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2126,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2127,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2128,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2129,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2130,("C:" + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2131,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2132,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2133,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2134,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2135,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2136,(((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2137,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2138,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2139,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2140,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/../../../c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2141,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2142,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2143,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2144,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2145,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/../../.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2146,(((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2147,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/../c/../d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2148,(((((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2149,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b//d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2150,(((((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2151,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/a/b/././."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2152,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2153,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/./a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2154,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2155,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/./"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2156,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2157,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2158,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/../a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2159,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/.."));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2160,(((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "server") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2161,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("//server/"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNormalizeNoEndSeparatorUnixWin() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNormalizeNoEndSeparatorUnixWin");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2162,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../c/", true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2163,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("\\a\\b\\..\\c\\", true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2164,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("/a/b/../c/", false));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2165,org.apache.commons.io.FilenameUtils.normalizeNoEndSeparator("\\a\\b\\..\\c\\", false));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testConcat() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testConcat");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1305,org.apache.commons.io.FilenameUtils.concat("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1306,org.apache.commons.io.FilenameUtils.concat(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1307,org.apache.commons.io.FilenameUtils.concat(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1308,org.apache.commons.io.FilenameUtils.concat(null, "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1309,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1310,org.apache.commons.io.FilenameUtils.concat(null, "/a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1311,org.apache.commons.io.FilenameUtils.concat("", ":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1312,org.apache.commons.io.FilenameUtils.concat(":", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1313,("f" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1314,org.apache.commons.io.FilenameUtils.concat("", "f/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1315,org.apache.commons.io.FilenameUtils.concat("", "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1316,((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "f") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1317,org.apache.commons.io.FilenameUtils.concat("a/", "f/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1318,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1319,org.apache.commons.io.FilenameUtils.concat("a", "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1320,((((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "f") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1321,org.apache.commons.io.FilenameUtils.concat("a/b/", "f/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1322,(((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "b") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1323,org.apache.commons.io.FilenameUtils.concat("a/b", "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1324,((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "f") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1325,org.apache.commons.io.FilenameUtils.concat("a/b/", "../f/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1326,(("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1327,org.apache.commons.io.FilenameUtils.concat("a/b", "../f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1328,((((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "g") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1329,org.apache.commons.io.FilenameUtils.concat("a/b/../c/", "f/../g/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1330,(((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "g"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1331,org.apache.commons.io.FilenameUtils.concat("a/b/../c", "f/../g"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1332,(((("a" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c.txt") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1333,org.apache.commons.io.FilenameUtils.concat("a/c.txt", "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1334,(((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "f") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1335,org.apache.commons.io.FilenameUtils.concat("", "/f/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1336,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1337,org.apache.commons.io.FilenameUtils.concat("", "/f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1338,(((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "f") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1339,org.apache.commons.io.FilenameUtils.concat("a/", "/f/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1340,((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,org.apache.commons.io.FilenameUtils.concat("a", "/f"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1342,((((org.apache.commons.io.FilenameUtilsTestCase.SEP) + "c") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1343,org.apache.commons.io.FilenameUtils.concat("a/b/", "/c/d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1344,(("C:c" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1345,org.apache.commons.io.FilenameUtils.concat("a/b/", "C:c/d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1346,(((("C:" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1347,org.apache.commons.io.FilenameUtils.concat("a/b/", "C:/c/d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1348,(((("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1349,org.apache.commons.io.FilenameUtils.concat("a/b/", "~/c/d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1350,(((("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "c") + (org.apache.commons.io.FilenameUtilsTestCase.SEP)) + "d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1351,org.apache.commons.io.FilenameUtils.concat("a/b/", "~user/c/d"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1352,("~" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1353,org.apache.commons.io.FilenameUtils.concat("a/b/", "~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1354,("~user" + (org.apache.commons.io.FilenameUtilsTestCase.SEP)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1355,org.apache.commons.io.FilenameUtils.concat("a/b/", "~user"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSeparatorsToUnix() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSeparatorsToUnix");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2195,org.apache.commons.io.FilenameUtils.separatorsToUnix(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2196,org.apache.commons.io.FilenameUtils.separatorsToUnix("/a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2197,org.apache.commons.io.FilenameUtils.separatorsToUnix("/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2198,org.apache.commons.io.FilenameUtils.separatorsToUnix("/a/b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2199,org.apache.commons.io.FilenameUtils.separatorsToUnix("\\a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2200,org.apache.commons.io.FilenameUtils.separatorsToUnix("D:\\a\\b\\c"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSeparatorsToWindows() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSeparatorsToWindows");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2201,org.apache.commons.io.FilenameUtils.separatorsToWindows(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2202,org.apache.commons.io.FilenameUtils.separatorsToWindows("\\a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2203,org.apache.commons.io.FilenameUtils.separatorsToWindows("\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2204,org.apache.commons.io.FilenameUtils.separatorsToWindows("\\a\\b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2205,org.apache.commons.io.FilenameUtils.separatorsToWindows("/a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2206,org.apache.commons.io.FilenameUtils.separatorsToWindows("D:/a/b/c"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSeparatorsToSystem() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSeparatorsToSystem");
            if (WINDOWS) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2183,org.apache.commons.io.FilenameUtils.separatorsToSystem(null));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2184,org.apache.commons.io.FilenameUtils.separatorsToSystem("\\a\\b\\c"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2185,org.apache.commons.io.FilenameUtils.separatorsToSystem("\\a\\b\\c.txt"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2186,org.apache.commons.io.FilenameUtils.separatorsToSystem("\\a\\b/c"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2187,org.apache.commons.io.FilenameUtils.separatorsToSystem("/a/b/c"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2188,org.apache.commons.io.FilenameUtils.separatorsToSystem("D:/a/b/c"));
            } else {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2189,org.apache.commons.io.FilenameUtils.separatorsToSystem(null));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2190,org.apache.commons.io.FilenameUtils.separatorsToSystem("/a/b/c"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2191,org.apache.commons.io.FilenameUtils.separatorsToSystem("/a/b/c.txt"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2192,org.apache.commons.io.FilenameUtils.separatorsToSystem("/a/b\\c"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2193,org.apache.commons.io.FilenameUtils.separatorsToSystem("\\a\\b\\c"));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2194,org.apache.commons.io.FilenameUtils.separatorsToSystem("D:\\a\\b\\c"));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetPrefixLength() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetPrefixLength");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1556,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1557,org.apache.commons.io.FilenameUtils.getPrefixLength(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1558,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1559,org.apache.commons.io.FilenameUtils.getPrefixLength(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1560,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1561,org.apache.commons.io.FilenameUtils.getPrefixLength("1:\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1562,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1563,org.apache.commons.io.FilenameUtils.getPrefixLength("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1564,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1565,org.apache.commons.io.FilenameUtils.getPrefixLength("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1566,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1567,org.apache.commons.io.FilenameUtils.getPrefixLength("\\\\\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1568,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1569,org.apache.commons.io.FilenameUtils.getPrefixLength("\\\\a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1570,org.apache.commons.io.FilenameUtils.getPrefixLength(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1571,org.apache.commons.io.FilenameUtils.getPrefixLength("\\"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1572,org.apache.commons.io.FilenameUtils.getPrefixLength("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1573,org.apache.commons.io.FilenameUtils.getPrefixLength("C:\\"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1574,org.apache.commons.io.FilenameUtils.getPrefixLength("//server/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1575,org.apache.commons.io.FilenameUtils.getPrefixLength("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1576,org.apache.commons.io.FilenameUtils.getPrefixLength("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1577,org.apache.commons.io.FilenameUtils.getPrefixLength("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1578,org.apache.commons.io.FilenameUtils.getPrefixLength("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1579,org.apache.commons.io.FilenameUtils.getPrefixLength("a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,org.apache.commons.io.FilenameUtils.getPrefixLength("\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,org.apache.commons.io.FilenameUtils.getPrefixLength("C:a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,org.apache.commons.io.FilenameUtils.getPrefixLength("C:\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,org.apache.commons.io.FilenameUtils.getPrefixLength("\\\\server\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,org.apache.commons.io.FilenameUtils.getPrefixLength("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,org.apache.commons.io.FilenameUtils.getPrefixLength("/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,org.apache.commons.io.FilenameUtils.getPrefixLength("C:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,org.apache.commons.io.FilenameUtils.getPrefixLength("//server/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,org.apache.commons.io.FilenameUtils.getPrefixLength("~/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,org.apache.commons.io.FilenameUtils.getPrefixLength("~user/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,org.apache.commons.io.FilenameUtils.getPrefixLength("a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,org.apache.commons.io.FilenameUtils.getPrefixLength("\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,org.apache.commons.io.FilenameUtils.getPrefixLength("~\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,org.apache.commons.io.FilenameUtils.getPrefixLength("~user\\a\\b\\c.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIndexOfLastSeparator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfLastSeparator");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,org.apache.commons.io.FilenameUtils.indexOfLastSeparator(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1610,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1611,org.apache.commons.io.FilenameUtils.indexOfLastSeparator("noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1612,org.apache.commons.io.FilenameUtils.indexOfLastSeparator("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1613,org.apache.commons.io.FilenameUtils.indexOfLastSeparator("a\\b\\c"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIndexOfExtension() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIndexOfExtension");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1594,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1595,org.apache.commons.io.FilenameUtils.indexOfExtension(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1596,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1597,org.apache.commons.io.FilenameUtils.indexOfExtension("file"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1598,org.apache.commons.io.FilenameUtils.indexOfExtension("file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1599,org.apache.commons.io.FilenameUtils.indexOfExtension("a.txt/b.txt/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1600,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1601,org.apache.commons.io.FilenameUtils.indexOfExtension("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1602,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1603,org.apache.commons.io.FilenameUtils.indexOfExtension("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1604,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1605,org.apache.commons.io.FilenameUtils.indexOfExtension("a/b.notextension/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1606,-1);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1607,org.apache.commons.io.FilenameUtils.indexOfExtension("a\\b.notextension\\c"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetPrefix() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetPrefix");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1526,org.apache.commons.io.FilenameUtils.getPrefix(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1527,org.apache.commons.io.FilenameUtils.getPrefix(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1528,org.apache.commons.io.FilenameUtils.getPrefix("1:\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1529,org.apache.commons.io.FilenameUtils.getPrefix("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1530,org.apache.commons.io.FilenameUtils.getPrefix("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1531,org.apache.commons.io.FilenameUtils.getPrefix("\\\\\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1532,org.apache.commons.io.FilenameUtils.getPrefix("\\\\a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1533,org.apache.commons.io.FilenameUtils.getPrefix(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1534,org.apache.commons.io.FilenameUtils.getPrefix("\\"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1535,org.apache.commons.io.FilenameUtils.getPrefix("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1536,org.apache.commons.io.FilenameUtils.getPrefix("C:\\"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1537,org.apache.commons.io.FilenameUtils.getPrefix("//server/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1538,org.apache.commons.io.FilenameUtils.getPrefix("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1539,org.apache.commons.io.FilenameUtils.getPrefix("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1540,org.apache.commons.io.FilenameUtils.getPrefix("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1541,org.apache.commons.io.FilenameUtils.getPrefix("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1542,org.apache.commons.io.FilenameUtils.getPrefix("a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1543,org.apache.commons.io.FilenameUtils.getPrefix("\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1544,org.apache.commons.io.FilenameUtils.getPrefix("C:\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1545,org.apache.commons.io.FilenameUtils.getPrefix("\\\\server\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1546,org.apache.commons.io.FilenameUtils.getPrefix("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1547,org.apache.commons.io.FilenameUtils.getPrefix("/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1548,org.apache.commons.io.FilenameUtils.getPrefix("C:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1549,org.apache.commons.io.FilenameUtils.getPrefix("//server/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1550,org.apache.commons.io.FilenameUtils.getPrefix("~/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1551,org.apache.commons.io.FilenameUtils.getPrefix("~user/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1552,org.apache.commons.io.FilenameUtils.getPrefix("a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1553,org.apache.commons.io.FilenameUtils.getPrefix("\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1554,org.apache.commons.io.FilenameUtils.getPrefix("~\\a\\b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1555,org.apache.commons.io.FilenameUtils.getPrefix("~user\\a\\b\\c.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetPath() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetPath");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1466,org.apache.commons.io.FilenameUtils.getPath(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1467,org.apache.commons.io.FilenameUtils.getPath("noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1468,org.apache.commons.io.FilenameUtils.getPath("/noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1469,org.apache.commons.io.FilenameUtils.getPath("\\noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1470,org.apache.commons.io.FilenameUtils.getPath("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1471,org.apache.commons.io.FilenameUtils.getPath("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1472,org.apache.commons.io.FilenameUtils.getPath("a/b/c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1473,org.apache.commons.io.FilenameUtils.getPath("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1474,org.apache.commons.io.FilenameUtils.getPath(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1475,org.apache.commons.io.FilenameUtils.getPath("1:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1476,org.apache.commons.io.FilenameUtils.getPath("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1477,org.apache.commons.io.FilenameUtils.getPath("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1478,org.apache.commons.io.FilenameUtils.getPath("///a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1479,org.apache.commons.io.FilenameUtils.getPath("//a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1480,org.apache.commons.io.FilenameUtils.getPath(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1481,org.apache.commons.io.FilenameUtils.getPath("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1482,org.apache.commons.io.FilenameUtils.getPath("C:/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1483,org.apache.commons.io.FilenameUtils.getPath("//server/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1484,org.apache.commons.io.FilenameUtils.getPath("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1485,org.apache.commons.io.FilenameUtils.getPath("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1486,org.apache.commons.io.FilenameUtils.getPath("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1487,org.apache.commons.io.FilenameUtils.getPath("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1488,org.apache.commons.io.FilenameUtils.getPath("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1489,org.apache.commons.io.FilenameUtils.getPath("/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1490,org.apache.commons.io.FilenameUtils.getPath("C:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1491,org.apache.commons.io.FilenameUtils.getPath("C:a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1492,org.apache.commons.io.FilenameUtils.getPath("C:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1493,org.apache.commons.io.FilenameUtils.getPath("//server/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1494,org.apache.commons.io.FilenameUtils.getPath("~/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1495,org.apache.commons.io.FilenameUtils.getPath("~user/a/b/c.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetPathNoEndSeparator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetPathNoEndSeparator");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1496,org.apache.commons.io.FilenameUtils.getPath(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1497,org.apache.commons.io.FilenameUtils.getPath("noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1498,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("/noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1499,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("\\noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1500,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1501,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1502,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("a/b/c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1503,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1504,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1505,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("1:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1506,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1507,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1508,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("///a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1509,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("//a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1510,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1511,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1512,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("C:/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1513,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("//server/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1514,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1515,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1517,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1518,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1519,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1520,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("C:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1521,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("C:a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1522,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("C:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1523,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("//server/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1524,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("~/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1525,org.apache.commons.io.FilenameUtils.getPathNoEndSeparator("~user/a/b/c.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetFullPath() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetFullPath");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1398,org.apache.commons.io.FilenameUtils.getFullPath(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1399,org.apache.commons.io.FilenameUtils.getFullPath("noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1400,org.apache.commons.io.FilenameUtils.getFullPath("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1401,org.apache.commons.io.FilenameUtils.getFullPath("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1402,org.apache.commons.io.FilenameUtils.getFullPath("a/b/c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1403,org.apache.commons.io.FilenameUtils.getFullPath("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1404,org.apache.commons.io.FilenameUtils.getFullPath(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1405,org.apache.commons.io.FilenameUtils.getFullPath("1:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1406,org.apache.commons.io.FilenameUtils.getFullPath("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1407,org.apache.commons.io.FilenameUtils.getFullPath("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1408,org.apache.commons.io.FilenameUtils.getFullPath("///a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1409,org.apache.commons.io.FilenameUtils.getFullPath("//a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1410,org.apache.commons.io.FilenameUtils.getFullPath(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1411,org.apache.commons.io.FilenameUtils.getFullPath("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1412,org.apache.commons.io.FilenameUtils.getFullPath("C:/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1413,org.apache.commons.io.FilenameUtils.getFullPath("//server/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1414,org.apache.commons.io.FilenameUtils.getFullPath("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1415,org.apache.commons.io.FilenameUtils.getFullPath("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1416,org.apache.commons.io.FilenameUtils.getFullPath("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1417,org.apache.commons.io.FilenameUtils.getFullPath("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1418,org.apache.commons.io.FilenameUtils.getFullPath("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1419,org.apache.commons.io.FilenameUtils.getFullPath("/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1420,org.apache.commons.io.FilenameUtils.getFullPath("C:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1421,org.apache.commons.io.FilenameUtils.getFullPath("C:a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1422,org.apache.commons.io.FilenameUtils.getFullPath("C:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1423,org.apache.commons.io.FilenameUtils.getFullPath("//server/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1424,org.apache.commons.io.FilenameUtils.getFullPath("~/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1425,org.apache.commons.io.FilenameUtils.getFullPath("~user/a/b/c.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetFullPathNoEndSeparator() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetFullPathNoEndSeparator");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1426,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1427,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1428,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1429,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1430,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("a/b/c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1431,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1432,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator(":"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1433,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("1:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1434,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("1:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1435,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("1:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1436,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("///a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1437,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("//a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1438,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator(""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1439,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("C:"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1440,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("C:/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1441,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("//server/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1442,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("~"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1443,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("~/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1444,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("~user"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1445,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("~user/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1446,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1447,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1448,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("C:a"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1449,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("C:a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1450,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("C:/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1451,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("//server/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1452,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("~/a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1453,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("~user/a/b/c.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-248
     */
public void testGetFullPathNoEndSeparator_IO_248() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetFullPathNoEndSeparator_IO_248");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1454,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1455,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("\\"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1456,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("/abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1457,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("\\abc"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1458,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("/abc/xyz"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1459,org.apache.commons.io.FilenameUtils.getFullPathNoEndSeparator("\\abc\\xyz"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetName() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetName");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1460,org.apache.commons.io.FilenameUtils.getName(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1461,org.apache.commons.io.FilenameUtils.getName("noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1462,org.apache.commons.io.FilenameUtils.getName("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1463,org.apache.commons.io.FilenameUtils.getName("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1464,org.apache.commons.io.FilenameUtils.getName("a/b/c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1465,org.apache.commons.io.FilenameUtils.getName("a\\b\\c"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetBaseName() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetBaseName");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1378,org.apache.commons.io.FilenameUtils.getBaseName(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1379,org.apache.commons.io.FilenameUtils.getBaseName("noseperator.inthispath"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1380,org.apache.commons.io.FilenameUtils.getBaseName("a/b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1381,org.apache.commons.io.FilenameUtils.getBaseName("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1382,org.apache.commons.io.FilenameUtils.getBaseName("a/b/c/"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1383,org.apache.commons.io.FilenameUtils.getBaseName("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1384,org.apache.commons.io.FilenameUtils.getBaseName("file.txt.bak"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testGetExtension() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testGetExtension");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1385,org.apache.commons.io.FilenameUtils.getExtension(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1386,org.apache.commons.io.FilenameUtils.getExtension("file.ext"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1387,org.apache.commons.io.FilenameUtils.getExtension("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1388,org.apache.commons.io.FilenameUtils.getExtension("domain.dot.com"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1389,org.apache.commons.io.FilenameUtils.getExtension("image.jpeg"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1390,org.apache.commons.io.FilenameUtils.getExtension("a.b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1391,org.apache.commons.io.FilenameUtils.getExtension("a.b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1392,org.apache.commons.io.FilenameUtils.getExtension("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1393,org.apache.commons.io.FilenameUtils.getExtension("a.b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1394,org.apache.commons.io.FilenameUtils.getExtension("a.b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1395,org.apache.commons.io.FilenameUtils.getExtension("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1396,org.apache.commons.io.FilenameUtils.getExtension("C:\\temp\\foo.bar\\README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1397,org.apache.commons.io.FilenameUtils.getExtension("../filename.ext"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRemoveExtension() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRemoveExtension");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2170,org.apache.commons.io.FilenameUtils.removeExtension(null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2171,org.apache.commons.io.FilenameUtils.removeExtension("file.ext"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2172,org.apache.commons.io.FilenameUtils.removeExtension("README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2173,org.apache.commons.io.FilenameUtils.removeExtension("domain.dot.com"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2174,org.apache.commons.io.FilenameUtils.removeExtension("image.jpeg"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2175,org.apache.commons.io.FilenameUtils.removeExtension("a.b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2176,org.apache.commons.io.FilenameUtils.removeExtension("a.b/c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2177,org.apache.commons.io.FilenameUtils.removeExtension("a/b/c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2178,org.apache.commons.io.FilenameUtils.removeExtension("a.b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2179,org.apache.commons.io.FilenameUtils.removeExtension("a.b\\c.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2180,org.apache.commons.io.FilenameUtils.removeExtension("a\\b\\c"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2181,org.apache.commons.io.FilenameUtils.removeExtension("C:\\temp\\foo.bar\\README"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2182,org.apache.commons.io.FilenameUtils.removeExtension("../filename.ext"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEqualsOnSystem() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsOnSystem");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1365,org.apache.commons.io.FilenameUtils.equalsOnSystem(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1366,org.apache.commons.io.FilenameUtils.equalsOnSystem(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1367,org.apache.commons.io.FilenameUtils.equalsOnSystem("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1368,org.apache.commons.io.FilenameUtils.equalsOnSystem("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1369,org.apache.commons.io.FilenameUtils.equalsOnSystem("file.txt", "file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1370,org.apache.commons.io.FilenameUtilsTestCase.WINDOWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1371,org.apache.commons.io.FilenameUtils.equalsOnSystem("file.txt", "FILE.TXT"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1372,org.apache.commons.io.FilenameUtils.equalsOnSystem("a\\b\\file.txt", "a/b/file.txt"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEqualsNormalizedOnSystem() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedOnSystem");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1356,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem(null, null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1357,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem(null, ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1358,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("", null));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1359,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1360,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1361,org.apache.commons.io.FilenameUtilsTestCase.WINDOWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1362,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "FILE.TXT"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1363,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("a\\b\\file.txt", "a/b/file.txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1364,org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("a/b/", "a/b"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
@Test(timeout = 1000)
    public void testEqualsNormalizedError_IO_128_add424() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_add424");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
@Test(timeout = 1000)
    public void testEqualsNormalizedError_IO_128_add425() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_add425");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
@Test(timeout = 1000)
    public void testEqualsNormalizedError_IO_128_add426() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_add426");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEquals() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEquals");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("+/file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalized() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalized");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//fi©le.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1880() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1880");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//fle.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1881() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1881");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.Âxt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1882() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1882");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "fileL.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1883() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1883");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.tt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1884() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1884");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.xt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1885() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1885");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("fileÎ.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1886() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1886");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("filetxt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1887() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1887");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//oile.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1888() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1888");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//fileÍ.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1889() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1889");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "/file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1890() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1890");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//fiÎe.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1891() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1891");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.twxt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1892() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1892");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//fle.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1893() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1893");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//fïle.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1894() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1894");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for https://issues.apache.org/jira/browse/IO-128
     */
public void testEqualsNormalizedError_IO_128_literalMutation1895() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEqualsNormalizedError_IO_128_literalMutation1895");
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("file.txt", "//file.txt");
            } catch (NullPointerException e) {
            }
            try {
                org.apache.commons.io.FilenameUtils.equalsNormalizedOnSystem("//file.txt", "//fil.txt");
            } catch (NullPointerException e) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEquals_fullControl() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEquals_fullControl");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1373,org.apache.commons.io.FilenameUtils.equals("file.txt", "FILE.TXT", true, org.apache.commons.io.IOCase.SENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1374,org.apache.commons.io.FilenameUtils.equals("file.txt", "FILE.TXT", true, org.apache.commons.io.IOCase.INSENSITIVE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1375,org.apache.commons.io.FilenameUtilsTestCase.WINDOWS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1376,org.apache.commons.io.FilenameUtils.equals("file.txt", "FILE.TXT", true, org.apache.commons.io.IOCase.SYSTEM));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1377,org.apache.commons.io.FilenameUtils.equals("file.txt", "FILE.TXT", true, null));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIsExtension() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsExtension");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1614,org.apache.commons.io.FilenameUtils.isExtension(null, ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1615,org.apache.commons.io.FilenameUtils.isExtension("file.txt", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1616,org.apache.commons.io.FilenameUtils.isExtension("file", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1617,org.apache.commons.io.FilenameUtils.isExtension("file.txt", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1618,org.apache.commons.io.FilenameUtils.isExtension("file", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1619,org.apache.commons.io.FilenameUtils.isExtension("file.txt", "txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1620,org.apache.commons.io.FilenameUtils.isExtension("file.txt", "rtf"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1621,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1622,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1623,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", "txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1624,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", "rtf"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1625,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1626,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1627,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", "txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1628,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", "rtf"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1629,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1630,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1631,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", "txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1632,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", "rtf"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1633,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", ((java.lang.String)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1634,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", ""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1635,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", "txt"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1636,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", "rtf"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1637,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", "TXT"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIsExtensionArray() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsExtensionArray");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1638,org.apache.commons.io.FilenameUtils.isExtension(null, ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1639,org.apache.commons.io.FilenameUtils.isExtension("file.txt", ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,org.apache.commons.io.FilenameUtils.isExtension("file", ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.lang.String[]{ "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.lang.String[]{ "rtf" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,org.apache.commons.io.FilenameUtils.isExtension("file", new java.lang.String[]{ "rtf" , "" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.lang.String[]{ "rtf" , "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1647,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1648,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.lang.String[]{ "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1649,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.lang.String[]{ "rtf" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1650,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.lang.String[]{ "rtf" , "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1651,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1652,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1653,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.lang.String[]{ "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1654,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.lang.String[]{ "rtf" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1655,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.lang.String[]{ "rtf" , "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1656,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.lang.String[]{ "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1659,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.lang.String[]{ "rtf" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1660,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.lang.String[]{ "rtf" , "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1661,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", ((java.lang.String[])(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1662,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.lang.String[0]));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1663,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.lang.String[]{ "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1664,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.lang.String[]{ "rtf" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1665,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.lang.String[]{ "rtf" , "txt" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1666,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.lang.String[]{ "TXT" }));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1667,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.lang.String[]{ "TXT" , "RTF" }));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testIsExtensionCollection() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testIsExtensionCollection");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1668,org.apache.commons.io.FilenameUtils.isExtension(null, ((java.util.Collection<java.lang.String>)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1669,org.apache.commons.io.FilenameUtils.isExtension("file.txt", ((java.util.Collection<java.lang.String>)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1670,org.apache.commons.io.FilenameUtils.isExtension("file", ((java.util.Collection<java.lang.String>)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1671,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.util.ArrayList<java.lang.String>()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,org.apache.commons.io.FilenameUtils.isExtension("file", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" , "" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1675,org.apache.commons.io.FilenameUtils.isExtension("file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" , "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1676,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", ((java.util.Collection<java.lang.String>)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1677,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.util.ArrayList<java.lang.String>()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1678,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1679,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,org.apache.commons.io.FilenameUtils.isExtension("a/b/file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" , "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", ((java.util.Collection<java.lang.String>)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.util.ArrayList<java.lang.String>()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1685,org.apache.commons.io.FilenameUtils.isExtension("a.b/file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" , "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1686,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", ((java.util.Collection<java.lang.String>)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1687,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.util.ArrayList<java.lang.String>()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1688,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1689,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1690,org.apache.commons.io.FilenameUtils.isExtension("a\\b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" , "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1691,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", ((java.util.Collection<java.lang.String>)(null))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1692,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.util.ArrayList<java.lang.String>()));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1693,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1694,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1695,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "rtf" , "txt" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "TXT" }))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,org.apache.commons.io.FilenameUtils.isExtension("a.b\\file.txt", new java.util.ArrayList<java.lang.String>(java.util.Arrays.asList(new java.lang.String[]{ "TXT" , "RTF" }))));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }
}

