package com.google.gson.functional;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.BitSet;
import java.util.Calendar;
import java.lang.reflect.Constructor;
import java.util.Date;
import java.util.GregorianCalendar;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import java.util.HashSet;
import java.io.IOException;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import com.google.gson.stream.JsonReader;
import com.google.gson.stream.JsonWriter;
import java.util.List;
import java.util.Locale;
import java.util.Properties;
import org.junit.Test;
import junit.framework.TestCase;
import java.sql.Time;
import java.util.TimeZone;
import java.sql.Timestamp;
import java.util.TreeSet;
import java.lang.reflect.Type;
import com.google.gson.TypeAdapter;
import com.google.gson.reflect.TypeToken;
import java.net.URI;
import java.net.URL;
import java.util.UUID;

/** 
 * Functional test for Json serialization and deserialization for common classes for which default
 * support is provided in Gson. The tests for Map types are available in {@link MapTest}.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class DefaultTypeAdaptersTest extends TestCase {
    private Gson gson;

    private TimeZone oldTimeZone;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        this.oldTimeZone = TimeZone.getDefault();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),474,this.oldTimeZone);
        TimeZone.setDefault(TimeZone.getTimeZone("America/Los_Angeles"));
        Locale.setDefault(Locale.US);
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),475,gson);
    }

    @Override
    protected void tearDown() throws Exception {
        TimeZone.setDefault(oldTimeZone);
        super.tearDown();
    }

    @Test(timeout = 1000)
    public void testClassSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassSerialization");
            try {
                gson.toJson(String.class);
                gson.toJson(String.class);
            } catch (UnsupportedOperationException expected) {
            }
            gson = new GsonBuilder().registerTypeAdapter(Class.class, new MyClassTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),514,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),513,gson.toJson(java.lang.String.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testClassDeserialization_add93() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassDeserialization_add93");
            try {
                gson.fromJson("String.class", String.class.getClass());
                gson.fromJson("String.class", String.class.getClass());
            } catch (UnsupportedOperationException expected) {
            }
            gson = new GsonBuilder().registerTypeAdapter(Class.class, new MyClassTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,java.lang.String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,gson.fromJson("java.lang.String", java.lang.Class.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassDeserialization");
            try {
                gson.fromJson("String.,lass", String.class.getClass());
            } catch (UnsupportedOperationException expected) {
            }
            gson = new GsonBuilder().registerTypeAdapter(Class.class, new MyClassTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,java.lang.String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,gson.fromJson("java.lang.String", java.lang.Class.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassDeserialization_literalMutation955() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassDeserialization_literalMutation955");
            try {
                gson.fromJson("StrØing.class", String.class.getClass());
            } catch (UnsupportedOperationException expected) {
            }
            gson = new GsonBuilder().registerTypeAdapter(Class.class, new MyClassTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,java.lang.String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,gson.fromJson("java.lang.String", java.lang.Class.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassDeserialization_literalMutation956() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassDeserialization_literalMutation956");
            try {
                gson.fromJson("Strin.class", String.class.getClass());
            } catch (UnsupportedOperationException expected) {
            }
            gson = new GsonBuilder().registerTypeAdapter(Class.class, new MyClassTypeAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),512,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),510,java.lang.String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),511,gson.fromJson("java.lang.String", java.lang.Class.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSerialization");
            String urlValue = "http://go\ngle.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,urlValue);
            URL url = new URL(urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,url);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,gson.toJson(url));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlSerialization_literalMutation1273() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSerialization_literalMutation1273");
            String urlValue = "http://go¯ogle.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,urlValue);
            URL url = new URL(urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,url);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,gson.toJson(url));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlSerialization_literalMutation1274() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlSerialization_literalMutation1274");
            String urlValue = "htp://google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),745,urlValue);
            URL url = new URL(urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),746,url);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),744,gson.toJson(url));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testUrlDeserialization_add161() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization_add161");
            String urlValue = "http://google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'http:\\/\\/google.com\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization");
            String urlValue = "http://googleÐcom/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'http:\\/\\/google.com\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlDeserialization_literalMutation1265() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization_literalMutation1265");
            String urlValue = "http://goog]le.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'http:\\/\\/google.com\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlDeserialization_literalMutation1266() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization_literalMutation1266");
            String urlValue = "http://google.co/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'http:\\/\\/google.com\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlDeserialization_literalMutation1267() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization_literalMutation1267");
            String urlValue = "http://google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'htFp:\\/\\/google.com\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlDeserialization_literalMutation1268() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization_literalMutation1268");
            String urlValue = "http://google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'http:\\/\\/google.µcom\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlDeserialization_literalMutation1269() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization_literalMutation1269");
            String urlValue = "http://google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'htt:\\/\\/google.com\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            gson.fromJson((('\"' + urlValue) + '\"'), URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testUrlDeserialization_remove151() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlDeserialization_remove151");
            String urlValue = "http://google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),737,urlValue);
            String json = "\'http:\\/\\/google.com\\/\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),200,json);
            URL target = gson.fromJson(json, URL.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),738,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),733,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),734,target.toExternalForm());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),735,urlValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),736,target.toExternalForm());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlNullSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlNullSerialization");
            ClassWithUrlField target = new ClassWithUrlField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),743,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),742,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUrlNullDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUrlNullDeserialization");
            String json = "{}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,json);
            ClassWithUrlField target = gson.fromJson(json, ClassWithUrlField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),739,target.url);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithUrlField {
        URL url;
    }

    public void testUriSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUriSerialization");
            String uriValue = "http://goÎgle.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),731,uriValue);
            URI uri = new URI(uriValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),732,uri);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),730,gson.toJson(uri));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUriSerialization_literalMutation1262() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUriSerialization_literalMutation1262");
            String uriValue = "http://goêogle.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),731,uriValue);
            URI uri = new URI(uriValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),732,uri);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),730,gson.toJson(uri));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUriSerialization_literalMutation1263() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUriSerialization_literalMutation1263");
            String uriValue = "http//google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),731,uriValue);
            URI uri = new URI(uriValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),732,uri);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),730,gson.toJson(uri));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUriDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUriDeserialization");
            String uriValue = "http://googl<.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),729,uriValue);
            String json = ('\"' + uriValue) + '\"';
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            URI target = gson.fromJson(json, URI.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),727,uriValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),728,target.toASCIIString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUriDeserialization_literalMutation1257() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUriDeserialization_literalMutation1257");
            String uriValue = "http:u//google.com/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),729,uriValue);
            String json = ('\"' + uriValue) + '\"';
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            URI target = gson.fromJson(json, URI.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),727,uriValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),728,target.toASCIIString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUriDeserialization_literalMutation1258() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUriDeserialization_literalMutation1258");
            String uriValue = "http://google.co/";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),729,uriValue);
            String json = ('\"' + uriValue) + '\"';
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),445,json);
            URI target = gson.fromJson(json, URI.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),184,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),727,uriValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),728,target.toASCIIString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add118() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add118");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add119() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add119");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add120() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add120");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add121() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add121");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add122() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add122");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add123() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add123");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add124() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add124");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add125() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add125");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add126() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add126");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add127() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add127");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add128() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add128");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add129() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add129");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add130() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add130");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add131() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add131");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add132() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add132");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add133() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add133");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add134() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add134");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add135() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add135");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add136() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add136");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add137() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add137");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add138() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add138");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add139() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add139");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add140() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add140");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add141() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add141");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add142() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add142");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add143() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add143");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add144() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add144");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add145() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add145");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add146() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add146");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add147() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add147");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_add148() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_add148");
            testNullSerializationAndDeserialization(java.lang.Boolean.class);
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove111() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove111");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove112() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove112");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove113() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove113");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove114() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove114");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove115() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove115");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove116() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove116");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove117() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove117");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove118() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove118");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove119() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove119");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove120() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove120");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove121() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove121");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove122() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove122");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove123() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove123");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove124() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove124");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove125() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove125");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove126() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove126");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove127() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove127");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove128() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove128");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove129() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove129");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove130() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove130");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove131() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove131");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove132() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove132");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove133() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove133");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove134() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove134");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove135() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove135");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove136() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove136");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove137() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove137");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove138() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove138");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove139() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove139");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove140() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove140");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove141() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove141");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testNullSerialization_remove142() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization_remove142");
            testNullSerializationAndDeserialization(java.lang.Byte.class);
            testNullSerializationAndDeserialization(java.lang.Short.class);
            testNullSerializationAndDeserialization(java.lang.Integer.class);
            testNullSerializationAndDeserialization(java.lang.Long.class);
            testNullSerializationAndDeserialization(java.lang.Double.class);
            testNullSerializationAndDeserialization(java.lang.Float.class);
            testNullSerializationAndDeserialization(Number.class);
            testNullSerializationAndDeserialization(java.lang.Character.class);
            testNullSerializationAndDeserialization(String.class);
            testNullSerializationAndDeserialization(StringBuilder.class);
            testNullSerializationAndDeserialization(StringBuffer.class);
            testNullSerializationAndDeserialization(BigDecimal.class);
            testNullSerializationAndDeserialization(BigInteger.class);
            testNullSerializationAndDeserialization(TreeSet.class);
            testNullSerializationAndDeserialization(java.util.ArrayList.class);
            testNullSerializationAndDeserialization(HashSet.class);
            testNullSerializationAndDeserialization(Properties.class);
            testNullSerializationAndDeserialization(URL.class);
            testNullSerializationAndDeserialization(URI.class);
            testNullSerializationAndDeserialization(UUID.class);
            testNullSerializationAndDeserialization(Locale.class);
            testNullSerializationAndDeserialization(java.net.InetAddress.class);
            testNullSerializationAndDeserialization(BitSet.class);
            testNullSerializationAndDeserialization(Date.class);
            testNullSerializationAndDeserialization(GregorianCalendar.class);
            testNullSerializationAndDeserialization(Calendar.class);
            testNullSerializationAndDeserialization(Time.class);
            testNullSerializationAndDeserialization(Timestamp.class);
            testNullSerializationAndDeserialization(java.sql.Date.class);
            testNullSerializationAndDeserialization(java.lang.Enum.class);
            testNullSerializationAndDeserialization(Class.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void testNullSerializationAndDeserialization(Class<?> c) {
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),672,gson.toJson(null, c));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),673,gson.fromJson("null", c));
    }

    public void testUuidSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUuidSerialization");
            String uuidValue = "c237bec1-19ef-458-a98e-521cf0aad4c0";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,uuidValue);
            UUID uuid = UUID.fromString(uuidValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,uuid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,(('\"' + uuidValue) + '\"'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,gson.toJson(uuid));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUuidSerialization_literalMutation1281() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUuidSerialization_literalMutation1281");
            String uuidValue = "c237bec1-19ef-4858-a98e-5$21cf0aad4c0";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,uuidValue);
            UUID uuid = UUID.fromString(uuidValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,uuid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,(('\"' + uuidValue) + '\"'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,gson.toJson(uuid));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUuidSerialization_literalMutation1282() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUuidSerialization_literalMutation1282");
            String uuidValue = "c237bec1-19ef-4858-98e-521cf0aad4c0";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),754,uuidValue);
            UUID uuid = UUID.fromString(uuidValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),755,uuid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),752,(('\"' + uuidValue) + '\"'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),753,gson.toJson(uuid));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUuidDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUuidDeserialization");
            String uuidValue = "c237bec1-19eV-4858-a98e-521cf0aad4c0";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,uuidValue);
            String json = ('\"' + uuidValue) + '\"';
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,json);
            UUID target = gson.fromJson(json, UUID.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,uuidValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,target.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUuidDeserialization_literalMutation1276() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUuidDeserialization_literalMutation1276");
            String uuidValue = "c237bec1N-19ef-4858-a98e-521cf0aad4c0";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,uuidValue);
            String json = ('\"' + uuidValue) + '\"';
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,json);
            UUID target = gson.fromJson(json, UUID.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,uuidValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,target.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testUuidDeserialization_literalMutation1277() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testUuidDeserialization_literalMutation1277");
            String uuidValue = "c237bec1-19ef-4858-a98e521cf0aad4c0";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),749,uuidValue);
            String json = ('\"' + uuidValue) + '\"';
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,json);
            UUID target = gson.fromJson(json, UUID.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),747,uuidValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),748,target.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleSerializationWithLanguage() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleSerializationWithLanguage");
            Locale target = new Locale("en");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),664,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),663,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguage() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguage");
            String json = "\"en\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),661,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),662,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),660,locale.getLanguage());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguage_literalMutation1195() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguage_literalMutation1195");
            String json = "\"eJn\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),661,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),662,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),660,locale.getLanguage());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguage_literalMutation1196() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguage_literalMutation1196");
            String json = "\"e\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),661,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),662,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),660,locale.getLanguage());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleSerializationWithLanguageCountry() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleSerializationWithLanguageCountry");
            Locale target = Locale.CANADA_FRENCH;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),666,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),665,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguageCountry() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguageCountry");
            String json = "\"fr_A\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),658,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),659,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),656,java.util.Locale.CANADA_FRENCH);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),657,locale);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguageCountry_literalMutation1198() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguageCountry_literalMutation1198");
            String json = "\"frE_CA\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),658,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),659,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),656,java.util.Locale.CANADA_FRENCH);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),657,locale);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguageCountry_literalMutation1199() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguageCountry_literalMutation1199");
            String json = "\"fr_A\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),658,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),659,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),656,java.util.Locale.CANADA_FRENCH);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),657,locale);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleSerializationWithLanguageCountryVariant() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleSerializationWithLanguageCountryVariant");
            Locale target = new Locale("de" , "DE" , "EURO");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),668,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),669,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),667,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguageCountryVariant() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguageCountryVariant");
            String json = "\"de_DE_EU¤O\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),654,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),655,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),651,locale.getLanguage());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),652,locale.getCountry());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),653,locale.getVariant());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguageCountryVariant_literalMutation1201() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguageCountryVariant_literalMutation1201");
            String json = "\"de_D*E_EURO\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),654,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),655,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),651,locale.getLanguage());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),652,locale.getCountry());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),653,locale.getVariant());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testLocaleDeserializationWithLanguageCountryVariant_literalMutation1202() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testLocaleDeserializationWithLanguageCountryVariant_literalMutation1202");
            String json = "\"de_DE_URO\"";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),654,json);
            Locale locale = gson.fromJson(json, Locale.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),655,locale);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),651,locale.getLanguage());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),652,locale.getCountry());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),653,locale.getVariant());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldSerialization");
            ClassWithBigDecimal target = new ClassWithBigDecimal("-12201e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,json);
            String actual = json.substring(((json.indexOf(':')) + 1), json.indexOf('}'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,target.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,new java.math.BigDecimal(actual));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldSerialization_literalMutation894() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldSerialization_literalMutation894");
            ClassWithBigDecimal target = new ClassWithBigDecimal("-122^.01e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,json);
            String actual = json.substring(((json.indexOf(':')) + 1), json.indexOf('}'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,target.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,new java.math.BigDecimal(actual));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldSerialization_literalMutation895() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldSerialization_literalMutation895");
            ClassWithBigDecimal target = new ClassWithBigDecimal("-122.01e-1");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,json);
            String actual = json.substring(((json.indexOf(':')) + 1), json.indexOf('}'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,target.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,new java.math.BigDecimal(actual));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldSerialization_literalMutation897() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldSerialization_literalMutation897");
            ClassWithBigDecimal target = new ClassWithBigDecimal("-122.01e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,json);
            String actual = json.substring(((json.indexOf(':')) + 2), json.indexOf('}'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,target.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,new java.math.BigDecimal(actual));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldSerialization_literalMutation898() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldSerialization_literalMutation898");
            ClassWithBigDecimal target = new ClassWithBigDecimal("-122.01e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,json);
            String actual = json.substring(((json.indexOf(':')) + 0), json.indexOf('}'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,target.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,new java.math.BigDecimal(actual));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldSerialization_literalMutation899() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldSerialization_literalMutation899");
            ClassWithBigDecimal target = new ClassWithBigDecimal("-122.01e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),482,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),483,json);
            String actual = json.substring(((json.indexOf(':')) + 0), json.indexOf('}'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),484,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),480,target.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),481,new java.math.BigDecimal(actual));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldDeserialization");
            ClassWithBigDecimal expected = new ClassWithBigDecimal("-122*01e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,expected);
            String json = expected.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),273,json);
            ClassWithBigDecimal actual = gson.fromJson(json, ClassWithBigDecimal.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,expected.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,actual.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldDeserialization_literalMutation891() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldDeserialization_literalMutation891");
            ClassWithBigDecimal expected = new ClassWithBigDecimal("-122.01e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,expected);
            String json = expected.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),273,json);
            ClassWithBigDecimal actual = gson.fromJson(json, ClassWithBigDecimal.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,expected.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,actual.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigDecimalFieldDeserialization_literalMutation892() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigDecimalFieldDeserialization_literalMutation892");
            ClassWithBigDecimal expected = new ClassWithBigDecimal("-22.01e-21");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),478,expected);
            String json = expected.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),273,json);
            ClassWithBigDecimal actual = gson.fromJson(json, ClassWithBigDecimal.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),479,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),476,expected.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),477,actual.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBadValueForBigDecimalDeserialization_add86() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadValueForBigDecimalDeserialization_add86");
            try {
                gson.fromJson("{\"value\"=1.5e-1.0031}", ClassWithBigDecimal.class);
                gson.fromJson("{\"value\"=1.5e-1.0031}", ClassWithBigDecimal.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadValueForBigDecimalDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadValueForBigDecimalDeserialization");
            try {
                gson.fromJson("{\"value\"=1.5e-1¾0031}", ClassWithBigDecimal.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadValueForBigDecimalDeserialization_literalMutation888() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadValueForBigDecimalDeserialization_literalMutation888");
            try {
                gson.fromJson("{\"value\"=1.5e-1.0031}", ClassWithBigDecimal.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBadValueForBigDecimalDeserialization_literalMutation889() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBadValueForBigDecimalDeserialization_literalMutation889");
            try {
                gson.fromJson("{\"value\"=.5e-1.0031}", ClassWithBigDecimal.class);
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigIntegerFieldSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigIntegerFieldSerialization");
            ClassWithBigInteger target = new ClassWithBigInteger("¹3232323215323234234324324324324324324");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigIntegerFieldSerialization_literalMutation906() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigIntegerFieldSerialization_literalMutation906");
            ClassWithBigInteger target = new ClassWithBigInteger("2323q2323215323234234324324324324324324");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigIntegerFieldSerialization_literalMutation907() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigIntegerFieldSerialization_literalMutation907");
            ClassWithBigInteger target = new ClassWithBigInteger("2323233215323234234324324324324324324");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,target);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),397,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),490,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),491,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigIntegerFieldDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigIntegerFieldDeserialization");
            ClassWithBigInteger expected = new ClassWithBigInteger("87969769769769769769769769697697697");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,expected);
            String json = expected.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,json);
            ClassWithBigInteger actual = gson.fromJson(json, ClassWithBigInteger.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,expected.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,actual.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigIntegerFieldDeserialization_literalMutation903() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigIntegerFieldDeserialization_literalMutation903");
            ClassWithBigInteger expected = new ClassWithBigInteger("879697697697697697697697697697697697");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,expected);
            String json = expected.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,json);
            ClassWithBigInteger actual = gson.fromJson(json, ClassWithBigInteger.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,expected.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,actual.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBigIntegerFieldDeserialization_literalMutation904() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBigIntegerFieldDeserialization_literalMutation904");
            ClassWithBigInteger expected = new ClassWithBigInteger("87969769769769697697697697697697697");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),487,expected);
            String json = expected.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),488,json);
            ClassWithBigInteger actual = gson.fromJson(json, ClassWithBigInteger.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),489,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),485,expected.value);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),486,actual.value);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testOverrideBigIntegerTypeAdapter() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testOverrideBigIntegerTypeAdapter");
            gson = new GsonBuilder().registerTypeAdapter(BigInteger.class, new NumberAsStringAdapter(BigInteger.class)).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),681,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),678,gson.toJson(new java.math.BigInteger("123"), java.math.BigInteger.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),679,new java.math.BigInteger("123"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),680,gson.fromJson("\"123\"", java.math.BigInteger.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testOverrideBigDecimalTypeAdapter() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testOverrideBigDecimalTypeAdapter");
            gson = new GsonBuilder().registerTypeAdapter(BigDecimal.class, new NumberAsStringAdapter(BigDecimal.class)).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),677,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),674,gson.toJson(new java.math.BigDecimal("1.1"), java.math.BigDecimal.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),675,new java.math.BigDecimal("1.1"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),676,gson.fromJson("\"1.1\"", java.math.BigDecimal.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSetSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetSerialization");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,gson);
            HashSet<java.lang.String> s = new HashSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,s);
            s.add("blah");
            String json = gson.toJson(s);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,json);
            json = gson.toJson(s, java.util.Set.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSetSerialization_add150() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetSerialization_add150");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,gson);
            HashSet<java.lang.String> s = new HashSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,s);
            s.add("blah");
            s.add("blah");
            String json = gson.toJson(s);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,json);
            json = gson.toJson(s, java.util.Set.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSetSerialization_literalMutation1215() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetSerialization_literalMutation1215");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,gson);
            HashSet<java.lang.String> s = new HashSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,s);
            s.add("§lah");
            String json = gson.toJson(s);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,json);
            json = gson.toJson(s, java.util.Set.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSetSerialization_literalMutation1216() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetSerialization_literalMutation1216");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,gson);
            HashSet<java.lang.String> s = new HashSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,s);
            s.add("b\tlah");
            String json = gson.toJson(s);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,json);
            json = gson.toJson(s, java.util.Set.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSetSerialization_literalMutation1217() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetSerialization_literalMutation1217");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,gson);
            HashSet<java.lang.String> s = new HashSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,s);
            s.add("blh");
            String json = gson.toJson(s);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,json);
            json = gson.toJson(s, java.util.Set.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSetSerialization_remove144() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSetSerialization_remove144");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),693,gson);
            HashSet<java.lang.String> s = new HashSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),694,s);
            String json = gson.toJson(s);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),690,json);
            json = gson.toJson(s, java.util.Set.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),692,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),691,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetSerialization_add90() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_add90");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(1);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetSerialization_add91() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_add91");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 6);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetSerialization_add92() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_add92");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 6);
            bits.set(9);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(2);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation936() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation936");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(0);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation937() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation937");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(0);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation939() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation939");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(4, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation940() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation940");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(2, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation941() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation941");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(1, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation942() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation942");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(6, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation944() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation944");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 5);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation945() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation945");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 3);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation946() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation946");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 12);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation947() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation947");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 7);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation949() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation949");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 6);
            bits.set(8);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation950() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation950");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 6);
            bits.set(4);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation951() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation951");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 6);
            bits.set(18);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetSerialization_literalMutation952() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_literalMutation952");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(1);
            bits.set(3, 6);
            bits.set(10);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetSerialization_remove88() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_remove88");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetSerialization_remove89() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_remove89");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetSerialization_remove90() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetSerialization_remove90");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),249,gson);
            BitSet bits = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),508,bits);
            bits.set(3, 6);
            bits.set(9);
            String json = gson.toJson(bits);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),509,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),507,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetDeserialization_add87() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_add87");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetDeserialization_add88() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_add88");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetDeserialization_add89() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_add89");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(1);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation909() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation909");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(-1);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation910() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation910");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation912() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation912");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(1, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation913() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation913");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(4, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation914() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation914");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(3, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation916() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation916");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 5);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation917() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation917");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 3);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation918() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation918");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 12);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation919() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation919");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 7);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation921() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation921");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(4);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation922() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation922");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(16);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation923() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation923");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(9);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation924() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation924");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(7);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation926() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation926");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0þ0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation927() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation927");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0D,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation928() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation928");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation929() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation929");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"?\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation930() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation930");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"<1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation931() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation931");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation932() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation932");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,falsefalse,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation933() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation933");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,faÅlse,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBitSetDeserialization_literalMutation934() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_literalMutation934");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(0);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,flse,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetDeserialization_remove85() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_remove85");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetDeserialization_remove86() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_remove86");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testBitSetDeserialization_remove87() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBitSetDeserialization_remove87");
            BitSet expected = new BitSet();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),504,expected);
            expected.set(2, 6);
            expected.set(8);
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),505,gson);
            String json = gson.toJson(expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),506,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),493,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),494,gson.fromJson(json, java.util.BitSet.class));
            json = "[1,0,1,1,1,1,0,0,1,0,0,0]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),501,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),495,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),496,gson.fromJson(json, java.util.BitSet.class));
            json = "[\"1\",\"0\",\"1\",\"1\",\"1\",\"1\",\"0\",\"0\",\"1\"]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),502,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),497,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),498,gson.fromJson(json, java.util.BitSet.class));
            json = "[true,false,true,true,true,true,false,false,true,false,false]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),503,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),499,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),500,gson.fromJson(json, java.util.BitSet.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerialization");
            Date now = new Date(1315806903102L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerialization_literalMutation1040() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerialization_literalMutation1040");
            Date now = new Date(657903451551L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerialization_literalMutation1041() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerialization_literalMutation1041");
            Date now = new Date(2631613806206L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerialization_literalMutation1042() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerialization_literalMutation1042");
            Date now = new Date(1315806903104L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),574,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),575,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),573,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultDateDeserialization_add101() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_add101");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultDateDeserialization_add102() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_add102");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization");
            String json = "\'Dec 13, 2009 07:18:0I AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1003() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1003");
            String json = "\'Dec 13,Ù 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1004() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1004");
            String json = "\'Dec 13, 2009 07:1:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1005() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1005");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2010, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1006() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1006");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2008, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1007() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1007");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 1004, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1008() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1008");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 4018, 11, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1010() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1010");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 10, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1011() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1011");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 5, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1012() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1012");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 22, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1013() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1013");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 12, 13);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1015() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1015");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 12);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1016() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1016");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 6);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1017() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1017");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 26);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1018() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1018");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 14);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1020() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1020");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 8, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1021() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1021");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 6, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1022() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1022");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 3, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1023() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1023");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 14, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1025() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1025");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 17, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1026() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1026");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 9, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1027() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1027");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 36, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1028() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1028");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 19, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1030() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1030");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1031() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1031");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 4);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserialization_literalMutation1032() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_literalMutation1032");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
            assertEqualsTime(extracted, 7, 18, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultDateDeserialization_remove95() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_remove95");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsTime(extracted, 7, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultDateDeserialization_remove96() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserialization_remove96");
            String json = "\'Dec 13, 2009 07:18:02 AM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),567,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),568,extracted);
            assertEqualsDate(extracted, 2009, 11, 13);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    private void assertEqualsDate(Date date, int year, int month, int day) {
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),462,(year - 1900));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),463,date.getYear());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),464,month);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),465,date.getMonth());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),466,day);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),467,date.getDate());
    }

    @SuppressWarnings(value = "deprecation")
    private void assertEqualsTime(Date date, int hours, int minutes, int seconds) {
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),468,hours);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),469,date.getHours());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),470,minutes);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),471,date.getMinutes());
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),472,seconds);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),473,date.getSeconds());
    }

    public void testDefaultJavaSqlDateSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateSerialization");
            java.sql.Date instant = new java.sql.Date(1259875081999L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,instant);
            String json = gson.toJson(instant);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateSerialization_literalMutation1071() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateSerialization_literalMutation1071");
            java.sql.Date instant = new java.sql.Date(1259875082001L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,instant);
            String json = gson.toJson(instant);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateSerialization_literalMutation1072() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateSerialization_literalMutation1072");
            java.sql.Date instant = new java.sql.Date(629937541000L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,instant);
            String json = gson.toJson(instant);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateSerialization_literalMutation1073() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateSerialization_literalMutation1073");
            java.sql.Date instant = new java.sql.Date(2519750164000L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),597,instant);
            String json = gson.toJson(instant);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),598,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),596,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlDateDeserialization_add103() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_add103");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsDate(extracted, 2009, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization");
            String json = "\'Dec 3,«2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1053() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1053");
            String json = "\'Dec 3, 20V09\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1054() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1054");
            String json = "\'De 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1055() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1055");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2010, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1056() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1056");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2008, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1057() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1057");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 1004, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1058() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1058");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 4018, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1060() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1060");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 10, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1061() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1061");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 5, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1062() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1062");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 22, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1063() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1063");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 12, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1065() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1065");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 4);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1066() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1066");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1067() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1067");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlDateDeserialization_literalMutation1068() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_literalMutation1068");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
            assertEqualsDate(extracted, 2009, 11, 6);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlDateDeserialization_remove97() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlDateDeserialization_remove97");
            String json = "\'Dec 3, 2009\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),594,json);
            java.sql.Date extracted = gson.fromJson(json, java.sql.Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),595,extracted);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampSerialization");
            Timestamp now = new Timestamp(1259875081999L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),606,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampSerialization_literalMutation1130() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampSerialization_literalMutation1130");
            Timestamp now = new Timestamp(1259875082001L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),606,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampSerialization_literalMutation1131() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampSerialization_literalMutation1131");
            Timestamp now = new Timestamp(629937541000L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),606,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampSerialization_literalMutation1132() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampSerialization_literalMutation1132");
            Timestamp now = new Timestamp(2519750164000L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),605,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),606,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),604,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlTimestampDeserialization_add105() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_add105");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlTimestampDeserialization_add106() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_add106");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization");
            String json = "\'Dec 3, 2009 1:18:02 ÷M\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1098() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1098");
            String json = "\'Dec 3, ¬2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1099() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1099");
            String json = "\'Dec 3, 2009 1:18:02 P\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1100() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1100");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2010, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1101() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1101");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2008, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1102() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1102");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 1004, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1103() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1103");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 4018, 11, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1105() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1105");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 10, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1106() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1106");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 5, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1107() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1107");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 22, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1108() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1108");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 12, 3);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1110() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1110");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 4);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1111() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1111");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 2);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1112() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1112");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 1);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1113() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1113");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 6);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1115() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1115");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 12, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1116() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1116");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 6, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1117() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1117");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 26, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1118() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1118");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 14, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1120() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1120");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 17, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1121() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1121");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 9, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1122() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1122");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 36, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1123() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1123");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 19, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1125() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1125");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1126() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1126");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 4);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimestampDeserialization_literalMutation1127() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_literalMutation1127");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
            assertEqualsTime(extracted, 13, 18, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlTimestampDeserialization_remove100() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_remove100");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsDate(extracted, 2009, 11, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlTimestampDeserialization_remove99() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimestampDeserialization_remove99");
            String json = "\'Dec 3, 2009 1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),602,json);
            Timestamp extracted = gson.fromJson(json, Timestamp.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),603,extracted);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeSerialization");
            Time now = new Time(1259875081999L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeSerialization_literalMutation1093() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeSerialization_literalMutation1093");
            Time now = new Time(1259875082001L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeSerialization_literalMutation1094() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeSerialization_literalMutation1094");
            Time now = new Time(629937541000L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeSerialization_literalMutation1095() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeSerialization_literalMutation1095");
            Time now = new Time(2519750164000L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),601,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),453,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),450,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlTimeDeserialization_add104() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_add104");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 18, 2);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization");
            String json = "\'1:18:0 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1076() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1076");
            String json = "\'1:18:0Ù2 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1077() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1077");
            String json = "\'1:18:2 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1078() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1078");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 12, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1079() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1079");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 6, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1080() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1080");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 26, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1081() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1081");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 14, 18, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1083() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1083");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 17, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1084() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1084");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 9, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1085() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1085");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 36, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1086() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1086");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 19, 2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1088() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1088");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 18, 1);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1089() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1089");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 18, 4);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultJavaSqlTimeDeserialization_literalMutation1090() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_literalMutation1090");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
            assertEqualsTime(extracted, 13, 18, 3);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDefaultJavaSqlTimeDeserialization_remove98() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultJavaSqlTimeDeserialization_remove98");
            String json = "\'1:18:02 PM\'";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),599,json);
            Time extracted = gson.fromJson(json, Time.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),600,extracted);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerializationUsingBuilder() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerializationUsingBuilder");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,gson);
            Date now = new Date(1315806903102L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerializationUsingBuilder_literalMutation1045() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerializationUsingBuilder_literalMutation1045");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,gson);
            Date now = new Date(657903451551L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerializationUsingBuilder_literalMutation1046() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerializationUsingBuilder_literalMutation1046");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,gson);
            Date now = new Date(2631613806206L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateSerializationUsingBuilder_literalMutation1047() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateSerializationUsingBuilder_literalMutation1047");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),570,gson);
            Date now = new Date(1315806903104L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),571,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),572,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),569,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserializationUsingBuilder() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserializationUsingBuilder");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,gson);
            Date now = new Date(1315806903102L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,now.toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,extracted.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserializationUsingBuilder_literalMutation1035() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserializationUsingBuilder_literalMutation1035");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,gson);
            Date now = new Date(657903451551L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,now.toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,extracted.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserializationUsingBuilder_literalMutation1036() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserializationUsingBuilder_literalMutation1036");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,gson);
            Date now = new Date(2631613806206L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,now.toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,extracted.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultDateDeserializationUsingBuilder_literalMutation1037() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultDateDeserializationUsingBuilder_literalMutation1037");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),563,gson);
            Date now = new Date(1315806903104L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),564,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),565,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),566,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),561,now.toString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),562,extracted.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultCalendarSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultCalendarSerialization");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),559,gson);
            String json = gson.toJson(Calendar.getInstance());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),560,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),553,json.contains("year"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),554,json.contains("month"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),555,json.contains("dayOfMonth"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),556,json.contains("hourOfDay"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),557,json.contains("minute"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),558,json.contains("second"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultCalendarDeserialization_literalMutation1000() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultCalendarDeserialization_literalMutation1000");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,gson);
            String json = "{year:2009,month:2,dayOfMonth:11,hourOfDay:14,minute:29,second:23}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,json);
            Calendar cal = gson.fromJson(json, Calendar.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,cal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,cal.get(java.util.Calendar.YEAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,cal.get(java.util.Calendar.MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,cal.get(java.util.Calendar.DAY_OF_MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,cal.get(java.util.Calendar.HOUR_OF_DAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,cal.get(java.util.Calendar.MINUTE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,cal.get(java.util.Calendar.SECOND));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultCalendarDeserialization_literalMutation1001() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultCalendarDeserialization_literalMutation1001");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,gson);
            String json = "{year:2009,month:2,dayOfMoth:11,hourOfDay:14,minute:29,second:23}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,json);
            Calendar cal = gson.fromJson(json, Calendar.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,cal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,cal.get(java.util.Calendar.YEAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,cal.get(java.util.Calendar.MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,cal.get(java.util.Calendar.DAY_OF_MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,cal.get(java.util.Calendar.HOUR_OF_DAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,cal.get(java.util.Calendar.MINUTE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,cal.get(java.util.Calendar.SECOND));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultCalendarDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultCalendarDeserialization");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),550,gson);
            String json = "{year:2009,moth:2,dayOfMonth:11,hourOfDay:14,minute:29,second:23}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),551,json);
            Calendar cal = gson.fromJson(json, Calendar.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),552,cal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),544,cal.get(java.util.Calendar.YEAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),545,cal.get(java.util.Calendar.MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),546,cal.get(java.util.Calendar.DAY_OF_MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),547,cal.get(java.util.Calendar.HOUR_OF_DAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),548,cal.get(java.util.Calendar.MINUTE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),549,cal.get(java.util.Calendar.SECOND));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultGregorianCalendarSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultGregorianCalendarSerialization");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),591,gson);
            GregorianCalendar cal = new GregorianCalendar();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),592,cal);
            String json = gson.toJson(cal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),593,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),585,json.contains("year"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),586,json.contains("month"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),587,json.contains("dayOfMonth"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),588,json.contains("hourOfDay"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),589,json.contains("minute"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),590,json.contains("second"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultGregorianCalendarDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultGregorianCalendarDeserialization");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,gson);
            String json = "{year:2009,month:2,dayOfMonth:11,hourOfDay:14,minut:29,second:23}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,json);
            GregorianCalendar cal = gson.fromJson(json, GregorianCalendar.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,cal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,cal.get(java.util.Calendar.YEAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,cal.get(java.util.Calendar.MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,cal.get(java.util.Calendar.DAY_OF_MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,cal.get(java.util.Calendar.HOUR_OF_DAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,cal.get(java.util.Calendar.MINUTE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,cal.get(java.util.Calendar.SECOND));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultGregorianCalendarDeserialization_literalMutation1050() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultGregorianCalendarDeserialization_literalMutation1050");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,gson);
            String json = "{year:2009,month:2,dayOfMonth:11,hourOfDay:14,minute:]29,second:23}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,json);
            GregorianCalendar cal = gson.fromJson(json, GregorianCalendar.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,cal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,cal.get(java.util.Calendar.YEAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,cal.get(java.util.Calendar.MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,cal.get(java.util.Calendar.DAY_OF_MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,cal.get(java.util.Calendar.HOUR_OF_DAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,cal.get(java.util.Calendar.MINUTE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,cal.get(java.util.Calendar.SECOND));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDefaultGregorianCalendarDeserialization_literalMutation1051() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDefaultGregorianCalendarDeserialization_literalMutation1051");
            Gson gson = new GsonBuilder().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),582,gson);
            String json = "{year:2009,month:2,dayOfMonth:1,hourOfDay:14,minute:29,second:23}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),583,json);
            GregorianCalendar cal = gson.fromJson(json, GregorianCalendar.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),584,cal);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),576,cal.get(java.util.Calendar.YEAR));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),577,cal.get(java.util.Calendar.MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),578,cal.get(java.util.Calendar.DAY_OF_MONTH));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),579,cal.get(java.util.Calendar.HOUR_OF_DAY));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),580,cal.get(java.util.Calendar.MINUTE));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),581,cal.get(java.util.Calendar.SECOND));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPattern() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPattern");
            String pattern = "yyyyOMM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPattern_literalMutation979() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPattern_literalMutation979");
            String pattern = "yyy9y-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPattern_literalMutation980() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPattern_literalMutation980");
            String pattern = "yyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPattern_literalMutation981() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPattern_literalMutation981");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,gson);
            Date now = new Date(1315806903102L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPattern_literalMutation982() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPattern_literalMutation982");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,gson);
            Date now = new Date(657903451551L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPattern_literalMutation983() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPattern_literalMutation983");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,gson);
            Date now = new Date(2631613806206L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPattern_literalMutation984() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPattern_literalMutation984");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),540,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),541,gson);
            Date now = new Date(1315806903104L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),542,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),543,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),539,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "dep4ecation")
    public void testDateDeserializationWithPattern() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation958() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation958");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "dprecation")
    public void testDateDeserializationWithPattern_literalMutation959() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation959");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation960() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation960");
            String pattern = "yyyx-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation961() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation961");
            String pattern = "yyyWy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation962() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation962");
            String pattern = "yyyy-MM-d";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation963() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation963");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903102L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation964() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation964");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(657903451551L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation965() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation965");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(2631613806206L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "deprecation")
    public void testDateDeserializationWithPattern_literalMutation966() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateDeserializationWithPattern_literalMutation966");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),521,pattern);
            Gson gson = new GsonBuilder().setDateFormat(java.text.DateFormat.FULL).setDateFormat(pattern).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),522,gson);
            Date now = new Date(1315806903104L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),523,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),524,json);
            Date extracted = gson.fromJson(json, Date.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),525,extracted);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),515,now.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),516,extracted.getYear());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),517,now.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),518,extracted.getMonth());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),519,now.getDay());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),520,extracted.getDay());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_add100() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_add100");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter");
            String pattern = "Gyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation987() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation987");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation988() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation988");
            String pattern = "yyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation989() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation989");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903102L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation990() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation990");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(657903451551L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation991() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation991");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(2631613806206L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation992() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation992");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903104L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation994() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation994");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903102L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation995() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation995");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(657903451551L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation996() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation996");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(2631613806206L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation997() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_literalMutation997");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903104L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationWithPatternNotOverridenByTypeAdapter_remove94() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationWithPatternNotOverridenByTypeAdapter_remove94");
            String pattern = "yyyy-MM-dd";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),535,pattern);
            Gson gson = new GsonBuilder().setDateFormat(pattern).registerTypeAdapter(Date.class, new com.google.gson.JsonDeserializer<java.util.Date>() {
                public Date deserialize(JsonElement json, Type typeOfT, com.google.gson.JsonDeserializationContext context) throws JsonParseException {
                    return new Date(1315806903103L);
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),536,gson);
            Date now = new Date(1315806903103L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),537,now);
            String json = gson.toJson(now);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),538,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),534,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_add95() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_add95");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_add96() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_add96");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_add97() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_add97");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_add98() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_add98");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_add99() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_add99");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("ÆTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation969() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation969");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("U¿TC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation970() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation970");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation971() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation971");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MMÒdd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation972() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation972");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyy¥y-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation973() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation973");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MMdd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation974() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation974");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation975() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation975");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(-1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateSerializationInCollection_literalMutation976() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_literalMutation976");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_remove91() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_remove91");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_remove92() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_remove92");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateSerializationInCollection_remove93() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateSerializationInCollection_remove93");
            Type listOfDates = new TypeToken<java.util.List<java.util.Date>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),528,listOfDates);
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),529,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),530,defaultLocale);
            try {
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),531,gson);
                List<java.util.Date> dates = java.util.Arrays.asList(new Date(0));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),532,dates);
                String json = gson.toJson(dates, listOfDates);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),533,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),526,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),527,gson.<java.util.List<java.util.Date>>fromJson("[\"1970-01-01\"]", listOfDates).get(0).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTimestampSerialization_add155() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_add155");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTimestampSerialization_add156() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_add156");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTimestampSerialization_add157() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_add157");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTimestampSerialization_add158() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_add158");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("*TC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1241() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1241");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UöTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1242() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1242");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1243() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1243");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(1L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1244() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1244");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(-1L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1245() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1245");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1247() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1247");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy¿MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1248() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1248");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MMß-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTimestampSerialization_literalMutation1249() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_literalMutation1249");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyyMM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTimestampSerialization_remove147() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_remove147");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTimestampSerialization_remove148() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTimestampSerialization_remove148");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),715,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),716,defaultLocale);
            try {
                Timestamp timestamp = new Timestamp(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),717,timestamp);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),718,gson);
                String json = gson.toJson(timestamp, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),719,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),713,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),714,gson.fromJson("\"1970-01-01\"", java.sql.Timestamp.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSqlDateSerialization_add151() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_add151");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSqlDateSerialization_add152() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_add152");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSqlDateSerialization_add153() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_add153");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSqlDateSerialization_add154() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_add154");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("¹TC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1219() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1219");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("U8TC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1220() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1220");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1221() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1221");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(1L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1222() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1222");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(-1L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1223() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1223");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1225() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1225");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyyMM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1226() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1226");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSqlDateSerialization_literalMutation1227() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_literalMutation1227");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-M-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSqlDateSerialization_remove145() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_remove145");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            Locale.setDefault(Locale.US);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSqlDateSerialization_remove146() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSqlDateSerialization_remove146");
            TimeZone defaultTimeZone = TimeZone.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),698,defaultTimeZone);
            TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
            Locale defaultLocale = Locale.getDefault();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),699,defaultLocale);
            try {
                java.sql.Date sqlDate = new java.sql.Date(0L);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),700,sqlDate);
                Gson gson = new GsonBuilder().setDateFormat("yyyy-MM-dd").create();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),701,gson);
                String json = gson.toJson(sqlDate, Timestamp.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),702,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),696,json);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),697,gson.fromJson("\"1970-01-01\"", java.sql.Date.class).getTime());
            } finally {
                TimeZone.setDefault(defaultTimeZone);
                Locale.setDefault(defaultLocale);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonPrimitiveSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonPrimitiveSerialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),647,gson.toJson(new com.google.gson.JsonPrimitive(5), com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),648,gson.toJson(new com.google.gson.JsonPrimitive(true), com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),649,gson.toJson(new com.google.gson.JsonPrimitive("foo"), com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),650,gson.toJson(new com.google.gson.JsonPrimitive('a'), com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonPrimitiveDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonPrimitiveDeserialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),631,new com.google.gson.JsonPrimitive(5));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),632,gson.fromJson("5", com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),633,new com.google.gson.JsonPrimitive(5));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),634,gson.fromJson("5", com.google.gson.JsonPrimitive.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),635,new com.google.gson.JsonPrimitive(true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),636,gson.fromJson("true", com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),637,new com.google.gson.JsonPrimitive(true));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),638,gson.fromJson("true", com.google.gson.JsonPrimitive.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),639,new com.google.gson.JsonPrimitive("foo"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),640,gson.fromJson("\"foo\"", com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),641,new com.google.gson.JsonPrimitive("foo"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),642,gson.fromJson("\"foo\"", com.google.gson.JsonPrimitive.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),643,new com.google.gson.JsonPrimitive('a'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),644,gson.fromJson("\"a\"", com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),645,new com.google.gson.JsonPrimitive('a'));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),646,gson.fromJson("\"a\"", com.google.gson.JsonPrimitive.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonNullSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonNullSerialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),619,gson.toJson(com.google.gson.JsonNull.INSTANCE, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),620,gson.toJson(com.google.gson.JsonNull.INSTANCE, com.google.gson.JsonNull.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullJsonElementSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullJsonElementSerialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),670,gson.toJson(null, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),671,gson.toJson(null, com.google.gson.JsonNull.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArraySerialization_add110() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_add110");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArraySerialization_add111() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_add111");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArraySerialization_add112() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_add112");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1151() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1151");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(0));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1152() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1152");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(0));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1154() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1154");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1155() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1155");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(4));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1156() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1156");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(3));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1158() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1158");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1159() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1159");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1160() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1160");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArraySerialization_literalMutation1161() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_literalMutation1161");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(6));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArraySerialization_remove104() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_remove104");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArraySerialization_remove105() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_remove105");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArraySerialization_remove106() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArraySerialization_remove106");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),614,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),613,gson.toJson(array, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArrayDeserialization_add107() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_add107");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArrayDeserialization_add108() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_add108");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArrayDeserialization_add109() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_add109");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1135() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1135");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(0));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1136() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1136");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(0));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1138() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1138");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1139() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1139");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(4));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1140() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1140");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(3));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1142() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1142");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(4));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1143() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1143");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(2));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1144() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1144");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(1));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1145() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1145");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(6));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1147() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1147");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1Â2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1148() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1148");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonArrayDeserialization_literalMutation1149() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_literalMutation1149");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(1));
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArrayDeserialization_remove101() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_remove101");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArrayDeserialization_remove102() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_remove102");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonArrayDeserialization_remove103() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonArrayDeserialization_remove103");
            JsonArray array = new JsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),611,array);
            array.add(new com.google.gson.JsonPrimitive(2));
            array.add(new com.google.gson.JsonPrimitive(3));
            String json = "[1,2,3]";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),612,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),607,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),608,gson.fromJson(json, com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),609,array);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),610,gson.fromJson(json, com.google.gson.JsonArray.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectSerialization_add115() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_add115");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectSerialization_add116() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_add116");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("$oo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1181() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1181");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("f­oo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1182() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1182");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("fo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1183() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1183");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(2));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1184() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1184");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(0));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1185() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1185");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(0));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1187() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1187");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("ar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1188() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1188");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("b,ar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1189() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1189");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("br", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1190() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1190");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1191() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1191");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(4));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectSerialization_literalMutation1192() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_literalMutation1192");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectSerialization_remove109() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_remove109");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectSerialization_remove110() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization_remove110");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),630,object);
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),629,gson.toJson(object, com.google.gson.JsonElement.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectDeserialization_add113() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_add113");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectDeserialization_add114() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_add114");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("Úoo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1164() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1164");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("fFoo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1165() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1165");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("fo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1166() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1166");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(2));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1167() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1167");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(0));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1168() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1168");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(0));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1170() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1170");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("åar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1171() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1171");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bêar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1172() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1172");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("br", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1173() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1173");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(1));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1174() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1174");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(4));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1175() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1175");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(3));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1177() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1177");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar°:2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1178() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1178");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonObjectDeserialization_literalMutation1179() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_literalMutation1179");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("foo", new com.google.gson.JsonPrimitive(1));
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"ba\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectDeserialization_remove107() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_remove107");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testJsonObjectDeserialization_remove108() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectDeserialization_remove108");
            JsonObject object = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),625,object);
            object.add("bar", new com.google.gson.JsonPrimitive(2));
            String json = "{\"foo\":1,\"bar\":2}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),626,json);
            JsonElement actual = gson.fromJson(json, JsonElement.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),627,actual);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),621,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),622,actual);
            JsonObject actualObj = gson.fromJson(json, JsonObject.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),628,actualObj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),623,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),624,actualObj);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonNullDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonNullDeserialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),615,com.google.gson.JsonNull.INSTANCE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),616,gson.fromJson("null", com.google.gson.JsonElement.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),617,com.google.gson.JsonNull.INSTANCE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),618,gson.fromJson("null", com.google.gson.JsonNull.class));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithBigDecimal {
        BigDecimal value;

        ClassWithBigDecimal(String value) {
            this.value = new BigDecimal(value);
        }

        String getExpectedJson() {
            return ("{\"value\":" + (value.toEngineeringString())) + "}";
        }
    }

    private static class ClassWithBigInteger {
        BigInteger value;

        ClassWithBigInteger(String value) {
            this.value = new BigInteger(value);
        }

        String getExpectedJson() {
            return ("{\"value\":" + (value)) + "}";
        }
    }

    @Test(timeout = 1000)
    public void testPropertiesSerialization_add149() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_add149");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("foo", "bar");
            props.setProperty("foo", "bar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("oo", "bar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1207() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1207");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("fßoo", "bar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1208() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1208");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("fo", "bar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1209() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1209");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("foo", "¥ar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1210() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1210");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("foo", "bûar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1211() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1211");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("foo", "br");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1212() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1212");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("foo", "bar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"f$o\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1213() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1213");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("foo", "bar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"£foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesSerialization_literalMutation1214() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_literalMutation1214");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            props.setProperty("foo", "bar");
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"fo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testPropertiesSerialization_remove143() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesSerialization_remove143");
            Properties props = new Properties();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),687,props);
            String json = gson.toJson(props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),688,json);
            String expected = "{\"foo\":\"bar\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),689,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),685,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),686,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesDeserialization");
            String json = "{foo:\'baê\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),683,json);
            Properties props = gson.fromJson(json, Properties.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),684,props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),682,props.getProperty("foo"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesDeserialization_literalMutation1204() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesDeserialization_literalMutation1204");
            String json = "{foo:\'bRar\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),683,json);
            Properties props = gson.fromJson(json, Properties.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),684,props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),682,props.getProperty("foo"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPropertiesDeserialization_literalMutation1205() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPropertiesDeserialization_literalMutation1205");
            String json = "{oo:\'bar\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),683,json);
            Properties props = gson.fromJson(json, Properties.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),684,props);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),682,props.getProperty("foo"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTreeSetSerialization_add160() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetSerialization_add160");
            TreeSet<java.lang.String> treeSet = new TreeSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),725,treeSet);
            treeSet.add("Value1");
            treeSet.add("Value1");
            String json = gson.toJson(treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),726,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),724,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTreeSetSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetSerialization");
            TreeSet<java.lang.String> treeSet = new TreeSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),725,treeSet);
            treeSet.add("ValØe1");
            String json = gson.toJson(treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),726,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),724,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTreeSetSerialization_literalMutation1254() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetSerialization_literalMutation1254");
            TreeSet<java.lang.String> treeSet = new TreeSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),725,treeSet);
            treeSet.add("Valuàe1");
            String json = gson.toJson(treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),726,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),724,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTreeSetSerialization_literalMutation1255() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetSerialization_literalMutation1255");
            TreeSet<java.lang.String> treeSet = new TreeSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),725,treeSet);
            treeSet.add("Vaue1");
            String json = gson.toJson(treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),726,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),724,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTreeSetSerialization_remove150() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetSerialization_remove150");
            TreeSet<java.lang.String> treeSet = new TreeSet<java.lang.String>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),725,treeSet);
            String json = gson.toJson(treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),726,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),724,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTreeSetDeserialization_add159() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetDeserialization_add159");
            String json = "[\'Value1\']";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),721,json);
            Type type = new TypeToken<java.util.TreeSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),722,type);
            TreeSet<java.lang.String> treeSet = gson.fromJson(json, type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),723,treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),720,treeSet.contains("Value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTreeSetDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetDeserialization");
            String json = "¼\'Value1\']";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),721,json);
            Type type = new TypeToken<java.util.TreeSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),722,type);
            TreeSet<java.lang.String> treeSet = gson.fromJson(json, type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),723,treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),720,treeSet.contains("Value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTreeSetDeserialization_literalMutation1251() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetDeserialization_literalMutation1251");
            String json = "[\'VaÎlue1\']";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),721,json);
            Type type = new TypeToken<java.util.TreeSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),722,type);
            TreeSet<java.lang.String> treeSet = gson.fromJson(json, type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),723,treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),720,treeSet.contains("Value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTreeSetDeserialization_literalMutation1252() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetDeserialization_literalMutation1252");
            String json = "[\'Vaue1\']";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),721,json);
            Type type = new TypeToken<java.util.TreeSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),722,type);
            TreeSet<java.lang.String> treeSet = gson.fromJson(json, type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),723,treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),720,treeSet.contains("Value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTreeSetDeserialization_remove149() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTreeSetDeserialization_remove149");
            String json = "[\'Value1\']";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),721,json);
            Type type = new TypeToken<java.util.TreeSet<java.lang.String>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),722,type);
            TreeSet<java.lang.String> treeSet = gson.fromJson(json, type);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),723,treeSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),720,treeSet.contains("Value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBuilderSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBuilderSerialization");
            StringBuilder sb = new StringBuilder("kbc");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),711,sb);
            String json = gson.toJson(sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),712,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),710,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBuilderSerialization_literalMutation1238() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBuilderSerialization_literalMutation1238");
            StringBuilder sb = new StringBuilder("a*bc");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),711,sb);
            String json = gson.toJson(sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),712,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),710,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBuilderSerialization_literalMutation1239() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBuilderSerialization_literalMutation1239");
            StringBuilder sb = new StringBuilder("ac");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),711,sb);
            String json = gson.toJson(sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),712,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),710,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBuilderDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBuilderDeserialization");
            StringBuilder sb = gson.fromJson("\'®bc\'", StringBuilder.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),709,sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),708,sb.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBuilderDeserialization_literalMutation1235() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBuilderDeserialization_literalMutation1235");
            StringBuilder sb = gson.fromJson("\'abæc\'", StringBuilder.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),709,sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),708,sb.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBuilderDeserialization_literalMutation1236() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBuilderDeserialization_literalMutation1236");
            StringBuilder sb = gson.fromJson("\'ab\'", StringBuilder.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),709,sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),708,sb.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBufferSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBufferSerialization");
            StringBuffer sb = new StringBuffer("bc");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),706,sb);
            String json = gson.toJson(sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),707,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),705,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBufferSerialization_literalMutation1232() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBufferSerialization_literalMutation1232");
            StringBuffer sb = new StringBuffer("a½bc");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),706,sb);
            String json = gson.toJson(sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),707,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),705,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBufferSerialization_literalMutation1233() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBufferSerialization_literalMutation1233");
            StringBuffer sb = new StringBuffer("ac");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),706,sb);
            String json = gson.toJson(sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),707,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),705,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBufferDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBufferDeserialization");
            StringBuffer sb = gson.fromJson("\'atc\'", StringBuffer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),704,sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),703,sb.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBufferDeserialization_literalMutation1229() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBufferDeserialization_literalMutation1229");
            StringBuffer sb = gson.fromJson("\'×abc\'", StringBuffer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),704,sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),703,sb.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringBufferDeserialization_literalMutation1230() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringBufferDeserialization_literalMutation1230");
            StringBuffer sb = gson.fromJson("\'bc\'", StringBuffer.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),704,sb);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),703,sb.toString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    private static class MyClassTypeAdapter extends TypeAdapter<java.lang.Class> {
        @Override
        public void write(JsonWriter out, Class value) throws IOException {
            out.value(value.getName());
        }

        @Override
        public Class read(JsonReader in) throws IOException {
            String className = in.nextString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),461,className);
            try {
                return Class.forName(className);
            } catch (ClassNotFoundException e) {
                throw new IOException(e);
            }
        }
    }

    static class NumberAsStringAdapter extends TypeAdapter<java.lang.Number> {
        private final Constructor<? extends java.lang.Number> constructor;

        NumberAsStringAdapter(Class<? extends java.lang.Number> type) throws Exception {
            this.constructor = type.getConstructor(String.class);
        }

        @Override
        public void write(JsonWriter out, Number value) throws IOException {
            out.value(value.toString());
        }

        @Override
        public Number read(JsonReader in) throws IOException {
            try {
                return constructor.newInstance(in.nextString());
            } catch (Exception e) {
                throw new AssertionError(e);
            }
        }
    }
}

