package com.google.gson.functional;

import java.util.ArrayList;
import java.util.Collection;
import com.google.gson.Gson;
import com.google.gson.JsonArray;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import java.util.LinkedList;
import java.util.List;
import java.util.Queue;
import java.util.Set;
import java.util.SortedSet;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.util.TreeSet;

/** 
 * Functional tests for Json serialization and deserialization of classes with
 * inheritance hierarchies.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class InheritanceTest extends TestCase {
    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),973,gson);
    }

    public void testSubClassSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(9 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1464() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1464");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(5 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1465() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1465");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(20 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1466() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1466");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(11 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1468() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1468");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 19 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1469() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1469");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 10 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1470() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1470");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 40 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1471() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1471");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 21 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1473() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1473");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , true , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1474() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1474");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "ùtringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1475() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1475");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringVaãlue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1476() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1476");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringVlue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1477() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1477");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(29 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1478() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1478");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(15 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1479() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1479");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(60 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1480() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1480");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(31 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1482() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1482");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 39 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1483() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1483");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 41 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1484() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1484");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 20 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1485() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1485");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 80 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1488() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1488");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringVÙlue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1489() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1489");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringVal£ue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassSerialization_literalMutation1490() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassSerialization_literalMutation1490");
            SubTypeOfNested target = new SubTypeOfNested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "strinValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1016,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1014,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1015,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization");
            String json = "{\"value\":5,\"p+imitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1452() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1452");
            String json = "{\"value\":5,\"primitive1\":{\"long:Value\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1453() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1453");
            String json = "{\"value\":5,\"primitive1\":{\"longalue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1454() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1454");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanìalue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1455() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1455");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValuHe\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1456() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1456");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":fase,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1457() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1457");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intVal\'e\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1458() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1458");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"loangValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1459() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1459");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"lngValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1460() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1460");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringV lue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1461() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1461");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringValue\":\"stÚringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubClassDeserialization_literalMutation1462() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubClassDeserialization_literalMutation1462");
            String json = "{\"value\":5,\"primitive1\":{\"longValue\":10,\"intValue\":20," + ("\"booleanValue\":false,\"stringValue\":\"stringValue\"},\"primitive2\":" + ("{\"longValue\":30,\"intValue\":40,\"booleanValue\":true," + "\"stringVaue\":\"stringValue\"}}"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),762,json);
            SubTypeOfNested target = gson.fromJson(json, SubTypeOfNested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),234,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1012,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1013,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassWithBaseFieldSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithBaseFieldSerialization");
            TestTypes.ClassWithBaseField sub = new TestTypes.ClassWithBaseField(new TestTypes.Sub());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1010,sub);
            JsonObject json = ((JsonObject)(gson.toJsonTree(sub)));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),241,json);
            JsonElement base = json.getAsJsonObject().get(TestTypes.ClassWithBaseField.FIELD_KEY);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1011,base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1008,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1009,base.getAsJsonObject().get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassWithBaseArrayFieldSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithBaseArrayFieldSerialization");
            TestTypes.Base[] baseClasses = new TestTypes.Base[]{ new TestTypes.Sub() , new TestTypes.Sub() };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),998,baseClasses);
            TestTypes.ClassWithBaseArrayField sub = new TestTypes.ClassWithBaseArrayField(baseClasses);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),999,sub);
            JsonObject json = gson.toJsonTree(sub).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1000,json);
            JsonArray bases = json.get(TestTypes.ClassWithBaseArrayField.FIELD_KEY).getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1001,bases);
            for (JsonElement element : bases) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),996,com.google.gson.common.TestTypes.Sub.SUB_NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),997,element.getAsJsonObject().get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testClassWithBaseCollectionFieldSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithBaseCollectionFieldSerialization");
            Collection<com.google.gson.common.TestTypes.Base> baseClasses = new ArrayList<com.google.gson.common.TestTypes.Base>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1004,baseClasses);
            baseClasses.add(new TestTypes.Sub());
            baseClasses.add(new TestTypes.Sub());
            baseClasses.add(new TestTypes.Sub());
            TestTypes.ClassWithBaseCollectionField sub = new TestTypes.ClassWithBaseCollectionField(baseClasses);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1005,sub);
            JsonObject json = gson.toJsonTree(sub).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1006,json);
            JsonArray bases = json.get(TestTypes.ClassWithBaseArrayField.FIELD_KEY).getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1007,bases);
            for (JsonElement element : bases) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1002,com.google.gson.common.TestTypes.Sub.SUB_NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1003,element.getAsJsonObject().get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testClassWithBaseCollectionFieldSerialization_add188() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithBaseCollectionFieldSerialization_add188");
            Collection<com.google.gson.common.TestTypes.Base> baseClasses = new ArrayList<com.google.gson.common.TestTypes.Base>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1004,baseClasses);
            baseClasses.add(new TestTypes.Sub());
            baseClasses.add(new TestTypes.Sub());
            baseClasses.add(new TestTypes.Sub());
            TestTypes.ClassWithBaseCollectionField sub = new TestTypes.ClassWithBaseCollectionField(baseClasses);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1005,sub);
            JsonObject json = gson.toJsonTree(sub).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1006,json);
            JsonArray bases = json.get(TestTypes.ClassWithBaseArrayField.FIELD_KEY).getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1007,bases);
            for (JsonElement element : bases) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1002,com.google.gson.common.TestTypes.Sub.SUB_NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1003,element.getAsJsonObject().get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testClassWithBaseCollectionFieldSerialization_remove177() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithBaseCollectionFieldSerialization_remove177");
            Collection<com.google.gson.common.TestTypes.Base> baseClasses = new ArrayList<com.google.gson.common.TestTypes.Base>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1004,baseClasses);
            baseClasses.add(new TestTypes.Sub());
            TestTypes.ClassWithBaseCollectionField sub = new TestTypes.ClassWithBaseCollectionField(baseClasses);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1005,sub);
            JsonObject json = gson.toJsonTree(sub).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1006,json);
            JsonArray bases = json.get(TestTypes.ClassWithBaseArrayField.FIELD_KEY).getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1007,bases);
            for (JsonElement element : bases) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1002,com.google.gson.common.TestTypes.Sub.SUB_NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1003,element.getAsJsonObject().get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testClassWithBaseCollectionFieldSerialization_remove178() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithBaseCollectionFieldSerialization_remove178");
            Collection<com.google.gson.common.TestTypes.Base> baseClasses = new ArrayList<com.google.gson.common.TestTypes.Base>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1004,baseClasses);
            baseClasses.add(new TestTypes.Sub());
            TestTypes.ClassWithBaseCollectionField sub = new TestTypes.ClassWithBaseCollectionField(baseClasses);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1005,sub);
            JsonObject json = gson.toJsonTree(sub).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1006,json);
            JsonArray bases = json.get(TestTypes.ClassWithBaseArrayField.FIELD_KEY).getAsJsonArray();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1007,bases);
            for (JsonElement element : bases) {
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1002,com.google.gson.common.TestTypes.Sub.SUB_NAME);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1003,element.getAsJsonObject().get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseSerializedAsSub() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseSerializedAsSub");
            TestTypes.Base base = new TestTypes.Sub();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),985,base);
            JsonObject json = gson.toJsonTree(base).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),127,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),983,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),984,json.get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseSerializedAsSubForToJsonMethod() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseSerializedAsSubForToJsonMethod");
            TestTypes.Base base = new TestTypes.Sub();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),987,base);
            String json = gson.toJson(base);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),988,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),986,json.contains(com.google.gson.common.TestTypes.Sub.SUB_NAME));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseSerializedAsBaseWhenSpecifiedWithExplicitType() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseSerializedAsBaseWhenSpecifiedWithExplicitType");
            TestTypes.Base base = new TestTypes.Sub();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),977,base);
            JsonObject json = gson.toJsonTree(base, TestTypes.Base.class).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),978,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),974,com.google.gson.common.TestTypes.Base.BASE_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),975,json.get(com.google.gson.common.TestTypes.Base.BASE_FIELD_KEY).getAsString());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),976,json.get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseSerializedAsBaseWhenSpecifiedWithExplicitTypeForToJsonMethod() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseSerializedAsBaseWhenSpecifiedWithExplicitTypeForToJsonMethod");
            TestTypes.Base base = new TestTypes.Sub();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),981,base);
            String json = gson.toJson(base, TestTypes.Base.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),982,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),979,json.contains(com.google.gson.common.TestTypes.Base.BASE_NAME));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),980,json.contains(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseSerializedAsSubWhenSpecifiedWithExplicitType() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseSerializedAsSubWhenSpecifiedWithExplicitType");
            TestTypes.Base base = new TestTypes.Sub();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),991,base);
            JsonObject json = gson.toJsonTree(base, TestTypes.Sub.class).getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),992,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),989,com.google.gson.common.TestTypes.Sub.SUB_NAME);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),990,json.get(com.google.gson.common.TestTypes.Sub.SUB_FIELD_KEY).getAsString());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBaseSerializedAsSubWhenSpecifiedWithExplicitTypeForToJsonMethod() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBaseSerializedAsSubWhenSpecifiedWithExplicitTypeForToJsonMethod");
            TestTypes.Base base = new TestTypes.Sub();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),994,base);
            String json = gson.toJson(base, TestTypes.Sub.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),995,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),993,json.contains(com.google.gson.common.TestTypes.Sub.SUB_NAME));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class SubTypeOfNested extends TestTypes.Nested {
        private final long value = 5;

        public SubTypeOfNested(TestTypes.BagOfPrimitives primitive1 ,TestTypes.BagOfPrimitives primitive2) {
            super(primitive1, primitive2);
        }

        @Override
        public void appendFields(StringBuilder sb) {
            sb.append("\"value\":").append(value).append(",");
            super.appendFields(sb);
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add189() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add189");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add190() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add190");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add191() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add191");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add192() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add192");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add193() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add193");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add194() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add194");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add195() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add195");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add196() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add196");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add197() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add197");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add198() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add198");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add199() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add199");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add200() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add200");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add201() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add201");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add202() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add202");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add203() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add203");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_add204() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_add204");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(1);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1498() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1498");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(-1);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1499() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1499");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1501() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1501");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(2);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1502() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1502");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(0);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1503() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1503");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(0);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1505() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1505");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(1);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1506() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1506");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(4);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1507() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1507");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(3);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1509() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1509");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(4);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1510() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1510");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(2);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1511() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1511");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(1);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1512() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1512");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(6);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1514() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1514");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(1L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1515() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1515");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(-1L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1516() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1516");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1518() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1518");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(2L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1519() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1519");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(0L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1520() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1520");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(0L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1522() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1522");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(1L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1523() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1523");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(4L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1524() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1524");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(3L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1526() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1526");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(4L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1527() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1527");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(2L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1528() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1528");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(1L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1529() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1529");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(6L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1531() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1531");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(-0.9F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1532() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1532");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.05F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1533() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1533");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1534() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1534");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(1.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1536() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1536");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(1.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1537() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1537");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(-0.8F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1538() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1538");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.1F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1539() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1539");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.4F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1541() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1541");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(-0.7F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1542() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1542");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.15F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1543() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1543");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.6F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1544() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1544");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(1.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1546() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1546");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(1.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1547() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1547");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(-0.6F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1548() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1548");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.2F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionSerialization_literalMutation1549() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_literalMutation1549");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.8F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove179() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove179");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove180() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove180");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove181() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove181");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove182() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove182");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove183() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove183");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove184() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove184");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove185() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove185");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove186() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove186");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.1F);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove187() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove187");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove188() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove188");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove189() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove189");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove190() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove190");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove191() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove191");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove192() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove192");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove193() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove193");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testSubInterfacesOfCollectionSerialization_remove194() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionSerialization_remove194");
            List<java.lang.Integer> list = new LinkedList<java.lang.Integer>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1024,list);
            list.add(0);
            list.add(1);
            list.add(2);
            list.add(3);
            Queue<java.lang.Long> queue = new LinkedList<java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1025,queue);
            queue.add(0L);
            queue.add(1L);
            queue.add(2L);
            queue.add(3L);
            Set<java.lang.Float> set = new TreeSet<java.lang.Float>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1026,set);
            set.add(0.2F);
            set.add(0.3F);
            set.add(0.4F);
            SortedSet<java.lang.Character> sortedSet = new TreeSet<java.lang.Character>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1027,sortedSet);
            sortedSet.add('a');
            sortedSet.add('b');
            sortedSet.add('c');
            sortedSet.add('d');
            ClassWithSubInterfacesOfCollection target = new ClassWithSubInterfacesOfCollection(list , queue , set , sortedSet);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1028,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1023,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),162,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionDeserialization");
            String json = "{\"list\":[0,1,2,P],\"queue\":[0,1,2,3],\"set\":[0.1,0.2,0.3,0.4]," + ("\"sortedSet\":[\"a\",\"b\",\"c\",\"d\"]" + "}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1021,json);
            ClassWithSubInterfacesOfCollection target = gson.fromJson(json, ClassWithSubInterfacesOfCollection.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1022,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1017,target.listContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1018,target.queueContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1019,target.setContains(0.1F, 0.2F, 0.3F, 0.4F));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1020,target.sortedSetContains('a', 'b', 'c', 'd'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionDeserialization_literalMutation1492() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionDeserialization_literalMutation1492");
            String json = "{\"list\":[0,1,2,3]¦,\"queue\":[0,1,2,3],\"set\":[0.1,0.2,0.3,0.4]," + ("\"sortedSet\":[\"a\",\"b\",\"c\",\"d\"]" + "}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1021,json);
            ClassWithSubInterfacesOfCollection target = gson.fromJson(json, ClassWithSubInterfacesOfCollection.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1022,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1017,target.listContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1018,target.queueContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1019,target.setContains(0.1F, 0.2F, 0.3F, 0.4F));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1020,target.sortedSetContains('a', 'b', 'c', 'd'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionDeserialization_literalMutation1493() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionDeserialization_literalMutation1493");
            String json = "{\"list\":[0,1,2,3],\"queue\":[0,1,2,3]\"set\":[0.1,0.2,0.3,0.4]," + ("\"sortedSet\":[\"a\",\"b\",\"c\",\"d\"]" + "}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1021,json);
            ClassWithSubInterfacesOfCollection target = gson.fromJson(json, ClassWithSubInterfacesOfCollection.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1022,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1017,target.listContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1018,target.queueContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1019,target.setContains(0.1F, 0.2F, 0.3F, 0.4F));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1020,target.sortedSetContains('a', 'b', 'c', 'd'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionDeserialization_literalMutation1494() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionDeserialization_literalMutation1494");
            String json = "{\"list\":[0,1,2,3],\"queue\":[0,1,2,3],\"set\":[0.1,0.2,0.3,0.4]," + ("\"sortedôet\":[\"a\",\"b\",\"c\",\"d\"]" + "}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1021,json);
            ClassWithSubInterfacesOfCollection target = gson.fromJson(json, ClassWithSubInterfacesOfCollection.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1022,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1017,target.listContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1018,target.queueContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1019,target.setContains(0.1F, 0.2F, 0.3F, 0.4F));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1020,target.sortedSetContains('a', 'b', 'c', 'd'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionDeserialization_literalMutation1495() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionDeserialization_literalMutation1495");
            String json = "{\"list\":[0,1,2,3],\"queue\":[0,1,2,3],\"set\":[0.1,0.2,0.3,0.4]," + ("\"sortedSet\":[\"a\",\"b\",\"c\",\"d\"]" + "}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1021,json);
            ClassWithSubInterfacesOfCollection target = gson.fromJson(json, ClassWithSubInterfacesOfCollection.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1022,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1017,target.listContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1018,target.queueContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1019,target.setContains(0.1F, 0.2F, 0.3F, 0.4F));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1020,target.sortedSetContains('a', 'b', 'c', 'd'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testSubInterfacesOfCollectionDeserialization_literalMutation1496() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSubInterfacesOfCollectionDeserialization_literalMutation1496");
            String json = "{\"list\":[0,1,2,3],\"queue\":[0,1,2,3],\"set\":[0.1,0.2,0.3,0.4]," + ("\"sortedSet\":[\"a\",\"b\",\"c,\"d\"]" + "}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1021,json);
            ClassWithSubInterfacesOfCollection target = gson.fromJson(json, ClassWithSubInterfacesOfCollection.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1022,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1017,target.listContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1018,target.queueContains(0, 1, 2, 3));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1019,target.setContains(0.1F, 0.2F, 0.3F, 0.4F));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1020,target.sortedSetContains('a', 'b', 'c', 'd'));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithSubInterfacesOfCollection {
        private List<java.lang.Integer> list;

        private Queue<java.lang.Long> queue;

        private Set<java.lang.Float> set;

        private SortedSet<java.lang.Character> sortedSet;

        public ClassWithSubInterfacesOfCollection(List<java.lang.Integer> list ,Queue<java.lang.Long> queue ,Set<java.lang.Float> set ,SortedSet<java.lang.Character> sortedSet) {
            this.list = list;
            this.queue = queue;
            this.set = set;
            this.sortedSet = sortedSet;
        }

        boolean listContains(int... values) {
            for (int value : values) {
                if (!(list.contains(value))) {
                    return false;
                } 
            }
            return true;
        }

        boolean queueContains(long... values) {
            for (long value : values) {
                if (!(queue.contains(value))) {
                    return false;
                } 
            }
            return true;
        }

        boolean setContains(float... values) {
            for (float value : values) {
                if (!(set.contains(value))) {
                    return false;
                } 
            }
            return true;
        }

        boolean sortedSetContains(char... values) {
            for (char value : values) {
                if (!(sortedSet.contains(value))) {
                    return false;
                } 
            }
            return true;
        }

        public String getExpectedJson() {
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),970,sb);
            sb.append("{");
            sb.append("\"list\":");
            append(sb, list).append(",");
            sb.append("\"queue\":");
            append(sb, queue).append(",");
            sb.append("\"set\":");
            append(sb, set).append(",");
            sb.append("\"sortedSet\":");
            append(sb, sortedSet);
            sb.append("}");
            return sb.toString();
        }

        private StringBuilder append(StringBuilder sb, Collection<?> c) {
            sb.append("[");
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),972,first);
            for (Object o : c) {
                if (!first) {
                    sb.append(",");
                } else {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),971,first);
                }
                if ((o instanceof String) || (o instanceof Character)) {
                    sb.append('\"');
                } 
                sb.append(o.toString());
                if ((o instanceof String) || (o instanceof Character)) {
                    sb.append('\"');
                } 
            }
            sb.append("]");
            return sb;
        }
    }
}

