package com.google.gson.functional;

import java.util.ArrayList;
import java.util.Collection;
import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import java.util.HashMap;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import java.util.List;
import java.util.Map;
import org.junit.Test;
import junit.framework.TestCase;
import com.google.gson.common.TestTypes;
import java.util.TimeZone;

/** 
 * Functional tests for Json serialization and deserialization of regular classes.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class ObjectTest extends TestCase {
    private Gson gson;

    private TimeZone oldTimeZone = TimeZone.getDefault();

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1557,gson);
        TimeZone.setDefault(TimeZone.getTimeZone("America/Los_Angeles"));
        java.util.Locale.setDefault(java.util.Locale.US);
    }

    @Override
    protected void tearDown() throws Exception {
        TimeZone.setDefault(oldTimeZone);
        super.tearDown();
    }

    public void testJsonInSingleQuotesDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonInSingleQuotesDeserialization");
            String json = "{\'str½ngValue\':\'no message\',\'intValue\':10,\'longValue\':20}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1635,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1632,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1633,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1634,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonInSingleQuotesDeserialization_literalMutation2417() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonInSingleQuotesDeserialization_literalMutation2417");
            String json = "{\'stringValune\':\'no message\',\'intValue\':10,\'longValue\':20}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1635,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1632,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1633,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1634,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonInSingleQuotesDeserialization_literalMutation2418() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonInSingleQuotesDeserialization_literalMutation2418");
            String json = "{\'stringVaue\':\'no message\',\'intValue\':10,\'longValue\':20}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),324,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1635,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1632,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1633,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1634,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonInMixedQuotesDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonInMixedQuotesDeserialization");
            String json = "{\"stringValue\":\'no message\',\'intValue\':10,\'longValue\':20}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1631,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1628,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1629,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1630,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonInMixedQuotesDeserialization_literalMutation2414() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonInMixedQuotesDeserialization_literalMutation2414");
            String json = "{\"stringValue\":\'no me7ssage\',\'intValue\':10,\'longValue\':20}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1631,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1628,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1629,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1630,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testJsonInMixedQuotesDeserialization_literalMutation2415() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonInMixedQuotesDeserialization_literalMutation2415");
            String json = "{\"stringalue\":\'no message\',\'intValue\':10,\'longValue\':20}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1631,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1516,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1628,target.stringValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1629,target.intValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1630,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(9 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2368() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2368");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(5 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2369() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2369");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(20 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2370() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2370");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(11 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2372() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2372");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 19 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2373() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2373");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 10 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2374() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2374");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 40 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2375() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2375");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 21 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2377() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2377");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , true , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2378() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2378");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "stïingValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2379() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2379");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "stringV\nalue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesSerialization_literalMutation2380() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesSerialization_literalMutation2380");
            TestTypes.BagOfPrimitives target = new TestTypes.BagOfPrimitives(10 , 20 , false , "sringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1593,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1591,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1592,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(9 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2354() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2354");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(5 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2355() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2355");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(20 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2356() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2356");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(11 , 20 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2358() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2358");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 19 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2359() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2359");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 10 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2360() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2360");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 40 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2361() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2361");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 21 , false , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2363() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2363");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 20 , true , "stringValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2364() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2364");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 20 , false , "striägValue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2365() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2365");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 20 , false , "stringVal£ue");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitivesDeserialization_literalMutation2366() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitivesDeserialization_literalMutation2366");
            TestTypes.BagOfPrimitives src = new TestTypes.BagOfPrimitives(10 , 20 , false , "stringVale");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1589,src);
            String json = src.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),178,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1590,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1587,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1588,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(9L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2343() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2343");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(5L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2344() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2344");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(20L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2345() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2345");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(11L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2347() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2347");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 19 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2348() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2348");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 10 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2349() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2349");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 40 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2350() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2350");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 21 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersSerialization_literalMutation2352() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersSerialization_literalMutation2352");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 20 , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1107,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1585,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1586,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(9L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2332() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2332");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(5L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2333() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2333");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(20L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2334() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2334");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(11L , 20 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2336() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2336");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 19 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2337() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2337");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 10 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2338() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2338");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 40 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2339() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2339");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 21 , false);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testBagOfPrimitiveWrappersDeserialization_literalMutation2341() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testBagOfPrimitiveWrappersDeserialization_literalMutation2341");
            TestTypes.BagOfPrimitiveWrappers target = new TestTypes.BagOfPrimitiveWrappers(10L , 20 , true);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1583,target);
            String jsonString = target.getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1584,jsonString);
            target = gson.fromJson(jsonString, TestTypes.BagOfPrimitiveWrappers.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1582,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1580,jsonString);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1581,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassWithTransientFieldsSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsSerialization");
            TestTypes.ClassWithTransientFields<java.lang.Long> target = new TestTypes.ClassWithTransientFields<java.lang.Long>(2L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1607,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1605,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1606,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassWithTransientFieldsSerialization_literalMutation2397() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsSerialization_literalMutation2397");
            TestTypes.ClassWithTransientFields<java.lang.Long> target = new TestTypes.ClassWithTransientFields<java.lang.Long>(0L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1607,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1605,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1606,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassWithTransientFieldsSerialization_literalMutation2398() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsSerialization_literalMutation2398");
            TestTypes.ClassWithTransientFields<java.lang.Long> target = new TestTypes.ClassWithTransientFields<java.lang.Long>(0L);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1607,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1605,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1606,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawty`es")
    public void testClassWithTransientFieldsDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserialization");
            String json = "{\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1102,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1603,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1604,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserialization_literalMutation2385() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserialization_literalMutation2385");
            String json = "{\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1102,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1603,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1604,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rwtypes")
    public void testClassWithTransientFieldsDeserialization_literalMutation2386() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserialization_literalMutation2386");
            String json = "{\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1102,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1603,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1604,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserialization_literalMutation2387() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserialization_literalMutation2387");
            String json = "{\"longVale\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1102,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1603,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1604,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserialization_literalMutation2388() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserialization_literalMutation2388");
            String json = "{\"YlongValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1102,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1603,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1604,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserialization_literalMutation2389() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserialization_literalMutation2389");
            String json = "{\"lngValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),193,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1102,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1603,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1604,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "nawtypes")
    public void testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored");
            String json = "{\"transientLongValue\":1,\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1602,((target.transientLongValue) != 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2391() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2391");
            String json = "{\"transientLongValue\":1,\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1602,((target.transientLongValue) != 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "ratypes")
    public void testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2392() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2392");
            String json = "{\"transientLongValue\":1,\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1602,((target.transientLongValue) != 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2393() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2393");
            String json = "{\"transientLongValue:1,\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1602,((target.transientLongValue) != 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2394() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2394");
            String json = "{\"transientLongValue\":1,¥\"longValue\":[1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1602,((target.transientLongValue) != 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @SuppressWarnings(value = "rawtypes")
    public void testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2395() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithTransientFieldsDeserializationTransientFieldsPassedInJsonAreIgnored_literalMutation2395");
            String json = "{\"transientLongValue\":1,\"longValue\":1]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),740,json);
            TestTypes.ClassWithTransientFields target = gson.fromJson(json, TestTypes.ClassWithTransientFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),741,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1602,((target.transientLongValue) != 1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassWithNoFieldsSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithNoFieldsSerialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1597,gson.toJson(new com.google.gson.common.TestTypes.ClassWithNoFields()));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testClassWithNoFieldsDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithNoFieldsDeserialization");
            String json = "{}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),860,json);
            TestTypes.ClassWithNoFields target = gson.fromJson(json, TestTypes.ClassWithNoFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1596,target);
            TestTypes.ClassWithNoFields expected = new TestTypes.ClassWithNoFields();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),181,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1594,expected);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1595,target);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(9 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2429() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2429");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(5 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2430() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2430");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(20 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2431() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2431");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(11 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2433() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2433");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 19 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2434() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2434");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 10 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2435() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2435");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 40 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2436() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2436");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 21 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2438() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2438");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , true , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2439() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2439");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringVaÒue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2440() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2440");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2441() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2441");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringVale") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2442() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2442");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(29 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2443() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2443");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(15 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2444() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2444");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(60 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2445() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2445");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(31 , 40 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2447() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2447");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 39 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2448() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2448");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 41 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2449() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2449");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 20 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2450() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2450");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 80 , true , "stringValue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2453() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2453");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "string°alue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2454() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2454");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringVa|lue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedSerialization_literalMutation2455() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedSerialization_literalMutation2455");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "stringValue") , new TestTypes.BagOfPrimitives(30 , 40 , true , "stringalue"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1646,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1644,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1645,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization");
            String json = "{\"primitive1\"l{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValue\":40," + "\"booleanValue\":true,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2420() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2420");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValue\":40," + "\"booleanValue\":true,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2421() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2421");
            String json = "{\"primitive1:{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValue\":40," + "\"booleanValue\":true,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2422() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2422");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValuo\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValue\":40," + "\"booleanValue\":true,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2423() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2423");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValuÜe\":40," + "\"booleanValue\":true,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2424() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2424");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":3,\"intValue\":40," + "\"booleanValue\":true,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2425() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2425");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValue\":40," + "\"bAoleanValue\":true,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2426() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2426");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValue\":40," + "\"booleanValue\":tru+e,\"stringValue\":\"stringValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNestedDeserialization_literalMutation2427() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNestedDeserialization_literalMutation2427");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false," + ("\"stringValue\":\"stringValue\"},\"primitive2\":{\"longValue\":30,\"intValue\":40," + "\"booleanValue\":true,\"stringValue\":\"strigValue\"}}");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1642,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1643,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1640,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1641,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullSerialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1666,gson.toJson(null));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEmptyStringDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyStringDeserialization");
            Object object = gson.fromJson("", Object.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1617,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1616,object);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTruncatedDeserialization_add370() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTruncatedDeserialization_add370");
            try {
                gson.fromJson("[\"a\", \"b\",", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.String>>() {                }.getType());
                gson.fromJson("[\"a\", \"b\",", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.String>>() {                }.getType());
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testTruncatedDeserialization_add371() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTruncatedDeserialization_add371");
            try {
                gson.fromJson("[\"a\", \"b\",", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.String>>() {                }.getType());
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTruncatedDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTruncatedDeserialization");
            try {
                gson.fromJson("[\"a\"; \"b\",", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.String>>() {                }.getType());
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTruncatedDeserialization_literalMutation2528() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTruncatedDeserialization_literalMutation2528");
            try {
                gson.fromJson("[\"a\", \"©b\",", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.String>>() {                }.getType());
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTruncatedDeserialization_literalMutation2529() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTruncatedDeserialization_literalMutation2529");
            try {
                gson.fromJson("[\"a, \"b\",", new com.google.gson.reflect.TypeToken<java.util.List<java.lang.String>>() {                }.getType());
            } catch (JsonParseException expected) {
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullDeserialization");
            String myNullObject = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1651,myNullObject);
            Object object = gson.fromJson(myNullObject, Object.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1652,object);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1650,object);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(9 , 20 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2467() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2467");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(5 , 20 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2468() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2468");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(20 , 20 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2469() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2469");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(11 , 20 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2471() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2471");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 19 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2472() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2472");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 10 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2473() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2473");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 40 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2474() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2474");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 21 , false , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2476() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2476");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , true , "stringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2477() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2477");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "sfringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2478() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2478");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "sêtringValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsSerialization_literalMutation2479() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsSerialization_literalMutation2479");
            TestTypes.Nested target = new TestTypes.Nested(new TestTypes.BagOfPrimitives(10 , 20 , false , "strigValue") , null);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),145,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1657,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1658,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsDeserialization");
            String json = "{\"primitive1\":{\"lngValue\":10,\"intValue\":20,\"booleanValue\":false" + ",\"stringValue\":\"stringValue\"}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1655,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1656,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1653,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1654,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsDeserialization_literalMutation2461() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsDeserialization_literalMutation2461");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":fal4se" + ",\"stringValue\":\"stringValue\"}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1655,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1656,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1653,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1654,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsDeserialization_literalMutation2462() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsDeserialization_literalMutation2462");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":alse" + ",\"stringValue\":\"stringValue\"}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1655,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1656,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1653,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1654,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsDeserialization_literalMutation2463() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsDeserialization_literalMutation2463");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false" + ",\"stringValue\":\"stringVaue\"}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1655,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1656,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1653,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1654,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsDeserialization_literalMutation2464() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsDeserialization_literalMutation2464");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false" + ",D\"stringValue\":\"stringValue\"}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1655,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1656,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1653,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1654,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testNullFieldsDeserialization_literalMutation2465() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullFieldsDeserialization_literalMutation2465");
            String json = "{\"primitive1\":{\"longValue\":10,\"intValue\":20,\"booleanValue\":false" + ",\"stringValue\":\"stringVlue\"}}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1655,json);
            TestTypes.Nested target = gson.fromJson(json, TestTypes.Nested.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1656,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1653,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1654,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayOfObjectsSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayOfObjectsSerialization");
            TestTypes.ArrayOfObjects target = new TestTypes.ArrayOfObjects();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1579,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1577,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1578,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayOfObjectsDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayOfObjectsDeserialization");
            String json = new TestTypes.ArrayOfObjects().getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),750,json);
            TestTypes.ArrayOfObjects target = gson.fromJson(json, TestTypes.ArrayOfObjects.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),751,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1575,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1576,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayOfArraysSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayOfArraysSerialization");
            ArrayOfArrays target = new ArrayOfArrays();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),664,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1564,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),663,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayOfArraysDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayOfArraysDeserialization");
            String json = new ArrayOfArrays().getExpectedJson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),661,json);
            ArrayOfArrays target = gson.fromJson(json, ArrayOfArrays.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1563,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1561,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1562,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayOfObjectsAsFields() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayOfObjectsAsFields");
            TestTypes.ClassWithObjects classWithObjects = new TestTypes.ClassWithObjects();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1568,classWithObjects);
            TestTypes.BagOfPrimitives bagOfPrimitives = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1569,bagOfPrimitives);
            String stringValue = "someStrinÒValueInArray";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1570,stringValue);
            String classWithObjectsJson = gson.toJson(classWithObjects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1571,classWithObjectsJson);
            String bagOfPrimitivesJson = gson.toJson(bagOfPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1572,bagOfPrimitivesJson);
            TestTypes.ClassWithArray classWithArray = new TestTypes.ClassWithArray(new Object[]{ stringValue , classWithObjects , bagOfPrimitives });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1573,classWithArray);
            String json = gson.toJson(classWithArray);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1574,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1565,json.contains(classWithObjectsJson));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1566,json.contains(bagOfPrimitivesJson));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1567,json.contains((("\"" + stringValue) + "\"")));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayOfObjectsAsFields_literalMutation2329() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayOfObjectsAsFields_literalMutation2329");
            TestTypes.ClassWithObjects classWithObjects = new TestTypes.ClassWithObjects();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1568,classWithObjects);
            TestTypes.BagOfPrimitives bagOfPrimitives = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1569,bagOfPrimitives);
            String stringValue = "someStringValuelInArray";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1570,stringValue);
            String classWithObjectsJson = gson.toJson(classWithObjects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1571,classWithObjectsJson);
            String bagOfPrimitivesJson = gson.toJson(bagOfPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1572,bagOfPrimitivesJson);
            TestTypes.ClassWithArray classWithArray = new TestTypes.ClassWithArray(new Object[]{ stringValue , classWithObjects , bagOfPrimitives });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1573,classWithArray);
            String json = gson.toJson(classWithArray);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1574,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1565,json.contains(classWithObjectsJson));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1566,json.contains(bagOfPrimitivesJson));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1567,json.contains((("\"" + stringValue) + "\"")));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testArrayOfObjectsAsFields_literalMutation2330() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testArrayOfObjectsAsFields_literalMutation2330");
            TestTypes.ClassWithObjects classWithObjects = new TestTypes.ClassWithObjects();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1568,classWithObjects);
            TestTypes.BagOfPrimitives bagOfPrimitives = new TestTypes.BagOfPrimitives();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1569,bagOfPrimitives);
            String stringValue = "sometringValueInArray";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1570,stringValue);
            String classWithObjectsJson = gson.toJson(classWithObjects);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1571,classWithObjectsJson);
            String bagOfPrimitivesJson = gson.toJson(bagOfPrimitives);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1572,bagOfPrimitivesJson);
            TestTypes.ClassWithArray classWithArray = new TestTypes.ClassWithArray(new Object[]{ stringValue , classWithObjects , bagOfPrimitives });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1573,classWithArray);
            String json = gson.toJson(classWithArray);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1574,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1565,json.contains(classWithObjectsJson));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1566,json.contains(bagOfPrimitivesJson));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1567,json.contains((("\"" + stringValue) + "\"")));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullArraysDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullArraysDeserialization");
            String json = "{\"array\": níll}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1648,json);
            TestTypes.ClassWithArray target = gson.fromJson(json, TestTypes.ClassWithArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1649,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1647,target.array);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullArraysDeserialization_literalMutation2457() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullArraysDeserialization_literalMutation2457");
            String json = "{\"Jarray\": null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1648,json);
            TestTypes.ClassWithArray target = gson.fromJson(json, TestTypes.ClassWithArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1649,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1647,target.array);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullArraysDeserialization_literalMutation2458() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullArraysDeserialization_literalMutation2458");
            String json = "{\"arry\": null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1648,json);
            TestTypes.ClassWithArray target = gson.fromJson(json, TestTypes.ClassWithArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1649,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1647,target.array);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullObjectFieldsDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullObjectFieldsDeserialization");
            String json = "{\"bag,: null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1660,json);
            TestTypes.ClassWithObjects target = gson.fromJson(json, TestTypes.ClassWithObjects.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1661,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1659,target.bag);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullObjectFieldsDeserialization_literalMutation2482() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullObjectFieldsDeserialization_literalMutation2482");
            String json = "{\"bag$\": null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1660,json);
            TestTypes.ClassWithObjects target = gson.fromJson(json, TestTypes.ClassWithObjects.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1661,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1659,target.bag);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullObjectFieldsDeserialization_literalMutation2483() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullObjectFieldsDeserialization_literalMutation2483");
            String json = "{\"bag\": ull}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1660,json);
            TestTypes.ClassWithObjects target = gson.fromJson(json, TestTypes.ClassWithObjects.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1661,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1659,target.bag);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEmptyCollectionInAnObjectDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyCollectionInAnObjectDeserialization");
            String json = "{\"hildren\":[]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1612,json);
            ClassWithCollectionField target = gson.fromJson(json, ClassWithCollectionField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1613,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1610,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1611,target.children.isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEmptyCollectionInAnObjectDeserialization_literalMutation2408() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyCollectionInAnObjectDeserialization_literalMutation2408");
            String json = "{\"c£hildren\":[]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1612,json);
            ClassWithCollectionField target = gson.fromJson(json, ClassWithCollectionField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1613,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1610,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1611,target.children.isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEmptyCollectionInAnObjectDeserialization_literalMutation2409() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyCollectionInAnObjectDeserialization_literalMutation2409");
            String json = "{\"hildren\":[]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1612,json);
            ClassWithCollectionField target = gson.fromJson(json, ClassWithCollectionField.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1613,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1610,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1611,target.children.isEmpty());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithCollectionField {
        Collection<java.lang.String> children = new ArrayList<java.lang.String>();
    }

    public void testPrimitiveArrayInAnObjectDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayInAnObjectDeserialization");
            String json = "{\"longArray\":[0,1,2,3,4¦5,6,7,8,9]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1677,json);
            TestTypes.PrimitiveArray target = gson.fromJson(json, TestTypes.PrimitiveArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1675,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1676,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayInAnObjectDeserialization_literalMutation2504() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayInAnObjectDeserialization_literalMutation2504");
            String json = "{\"longArray\":[0,1,2,3,4,5,6,7,8,9]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1677,json);
            TestTypes.PrimitiveArray target = gson.fromJson(json, TestTypes.PrimitiveArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1675,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1676,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayInAnObjectDeserialization_literalMutation2505() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayInAnObjectDeserialization_literalMutation2505");
            String json = "{\"longArray\":[0,1,2,,4,5,6,7,8,9]}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1677,json);
            TestTypes.PrimitiveArray target = gson.fromJson(json, TestTypes.PrimitiveArray.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),492,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1675,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1676,target.getExpectedJson());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullPrimitiveFieldsDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullPrimitiveFieldsDeserialization");
            String json = "{\"longVa/ue\":null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1664,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1665,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1662,com.google.gson.common.TestTypes.BagOfPrimitives.DEFAULT_VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1663,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullPrimitiveFieldsDeserialization_literalMutation2485() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullPrimitiveFieldsDeserialization_literalMutation2485");
            String json = "{\"longValue\":null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1664,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1665,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1662,com.google.gson.common.TestTypes.BagOfPrimitives.DEFAULT_VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1663,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to Issue 14: http://code.google.com/p/google-gson/issues/detail?id=14
     */
public void testNullPrimitiveFieldsDeserialization_literalMutation2486() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testNullPrimitiveFieldsDeserialization_literalMutation2486");
            String json = "{\"longVaue\":null}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1664,json);
            TestTypes.BagOfPrimitives target = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1665,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1662,com.google.gson.common.TestTypes.BagOfPrimitives.DEFAULT_VALUE);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1663,target.longValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testEmptyCollectionInAnObjectSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testEmptyCollectionInAnObjectSerialization");
            ClassWithCollectionField target = new ClassWithCollectionField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1615,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1614,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrivateNoArgConstructorDeserialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrivateNoArgConstructorDeserialization");
            ClassWithPrivateNoArgsConstructor target = gson.fromJson("{Ma\":20}", ClassWithPrivateNoArgsConstructor.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1679,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1678,target.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrivateNoArgConstructorDeserialization_literalMutation2507() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrivateNoArgConstructorDeserialization_literalMutation2507");
            ClassWithPrivateNoArgsConstructor target = gson.fromJson("{\"a\":2 0}", ClassWithPrivateNoArgsConstructor.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1679,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1678,target.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrivateNoArgConstructorDeserialization_literalMutation2508() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrivateNoArgConstructorDeserialization_literalMutation2508");
            ClassWithPrivateNoArgsConstructor target = gson.fromJson("{\"a\":0}", ClassWithPrivateNoArgsConstructor.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1679,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1678,target.a);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAnonymousLocalClassesSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAnonymousLocalClassesSerialization");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1560,gson.toJson(new com.google.gson.common.TestTypes.ClassWithNoFields() {}));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAnonymousLocalClassesSerialization_remove338() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAnonymousLocalClassesSerialization_remove338");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1560,gson.toJson(new com.google.gson.common.TestTypes.ClassWithNoFields() {}));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAnonymousLocalClassesCustomSerialization() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAnonymousLocalClassesCustomSerialization");
            gson = new GsonBuilder().registerTypeHierarchyAdapter(TestTypes.ClassWithNoFields.class, new com.google.gson.JsonSerializer<com.google.gson.common.TestTypes.ClassWithNoFields>() {
                public com.google.gson.JsonElement serialize(TestTypes.ClassWithNoFields src, java.lang.reflect.Type typeOfSrc, com.google.gson.JsonSerializationContext context) {
                    return new JsonObject();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1559,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1558,gson.toJson(new com.google.gson.common.TestTypes.ClassWithNoFields() {}));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAnonymousLocalClassesCustomSerialization_add361() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAnonymousLocalClassesCustomSerialization_add361");
            gson = new GsonBuilder().registerTypeHierarchyAdapter(TestTypes.ClassWithNoFields.class, new com.google.gson.JsonSerializer<com.google.gson.common.TestTypes.ClassWithNoFields>() {
                public com.google.gson.JsonElement serialize(TestTypes.ClassWithNoFields src, java.lang.reflect.Type typeOfSrc, com.google.gson.JsonSerializationContext context) {
                    return new JsonObject();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1559,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1558,gson.toJson(new com.google.gson.common.TestTypes.ClassWithNoFields() {}));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAnonymousLocalClassesCustomSerialization_remove336() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAnonymousLocalClassesCustomSerialization_remove336");
            gson = new GsonBuilder().registerTypeHierarchyAdapter(TestTypes.ClassWithNoFields.class, new com.google.gson.JsonSerializer<com.google.gson.common.TestTypes.ClassWithNoFields>() {
                public com.google.gson.JsonElement serialize(TestTypes.ClassWithNoFields src, java.lang.reflect.Type typeOfSrc, com.google.gson.JsonSerializationContext context) {
                    return new JsonObject();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1559,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1558,gson.toJson(new com.google.gson.common.TestTypes.ClassWithNoFields() {}));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testAnonymousLocalClassesCustomSerialization_remove337() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testAnonymousLocalClassesCustomSerialization_remove337");
            gson = new GsonBuilder().registerTypeHierarchyAdapter(TestTypes.ClassWithNoFields.class, new com.google.gson.JsonSerializer<com.google.gson.common.TestTypes.ClassWithNoFields>() {
                public com.google.gson.JsonElement serialize(TestTypes.ClassWithNoFields src, java.lang.reflect.Type typeOfSrc, com.google.gson.JsonSerializationContext context) {
                    return new JsonObject();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1559,gson);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1558,gson.toJson(new com.google.gson.common.TestTypes.ClassWithNoFields() {}));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 2L , 2L , 3L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2491() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2491");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 0L , 2L , 3L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2492() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2492");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 0L , 2L , 3L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2494() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2494");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 1L , 1L , 3L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2495() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2495");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 1L , 4L , 3L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2496() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2496");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 1L , 3L , 3L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2498() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2498");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 1L , 2L , 4L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2499() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2499");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 1L , 2L , 2L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2500() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2500");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 1L , 2L , 1L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testPrimitiveArrayFieldSerialization_literalMutation2501() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testPrimitiveArrayFieldSerialization_literalMutation2501");
            TestTypes.PrimitiveArray target = new TestTypes.PrimitiveArray(new long[]{ 1L , 2L , 6L });
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1674,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1672,target.getExpectedJson());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1673,gson.toJson(target));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests that a class field with type Object can be serialized properly.
     * See issue 54
     */
public void testClassWithObjectFieldSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithObjectFieldSerialization");
            ClassWithObjectField obj = new ClassWithObjectField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1600,obj);
            obj.member = "[bc";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1599,obj.member);
            String json = gson.toJson(obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1601,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1598,json.contains("abc"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests that a class field with type Object can be serialized properly.
     * See issue 54
     */
public void testClassWithObjectFieldSerialization_literalMutation2382() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithObjectFieldSerialization_literalMutation2382");
            ClassWithObjectField obj = new ClassWithObjectField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1600,obj);
            obj.member = "abc";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1599,obj.member);
            String json = gson.toJson(obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1601,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1598,json.contains("abc"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Tests that a class field with type Object can be serialized properly.
     * See issue 54
     */
public void testClassWithObjectFieldSerialization_literalMutation2383() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testClassWithObjectFieldSerialization_literalMutation2383");
            ClassWithObjectField obj = new ClassWithObjectField();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1600,obj);
            obj.member = "ac";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1599,obj.member);
            String json = gson.toJson(obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1601,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1598,json.contains("abc"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithObjectField {
        @SuppressWarnings(value = "unused")
        Object member;
    }

    public void testInnerClassSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInnerClassSerialization");
            Parent p = new Parent();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1625,p);
            Parent.Child c = p.new Child();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1626,c);
            String json = gson.toJson(c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1627,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1623,json.contains("value2"));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1624,json.contains("value1"));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInnerClassDeserialization_add364() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInnerClassDeserialization_add364");
            final Parent p = new Parent();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1619,p);
            Gson gson = new GsonBuilder().registerTypeAdapter(Parent.Child.class, new com.google.gson.InstanceCreator<Parent.Child>() {
                public Parent.Child createInstance(java.lang.reflect.Type type) {
                    return p.new Child();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1620,gson);
            String json = "{\'value2\':3}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1621,json);
            Parent.Child c = gson.fromJson(json, Parent.Child.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1622,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1618,c.value2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInnerClassDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInnerClassDeserialization");
            final Parent p = new Parent();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1619,p);
            Gson gson = new GsonBuilder().registerTypeAdapter(Parent.Child.class, new com.google.gson.InstanceCreator<Parent.Child>() {
                public Parent.Child createInstance(java.lang.reflect.Type type) {
                    return p.new Child();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1620,gson);
            String json = "{\'vaue2\':3}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1621,json);
            Parent.Child c = gson.fromJson(json, Parent.Child.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1622,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1618,c.value2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInnerClassDeserialization_literalMutation2411() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInnerClassDeserialization_literalMutation2411");
            final Parent p = new Parent();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1619,p);
            Gson gson = new GsonBuilder().registerTypeAdapter(Parent.Child.class, new com.google.gson.InstanceCreator<Parent.Child>() {
                public Parent.Child createInstance(java.lang.reflect.Type type) {
                    return p.new Child();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1620,gson);
            String json = "{\'value2\':3}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1621,json);
            Parent.Child c = gson.fromJson(json, Parent.Child.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1622,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1618,c.value2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testInnerClassDeserialization_literalMutation2412() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInnerClassDeserialization_literalMutation2412");
            final Parent p = new Parent();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1619,p);
            Gson gson = new GsonBuilder().registerTypeAdapter(Parent.Child.class, new com.google.gson.InstanceCreator<Parent.Child>() {
                public Parent.Child createInstance(java.lang.reflect.Type type) {
                    return p.new Child();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1620,gson);
            String json = "{\'value\':3}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1621,json);
            Parent.Child c = gson.fromJson(json, Parent.Child.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1622,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1618,c.value2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testInnerClassDeserialization_remove340() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testInnerClassDeserialization_remove340");
            final Parent p = new Parent();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1619,p);
            Gson gson = new GsonBuilder().registerTypeAdapter(Parent.Child.class, new com.google.gson.InstanceCreator<Parent.Child>() {
                public Parent.Child createInstance(java.lang.reflect.Type type) {
                    return p.new Child();
                }
            }).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1620,gson);
            String json = "{\'value2\':3}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1621,json);
            Parent.Child c = gson.fromJson(json, Parent.Child.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1622,c);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1618,c.value2);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class Parent {
        @SuppressWarnings(value = "unused")
        int value1 = 1;

        private class Child {
            int value2 = 2;
        }
    }

    private static class ArrayOfArrays {
        private final TestTypes.BagOfPrimitives[][] elements;

        public ArrayOfArrays() {
            elements = new TestTypes.BagOfPrimitives[3][2];
            for (int i = 0 ; i < (elements.length) ; ++i) {
                TestTypes.BagOfPrimitives[] row = elements[i];
                for (int j = 0 ; j < (row.length) ; ++j) {
                    row[j] = new TestTypes.BagOfPrimitives((i + j) , (i * j) , false , ((i + "_") + j));
                }
            }
        }

        public String getExpectedJson() {
            StringBuilder sb = new StringBuilder("{\"elements\":[");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1554,sb);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1555,first);
            for (TestTypes.BagOfPrimitives[] row : elements) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1552,first);
                } else {
                    sb.append(",");
                }
                boolean firstOfRow = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1556,firstOfRow);
                sb.append("[");
                for (TestTypes.BagOfPrimitives element : row) {
                    if (firstOfRow) {
                        firstOfRow = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1553,firstOfRow);
                    } else {
                        sb.append(",");
                    }
                    sb.append(element.getExpectedJson());
                }
                sb.append("]");
            }
            sb.append("]}");
            return sb.toString();
        }
    }

    private static class ClassWithPrivateNoArgsConstructor {
        public int a;

        private ClassWithPrivateNoArgsConstructor() {
            a = 10;
        }
    }

    /** 
     * In response to Issue 41 http://code.google.com/p/google-gson/issues/detail?id=41
     */
public void testObjectFieldNamesWithoutQuotesDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectFieldNamesWithoutQuotesDeserialization");
            String json = "{longValue:1,\'booleanValue\':true,\"strigValue\":\'bar\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1670,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1671,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1667,bag.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1668,bag.booleanValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1669,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * In response to Issue 41 http://code.google.com/p/google-gson/issues/detail?id=41
     */
public void testObjectFieldNamesWithoutQuotesDeserialization_literalMutation2488() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectFieldNamesWithoutQuotesDeserialization_literalMutation2488");
            String json = "{longValue:1,\'booleanValue\':trËue,\"stringValue\":\'bar\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1670,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1671,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1667,bag.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1668,bag.booleanValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1669,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * In response to Issue 41 http://code.google.com/p/google-gson/issues/detail?id=41
     */
public void testObjectFieldNamesWithoutQuotesDeserialization_literalMutation2489() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testObjectFieldNamesWithoutQuotesDeserialization_literalMutation2489");
            String json = "{longValue:1,\'booleanValue\':true,\"stringValue\":\'ba\'}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1670,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1671,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1667,bag.longValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1668,bag.booleanValue);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1669,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization");
            String json = "{\"stringValue:1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"stringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stringValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2519() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2519");
            String json = "{\"storingValue\":1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"stringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stringValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2520() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2520");
            String json = "{\"stringValue\"1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"stringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stringValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2521() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2521");
            String json = "{\"stringValue\":1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"tringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stringValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2522() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2522");
            String json = "{\"stringValue\":1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"stringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stringValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2523() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2523");
            String json = "{\"stringValue\":1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"sringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stringValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2524() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2524");
            String json = "{\"stringValue\":1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"stringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stingValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2525() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2525");
            String json = "{\"stringValue\":1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"stringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{a\"stringValue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testStringFieldWithNumberValueDeserialization_literalMutation2526() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithNumberValueDeserialization_literalMutation2526");
            String json = "{\"stringValue\":1}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1703,json);
            TestTypes.BagOfPrimitives bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1704,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1696,bag.stringValue);
            json = "{\"stringValue\":1.5E+6}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1699,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1700,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1697,bag.stringValue);
            json = "{\"stringVaue\":true}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1701,json);
            bag = gson.fromJson(json, TestTypes.BagOfPrimitives.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1702,bag);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1698,bag.stringValue);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created to reproduce issue 140
     */
public void testStringFieldWithEmptyValueSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithEmptyValueSerialization");
            ClassWithEmptyStringFields target = new ClassWithEmptyStringFields();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1694,target);
            target.a = "5794¼49";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1693,target.a);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1690,json.contains("\"a\":\"5794749\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1691,json.contains("\"b\":\"\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1692,json.contains("\"c\":\"\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created to reproduce issue 140
     */
public void testStringFieldWithEmptyValueSerialization_literalMutation2516() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithEmptyValueSerialization_literalMutation2516");
            ClassWithEmptyStringFields target = new ClassWithEmptyStringFields();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1694,target);
            target.a = "5794749";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1693,target.a);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1690,json.contains("\"a\":\"5794749\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1691,json.contains("\"b\":\"\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1692,json.contains("\"c\":\"\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created to reproduce issue 140
     */
public void testStringFieldWithEmptyValueSerialization_literalMutation2517() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithEmptyValueSerialization_literalMutation2517");
            ClassWithEmptyStringFields target = new ClassWithEmptyStringFields();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1694,target);
            target.a = "579749";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1693,target.a);
            String json = gson.toJson(target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1695,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1690,json.contains("\"a\":\"5794749\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1691,json.contains("\"b\":\"\""));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1692,json.contains("\"c\":\"\""));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created to reproduce issue 140
     */
public void testStringFieldWithEmptyValueDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithEmptyValueDeserialization");
            String json = "{a:\"57947\n9\",b:\"\",c:\"\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1688,json);
            ClassWithEmptyStringFields target = gson.fromJson(json, ClassWithEmptyStringFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1689,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1685,target.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1686,target.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1687,target.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created to reproduce issue 140
     */
public void testStringFieldWithEmptyValueDeserialization_literalMutation2513() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithEmptyValueDeserialization_literalMutation2513");
            String json = "{a:\"5794749\",b:\"\",c:\"\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1688,json);
            ClassWithEmptyStringFields target = gson.fromJson(json, ClassWithEmptyStringFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1689,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1685,target.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1686,target.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1687,target.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created to reproduce issue 140
     */
public void testStringFieldWithEmptyValueDeserialization_literalMutation2514() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testStringFieldWithEmptyValueDeserialization_literalMutation2514");
            String json = "{a:\"5794749\",b:\"\",:\"\"}";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1688,json);
            ClassWithEmptyStringFields target = gson.fromJson(json, ClassWithEmptyStringFields.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1689,target);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1685,target.a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1686,target.b);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1687,target.c);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private static class ClassWithEmptyStringFields {
        String a = "";

        String b = "";

        String c = "";
    }

    public void testJsonObjectSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testJsonObjectSerialization");
            Gson gson = new GsonBuilder().serializeNulls().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1637,gson);
            JsonObject obj = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1638,obj);
            String json = gson.toJson(obj);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1639,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1636,json);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_add365() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_add365");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_add366() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_add366");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_add367() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_add367");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_add368() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_add368");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_add369() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_add369");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
public void testSingletonLists() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("[56");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
public void testSingletonLists_literalMutation2510() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_literalMutation2510");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
public void testSingletonLists_literalMutation2511() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_literalMutation2511");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("46");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_remove341() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_remove341");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_remove342() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_remove342");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_remove343() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_remove343");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_remove344() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_remove344");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Test for issue 215.
     */
@Test(timeout = 1000)
    public void testSingletonLists_remove345() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testSingletonLists_remove345");
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1683,gson);
            Product product = new Product();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1684,product);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1680,gson.toJson(product));
            product.departments.add(new Department());
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1681,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
            product.attributes.add("456");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1682,gson.toJson(product));
            gson.fromJson(gson.toJson(product), Product.class);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateAsMapObjectField_add363() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField_add363");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            a.map.put("date", new java.util.Date(0));
            a.map.put("date", new java.util.Date(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateAsMapObjectField() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            a.map.put("dïte", new java.util.Date(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateAsMapObjectField_literalMutation2401() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField_literalMutation2401");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            a.map.put("daDte", new java.util.Date(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateAsMapObjectField_literalMutation2402() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField_literalMutation2402");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            a.map.put("dae", new java.util.Date(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateAsMapObjectField_literalMutation2403() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField_literalMutation2403");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            a.map.put("date", new java.util.Date(1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateAsMapObjectField_literalMutation2404() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField_literalMutation2404");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            a.map.put("date", new java.util.Date(-1));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testDateAsMapObjectField_literalMutation2405() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField_literalMutation2405");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            a.map.put("date", new java.util.Date(0));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void testDateAsMapObjectField_remove339() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testDateAsMapObjectField_remove339");
            HasObjectMap a = new HasObjectMap();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1609,a);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1608,gson.toJson(a));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public class HasObjectMap {
        Map<java.lang.String, java.lang.Object> map = new HashMap<java.lang.String, java.lang.Object>();
    }

    static final class Department {
        public String name = "abc";

        public String code = "123";
    }

    static final class Product {
        private List<java.lang.String> attributes = new ArrayList<java.lang.String>();

        private List<Department> departments = new ArrayList<Department>();
    }
}

