package com.google.gson.functional;

import com.google.gson.Gson;
import com.google.gson.GsonBuilder;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import com.google.gson.JsonPrimitive;
import com.google.gson.JsonSerializationContext;
import com.google.gson.JsonSerializer;
import org.junit.Test;
import junit.framework.TestCase;
import java.lang.reflect.Type;

/** 
 * Test that the hierarchy adapter works when subtypes are used.
 */
public final class TypeHierarchyAdapterTest extends TestCase {
    public void testTypeHierarchy() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "ady";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3555() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3555");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "an dy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3556() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3556");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "any";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3557() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3557");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2006;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3558() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3558");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2004;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3559() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3559");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 1002;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3560() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3560");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 4010;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3562() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3562");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("i!der" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3563() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3563");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("ind?er" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3564() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3564");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("indr" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3565() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3565");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2008) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3566() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3566");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2006) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3567() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3567");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 1003) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3568() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3568");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 4014) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3570() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3570");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("jÚel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3571() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3571");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("jµoel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3572() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3572");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("jel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3573() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3573");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2007) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3574() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3574");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2005) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3575() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3575");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 1003) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3576() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3576");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 4012) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3578() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3578");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jjsse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3579() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3579");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3580() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3580");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jese" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3581() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3581");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2007) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3582() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3582");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2005) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3583() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3583");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 1003) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3584() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3584");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 4012) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3586() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3586");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eÈic";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3587() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3587");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eäric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3588() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3588");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "erc";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3589() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3589");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2002;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3590() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3590");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3591() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3591");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 1000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3592() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3592");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 4002;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3594() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3594");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerEme" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3595() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3595");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jÇerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3596() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3596");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jeome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3597() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3597");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2007);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3598() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3598");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2005);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3599() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3599");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 1003);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3600() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3600");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 4012);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3602() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3602");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("la3ry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3603() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3603");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("laRrry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3604() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3604");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("lrry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3605() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3605");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1999) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3606() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3606");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1997) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3607() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3607");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 999) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3608() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3608");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 3996) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3610() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3610");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("ser\'ey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3611() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3611");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3612() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3612");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("srgey" , 1998) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3613() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3613");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1999) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3614() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3614");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 1997) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3615() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3615");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 999) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testTypeHierarchy_literalMutation3616() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testTypeHierarchy_literalMutation3616");
            Manager andy = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2435,andy);
            andy.userid = "andy";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2427,andy.userid);
            andy.startDate = 2005;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2428,andy.startDate);
            andy.minions = new Employee[]{ new Employee("inder" , 2007) , new Employee("joel" , 2006) , new Employee("jesse" , 2006) };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2429,andy.minions);
            CEO eric = new CEO();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2436,eric);
            eric.userid = "eric";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2430,eric.userid);
            eric.startDate = 2001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2431,eric.startDate);
            eric.assistant = new Employee("jerome" , 2006);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2432,eric.assistant);
            eric.minions = new Employee[]{ new Employee("larry" , 1998) , new Employee("sergey" , 3996) , andy };
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2433,eric.minions);
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).setPrettyPrinting().create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),428,gson);
            Company company = new Company();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2437,company);
            company.ceo = eric;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2434,company.ceo);
            String json = gson.toJson(company, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),232,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2411,("{\n" + ("  \"ceo\": {\n" + ("    \"userid\": \"eric\",\n" + ("    \"startDate\": 2001,\n" + ("    \"minions\": [\n" + ("      {\n" + ("        \"userid\": \"larry\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"sergey\",\n" + ("        \"startDate\": 1998\n" + ("      },\n" + ("      {\n" + ("        \"userid\": \"andy\",\n" + ("        \"startDate\": 2005,\n" + ("        \"minions\": [\n" + ("          {\n" + ("            \"userid\": \"inder\",\n" + ("            \"startDate\": 2007\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"joel\",\n" + ("            \"startDate\": 2006\n" + ("          },\n" + ("          {\n" + ("            \"userid\": \"jesse\",\n" + ("            \"startDate\": 2006\n" + ("          }\n" + ("        ]\n" + ("      }\n" + ("    ],\n" + ("    \"assistant\": {\n" + ("      \"userid\": \"jerome\",\n" + ("      \"startDate\": 2006\n" + ("    }\n" + ("  }\n" + "}"))))))))))))))))))))))))))))))))))))));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),124,json);
            Company copied = gson.fromJson(json, Company.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2438,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1341,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2412,gson.toJson(copied, com.google.gson.functional.TypeHierarchyAdapterTest.Company.class));
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2413,copied.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2414,company.ceo.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2415,copied.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2416,company.ceo.assistant.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2417,copied.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2418,company.ceo.minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2419,copied.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2420,company.ceo.minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2421,copied.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2422,company.ceo.minions[2].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2423,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2424,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[0].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2425,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(copied.ceo.minions[2])).minions[1].userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2426,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(company.ceo.minions[2])).minions[1].userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegisterSuperTypeFirst() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegisterSuperTypeFirst");
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).registerTypeHierarchyAdapter(Manager.class, new ManagerAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2408,gson);
            Manager manager = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2409,manager);
            manager.userid = "iner";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2407,manager.userid);
            String json = gson.toJson(manager, Manager.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1790,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2404,json);
            Manager copied = gson.fromJson(json, Manager.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2410,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2405,manager.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2406,copied.userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegisterSuperTypeFirst_literalMutation3552() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegisterSuperTypeFirst_literalMutation3552");
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).registerTypeHierarchyAdapter(Manager.class, new ManagerAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2408,gson);
            Manager manager = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2409,manager);
            manager.userid = "indõer";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2407,manager.userid);
            String json = gson.toJson(manager, Manager.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1790,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2404,json);
            Manager copied = gson.fromJson(json, Manager.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2410,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2405,manager.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2406,copied.userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void testRegisterSuperTypeFirst_literalMutation3553() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegisterSuperTypeFirst_literalMutation3553");
            Gson gson = new GsonBuilder().registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).registerTypeHierarchyAdapter(Manager.class, new ManagerAdapter()).create();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2408,gson);
            Manager manager = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2409,manager);
            manager.userid = "ider";
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2407,manager.userid);
            String json = gson.toJson(manager, Manager.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1790,json);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2404,json);
            Manager copied = gson.fromJson(json, Manager.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2410,copied);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2405,manager.userid);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2406,copied.userid);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This behaviour changed in Gson 2.1; it used to throw.
     */
@Test(timeout = 1000)
    public void testRegisterSubTypeFirstAllowed() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "testRegisterSubTypeFirstAllowed");
            new GsonBuilder().registerTypeHierarchyAdapter(Manager.class, new ManagerAdapter()).registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).create();
            new GsonBuilder().registerTypeHierarchyAdapter(Manager.class, new ManagerAdapter()).registerTypeHierarchyAdapter(Employee.class, new EmployeeAdapter()).create();
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * This behaviour changed in Gson 2.1; it used to throw.
     */
@Test(timeout = 1000)
    public void testRegisterSubTypeFirstAllowed_remove420() {
    }

    static class ManagerAdapter implements JsonDeserializer<Manager> , JsonSerializer<Manager> {
        public Manager deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) {
            Manager result = new Manager();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1537,result);
            result.userid = json.getAsString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2403,result.userid);
            return result;
        }

        public JsonElement serialize(Manager src, Type typeOfSrc, JsonSerializationContext context) {
            return new JsonPrimitive(src.userid);
        }
    }

    static class EmployeeAdapter implements JsonDeserializer<Employee> , JsonSerializer<Employee> {
        public JsonElement serialize(Employee employee, Type typeOfSrc, JsonSerializationContext context) {
            JsonObject result = new JsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2391,result);
            result.add("userid", context.serialize(employee.userid, String.class));
            result.add("startDate", context.serialize(employee.startDate, long.class));
            if (employee instanceof Manager) {
                result.add("minions", context.serialize(((Manager)(employee)).minions, Employee[].class));
                if (employee instanceof CEO) {
                    result.add("assistant", context.serialize(((CEO)(employee)).assistant, Employee.class));
                } 
            } 
            return result;
        }

        public Employee deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context) throws JsonParseException {
            JsonObject object = json.getAsJsonObject();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2399,object);
            Employee result = null;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2400,result);
            JsonElement assistant = object.get("assistant");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2401,assistant);
            if (assistant != null) {
                result = new CEO();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2392,result);
                ((CEO)(result)).assistant = context.deserialize(assistant, Employee.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2393,((com.google.gson.functional.TypeHierarchyAdapterTest.CEO)(result)).assistant);
            } 
            JsonElement minons = object.get("minions");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2402,minons);
            if (minons != null) {
                if (result == null) {
                    result = new Manager();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2394,result);
                } 
                ((Manager)(result)).minions = context.deserialize(minons, Employee[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2395,((com.google.gson.functional.TypeHierarchyAdapterTest.Manager)(result)).minions);
            } 
            if (result == null) {
                result = new Employee();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2396,result);
            } 
            result.userid = context.deserialize(object.get("userid"), String.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2397,result.userid);
            result.startDate = context.<java.lang.Long>deserialize(object.get("startDate"), long.class);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2398,result.startDate);
            return result;
        }
    }

    static class Employee {
        String userid;

        long startDate;

        Employee(String userid ,long startDate) {
            this.userid = userid;
            this.startDate = startDate;
        }

        Employee() {
        }
    }

    static class Manager extends Employee {
        Employee[] minions;
    }

    static class CEO extends Manager {
        Employee assistant;
    }

    static class Company {
        CEO ceo;
    }
}

