package com.google.gson.metrics;

import java.util.ArrayList;
import com.google.gson.annotations.Expose;
import com.google.gson.Gson;
import java.util.HashMap;
import com.google.gson.JsonParseException;
import java.util.List;
import java.util.Map;
import java.io.StringWriter;
import org.junit.Test;
import junit.framework.TestCase;
import java.lang.reflect.Type;
import com.google.gson.reflect.TypeToken;

/** 
 * Tests to measure performance for Gson. All tests in this file will be disabled in code. To run
 * them remove disabled_ prefix from the tests and run them.
 * 
 * @author Inderjeet Singh
 * @author Joel Leitch
 */
public class PerformanceTest extends TestCase {
    private static final int COLLECTION_SIZE = 5000;

    private static final int NUM_ITERATIONS = 100;

    private Gson gson;

    @Override
    protected void setUp() throws Exception {
        super.setUp();
        gson = new Gson();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),1137,gson);
    }

    public void testDummy() {
    }

    @Test(timeout = 1000)
    public void disabled_testStringDeserialization_add538() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_add538");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testStringDeserialization_add539() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_add539");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testStringDeserialization_add540() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_add540");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testStringDeserialization_add541() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_add541");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization");
            StringBuilder sb = new StringBuilder(8097);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3920() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3920");
            StringBuilder sb = new StringBuilder(8095);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3921() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3921");
            StringBuilder sb = new StringBuilder(4048);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3922() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3922");
            StringBuilder sb = new StringBuilder(16192);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3924() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3924");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yipùie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3925() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3925");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yip¬pie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3926() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3926");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippe");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3928() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3928");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3929() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3929");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message2\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3930() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3930");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error mesage.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3931() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3931");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"ítackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3932() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3932");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testStringDeserialization_literalMutation3933() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_literalMutation3933");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            sb.append("Error Yippie");
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stacTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testStringDeserialization_remove459() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testStringDeserialization_remove459");
            StringBuilder sb = new StringBuilder(8096);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2596,sb);
            while (true) {
                try {
                    String stackTrace = sb.toString();
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2597,stackTrace);
                    sb.append(stackTrace);
                    String json = (("{\"message\":\"Error message.\"," + "\"stackTrace\":\"") + stackTrace) + "\"}";
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),878,json);
                    parseLongJson(json);
                    System.out.println(("Gson could handle a string of size: " + (stackTrace.length())));
                } catch (JsonParseException expected) {
                    break;
                }
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private void parseLongJson(String json) throws JsonParseException {
        ExceptionHolder target = gson.fromJson(json, ExceptionHolder.class);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2600,target);
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2598,target.message.contains("Error"));
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2599,target.stackTrace.contains("Yippie"));
    }

    private static class ExceptionHolder {
        public final String message;

        public final String stackTrace;

        @SuppressWarnings(value = "unused")
        private ExceptionHolder() {
            this("", "");
        }

        public ExceptionHolder(String message ,String stackTrace) {
            this.message = message;
            this.stackTrace = stackTrace;
        }
    }

    @SuppressWarnings(value = "unused")
    private static class CollectionEntry {
        final String name;

        final String value;

        private CollectionEntry() {
            this(null, null);
        }

        CollectionEntry(String name ,String value) {
            this.name = name;
            this.value = value;
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionSerialization_add527() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_add527");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionSerialization_add528() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_add528");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization");
            int count = 1400001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3858() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3858");
            int count = 700000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3859() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3859");
            int count = 2800000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3860() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3860");
            int count = 1399999;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3862() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3862");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 1 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3863() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3863");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = -1 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3864() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3864");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3866() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3866");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("]ame" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3867() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3867");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("naÎme" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3868() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3868");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("nae" + i) , ("value" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3869() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3869");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("v3lue" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3870() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3870");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("valZue" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionSerialization_literalMutation3871() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_literalMutation3871");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("vlue" + i)));
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionSerialization_remove448() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_remove448");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
            }
            gson.toJson(list);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionSerialization_remove449() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionSerialization_remove449");
            int count = 1400000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2579,count);
            List<CollectionEntry> list = new ArrayList<CollectionEntry>(count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2580,list);
            for (int i = 0 ; i < count ; ++i) {
                list.add(new CollectionEntry(("name" + i) , ("value" + i)));
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_add522() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_add522");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_add523() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_add523");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_add524() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_add524");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_add525() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_add525");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_add526() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_add526");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87001;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3839() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3839");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 86999;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3840() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3840");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 43500;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3841() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3841");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 174000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3845() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3845");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 1 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3846() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3846");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = -1 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3847() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3847");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3849() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3849");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = true;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3851() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3851");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:iname").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3852() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3852");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'nìame").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3853() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3853");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{ame:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3854() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3854");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'va~ue").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3855() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3855");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'va.lue").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testLargeCollectionDeserialization_literalMutation3856() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_literalMutation3856");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'alue").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_remove443() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_remove443");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_remove444() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_remove444");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_remove445() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_remove445");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_remove446() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_remove446");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testLargeCollectionDeserialization_remove447() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeCollectionDeserialization_remove447");
            StringBuilder sb = new StringBuilder();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2573,sb);
            int count = 87000;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2574,count);
            boolean first = true;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2575,first);
            sb.append('[');
            for (int i = 0 ; i < count ; ++i) {
                if (first) {
                    first = false;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2572,first);
                } else {
                    sb.append(',');
                }
                sb.append("{name:\'name").append(i).append("\',value:\'value").append(i).append("\'}");
            }
            sb.append(']');
            String json = sb.toString();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2576,json);
            Type collectionType = new TypeToken<java.util.ArrayList<CollectionEntry>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2577,collectionType);
            List<CollectionEntry> list = gson.fromJson(json, collectionType);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2578,list);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2570,count);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2571,list.size());
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testByteArraySerialization_add518() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_add518");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testByteArraySerialization_add519() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_add519");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization");
            for (int size = 4145151 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3802() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3802");
            for (int size = 4145153 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3803() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3803");
            for (int size = 2072576 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3804() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3804");
            for (int size = 8290304 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3807() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3807");
            for (int size = 4145152 ; true ; size += 1036287) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3808() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3808");
            for (int size = 4145152 ; true ; size += 1036289) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3809() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3809");
            for (int size = 4145152 ; true ; size += 518144) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3810() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3810");
            for (int size = 4145152 ; true ; size += 2072576) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3812() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3812");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 1 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3813() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3813");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = -1 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3814() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3814");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3816() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3816");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 4;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3817() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3817");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 2;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3818() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3818");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 10;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3819() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3819");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 6;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3821() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3821");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could seriali¢e a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3822() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3822");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gson could serialize a íbyte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disabled_testByteArraySerialization_literalMutation3823() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_literalMutation3823");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
                System.out.printf("Gon could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testByteArraySerialization_remove439() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_remove439");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                System.out.printf("Gson could serialize a byte array of size: %d\n", size);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disabled_testByteArraySerialization_remove440() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testByteArraySerialization_remove440");
            for (int size = 4145152 ; true ; size += 1036288) {
                byte[] ba = new byte[size];
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2559,ba);
                for (int i = 0 ; i < size ; ++i) {
                    ba[i] = 5;
                    fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2558,ba[i]);
                }
                gson.toJson(ba);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_add508() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_add508");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_add509() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_add509");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_add510() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_add510");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_add511() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_add511");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_add512() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_add512");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization");
            for (int numElements = 10639295 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3769() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3769");
            for (int numElements = 10639297 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3770() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3770");
            for (int numElements = 5319648 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3771() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3771");
            for (int numElements = 21278592 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3774() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3774");
            for (int numElements = 10639296 ; true ; numElements += 16385) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3775() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3775");
            for (int numElements = 10639296 ; true ; numElements += 8192) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3776() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3776");
            for (int numElements = 10639296 ; true ; numElements += 32768) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3777() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3777");
            for (int numElements = 10639296 ; true ; numElements += 16383) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3779() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3779");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 1));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3780() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3780");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 4));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
public void disable_testByteArrayDeserialization_literalMutation3781() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_literalMutation3781");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 3));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_remove429() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_remove429");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_remove430() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_remove430");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_remove431() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_remove431");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_remove432() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_remove432");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
                System.out.printf("Gson could deserialize a byte array of size: %d\n", ba.length);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    /** 
     * Created in response to http://code.google.com/p/google-gson/issues/detail?id=96
     */
@Test(timeout = 1000)
    public void disable_testByteArrayDeserialization_remove433() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testByteArrayDeserialization_remove433");
            for (int numElements = 10639296 ; true ; numElements += 16384) {
                StringBuilder sb = new StringBuilder((numElements * 2));
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2548,sb);
                sb.append("[");
                boolean first = true;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2549,first);
                for (int i = 0 ; i < numElements ; ++i) {
                    if (first) {
                        first = false;
                        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2547,first);
                    } else {
                        sb.append(",");
                    }
                    sb.append("5");
                }
                sb.append("]");
                String json = sb.toString();
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2550,json);
                byte[] ba = gson.fromJson(json, byte[].class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2551,ba);
            }
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeClasses_add532() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_add532");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeClasses_add533() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_add533");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeClasses_add534() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_add534");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses");
            ClassWithList c = new ClassWithList("Wtr");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3886() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3886");
            ClassWithList c = new ClassWithList("sMtr");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3887() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3887");
            ClassWithList c = new ClassWithList("sr");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3888() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3888");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 1 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3889() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3889");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = -1 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3890() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3890");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3892() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3892");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("el²ment-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3893() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3893");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("eleme±nt-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3894() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3894");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("elemet-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3895() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3895");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 1 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3896() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3896");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = -1 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3897() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3897");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3899() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3899");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time:\n%d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3900() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3900");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time:  %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeClasses_literalMutation3901() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_literalMutation3901");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Seralize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeClasses_remove453() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_remove453");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeClasses_remove454() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_remove454");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
            System.out.printf("Serialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeClasses_remove455() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeClasses_remove455");
            ClassWithList c = new ClassWithList("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2585,c);
            for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
                c.list.add(new ClassWithField(("element-" + i)));
            }
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2586,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2587,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2588,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2589,avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testDeserializeClasses_add520() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses_add520");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
            System.out.printf("Deserialize classes avg time: %d ms\n", avg);
            System.out.printf("Deserialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeClasses() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = 1 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
            System.out.printf("Deserialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeClasses_literalMutation3825() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses_literalMutation3825");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = -1 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
            System.out.printf("Deserialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeClasses_literalMutation3826() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses_literalMutation3826");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
            System.out.printf("Deserialize classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeClasses_literalMutation3828() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses_literalMutation3828");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
            System.out.printf("Deserialize classes avgåtime: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeClasses_literalMutation3829() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses_literalMutation3829");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
            System.out.printf("Deserialize classes 2avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeClasses_literalMutation3830() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses_literalMutation3830");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
            System.out.printf("Deserialize classes avg ime: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testDeserializeClasses_remove441() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeClasses_remove441");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2561,json);
            ClassWithList[] target = new ClassWithList[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),221,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2562,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithList.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2560,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2563,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2564,avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_add513() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_add513");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_add514() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_add514");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_add515() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_add515");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_add516() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_add516");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_add517() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_add517");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 1 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3784() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3784");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = -1 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3785() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3785");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3787() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3787");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100001 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3788() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3788");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 99999 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3789() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3789");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 50000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3790() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3790");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 200000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3792() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3792");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("feld" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3793() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3793");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("faield" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3794() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3794");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("fild" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3795() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3795");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object seria=ized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3796() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3796");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: Ã%d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3797() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3797");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large bject serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3798() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3798");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deseralized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3799() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3799");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disable_testLargeObjectSerializationAndDeserialization_literalMutation3800() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_literalMutation3800");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_remove434() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_remove434");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_remove435() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_remove435");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_remove436() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_remove436");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_remove437() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_remove437");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            System.out.printf("Large object serialized in: %d ms\n", (t2 - t1));
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disable_testLargeObjectSerializationAndDeserialization_remove438() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disable_testLargeObjectSerializationAndDeserialization_remove438");
            Map<java.lang.String, java.lang.Long> largeObject = new HashMap<java.lang.String, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2554,largeObject);
            for (long l = 0 ; l < 100000 ; l++) {
                largeObject.put(("field" + l), l);
            }
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2555,t1);
            String json = gson.toJson(largeObject);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2556,json);
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2557,t2);
            t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2552,t1);
            gson.fromJson(json, new TypeToken<java.util.Map<java.lang.String, java.lang.Long>>() {            }.getType());
            t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2553,t2);
            System.out.printf("Large object deserialized in: %d ms\n", (t2 - t1));
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeExposedClasses_add535() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_add535");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeExposedClasses_add536() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_add536");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeExposedClasses_add537() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_add537");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("ýtr");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3903() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3903");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("s\ntr");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3904() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3904");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("sr");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3905() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3905");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 1 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3906() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3906");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = -1 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3907() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3907");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3909() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3909");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("lement-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3910() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3910");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("el8ement-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3911() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3911");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("eement-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3912() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3912");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 1 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3913() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3913");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = -1 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3914() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3914");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3916() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3916");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes ´vg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3917() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3917");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serial@ize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testSerializeExposedClasses_literalMutation3918() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_literalMutation3918");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg ime: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeExposedClasses_remove456() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_remove456");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeExposedClasses_remove457() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_remove457");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
            System.out.printf("Serialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testSerializeExposedClasses_remove458() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testSerializeExposedClasses_remove458");
            ClassWithListOfObjects c1 = new ClassWithListOfObjects("str");
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2590,c1);
            for (int i1 = 0 ; i1 < (COLLECTION_SIZE) ; ++i1) {
                c1.list.add(new ClassWithExposedField(("element-" + i1)));
            }
            ClassWithListOfObjects c = c1;
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2591,c);
            StringWriter w = new StringWriter();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2592,w);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2593,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                gson.toJson(c, w);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2594,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2595,avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testDeserializeExposedClasses_add521() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses_add521");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
            System.out.printf("Deserialize exposed classes avg time: %d ms\n", avg);
            System.out.printf("Deserialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeExposedClasses() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = 1 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
            System.out.printf("Deserialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeExposedClasses_literalMutation3832() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses_literalMutation3832");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = -1 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
            System.out.printf("Deserialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeExposedClasses_literalMutation3833() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses_literalMutation3833");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
            System.out.printf("Deserialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeExposedClasses_literalMutation3835() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses_literalMutation3835");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
            System.out.printf("Deserialize exposed classes av  time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeExposedClasses_literalMutation3836() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses_literalMutation3836");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
            System.out.printf("Deserialize exposed classes avg time: %d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testDeserializeExposedClasses_literalMutation3837() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses_literalMutation3837");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
            System.out.printf("Deserialize exposed classes avg time: d ms\n", avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testDeserializeExposedClasses_remove442() {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testDeserializeExposedClasses_remove442");
            String json = buildJsonForClassWithList();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2566,json);
            ClassWithListOfObjects[] target = new ClassWithListOfObjects[NUM_ITERATIONS];
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),267,target);
            long t1 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2567,t1);
            for (int i = 0 ; i < (NUM_ITERATIONS) ; ++i) {
                target[i] = gson.fromJson(json, ClassWithListOfObjects.class);
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2565,target[i]);
            }
            long t2 = System.currentTimeMillis();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2568,t2);
            long avg = (t2 - t1) / (NUM_ITERATIONS);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2569,avg);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testLargeGsonMapRoundTrip_add529() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_add529");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testLargeGsonMapRoundTrip_add530() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_add530");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testLargeGsonMapRoundTrip_add531() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_add531");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 1 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3873() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3873");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = -1 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3874() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3874");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3876() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3876");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 999999 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3877() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3877");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000001 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3878() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3878");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 500000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3879() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3879");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 2000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3881() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3881");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 2));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3882() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3882");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 0));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    public void disabled_testLargeGsonMapRoundTrip_literalMutation3883() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_literalMutation3883");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 0));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testLargeGsonMapRoundTrip_remove450() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_remove450");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testLargeGsonMapRoundTrip_remove451() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_remove451");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
            gson.fromJson(json, longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    @Test(timeout = 1000)
    public void disabled_testLargeGsonMapRoundTrip_remove452() throws Exception {
        try {
            fr.inria.diversify.testamplification.logger.Logger.writeTestStart(Thread.currentThread(),this, "disabled_testLargeGsonMapRoundTrip_remove452");
            Map<java.lang.Long, java.lang.Long> original = new HashMap<java.lang.Long, java.lang.Long>();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2581,original);
            for (long i = 0 ; i < 1000000 ; i++) {
                original.put(i, (i + 1));
            }
            Gson gson = new Gson();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2582,gson);
            String json = gson.toJson(original);
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2583,json);
            Type longToLong = new TypeToken<java.util.Map<java.lang.Long, java.lang.Long>>() {            }.getType();
            fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2584,longToLong);
        } finally {
            fr.inria.diversify.testamplification.logger.Logger.writeTestFinish(Thread.currentThread());
        }
    }

    private String buildJsonForClassWithList() {
        StringBuilder sb = new StringBuilder("{");
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2544,sb);
        sb.append("field:").append("\'str\',");
        sb.append("list:[");
        boolean first = true;
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2545,first);
        for (int i = 0 ; i < (COLLECTION_SIZE) ; ++i) {
            if (first) {
                first = false;
                fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2543,first);
            } else {
                sb.append(",");
            }
            sb.append((("{field:\'element-" + i) + "\'}"));
        }
        sb.append("]");
        sb.append("}");
        String json = sb.toString();
        fr.inria.diversify.testamplification.logger.Logger.logAssertArgument(Thread.currentThread(),2546,json);
        return json;
    }

    @SuppressWarnings(value = "unused")
    private static final class ClassWithList {
        final String field;

        final List<ClassWithField> list = new ArrayList<ClassWithField>(PerformanceTest.COLLECTION_SIZE);

        ClassWithList() {
            this(null);
        }

        ClassWithList(String field) {
            this.field = field;
        }
    }

    @SuppressWarnings(value = "unused")
    private static final class ClassWithField {
        final String field;

        ClassWithField() {
            this("");
        }

        public ClassWithField(String field) {
            this.field = field;
        }
    }

    @SuppressWarnings(value = "unused")
    private static final class ClassWithListOfObjects {
        @Expose
        final String field;

        @Expose
        final List<ClassWithExposedField> list = new ArrayList<ClassWithExposedField>(PerformanceTest.COLLECTION_SIZE);

        ClassWithListOfObjects() {
            this(null);
        }

        ClassWithListOfObjects(String field) {
            this.field = field;
        }
    }

    @SuppressWarnings(value = "unused")
    private static final class ClassWithExposedField {
        @Expose
        final String field;

        ClassWithExposedField() {
            this("");
        }

        ClassWithExposedField(String field) {
            this.field = field;
        }
    }
}

